@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2019, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -514,6 +514,15 @@ public:
     //!
     uint32_t GetMode() { return m_mode; }
 
+    //!
+    //! \brief  Get the perf profiler pointer
+    //! \return The perf profiler \see m_perfProfiler
+    //!
+    MediaPerfProfiler *GetPerfProfiler()
+    {
+        return m_perfProfiler;
+    }
+
     //!
     //! \brief  Gets the decode standard
     //! \return The decode standard \see m_standard
@@ -657,6 +666,12 @@ public:
         m_dummyReferenceStatus = status;
     }
 
+    //!
+    //! \brief  Get mmc enable flag
+    //! \return bool
+    //!
+    bool IsDecoderMmcEnabled(){return m_mmc ? m_mmc->IsMmcEnabled() : false;}
+
 protected:
 
     //!
@@ -795,7 +810,7 @@ protected:
 
 #if USE_CODECHAL_DEBUG_TOOL
     MOS_STATUS DumpProcessingParams(
-        PCODECHAL_DECODE_PROCESSING_PARAMS decProcParams);
+        DecodeProcessingParams *decProcParams);
 
 #endif
 
@@ -960,8 +975,10 @@ protected:
     uint32_t                    m_standard          = CODECHAL_UNDEFINED;
     //! \brief Current frame number
     uint32_t                    m_frameNum          = 0;
-    //! \brief Indicates if current field is second field(bottom field)
+    //! \brief Indicates if current field is second field
     bool                        m_secondField       = false;
+    //! \brief Indidates if fields are completed
+    uint32_t                    m_fullFieldsFrame     = 0;
     //! \brief picture information of current render target
     CODEC_PICTURE               m_crrPic            = {0};
     //! \brief Video GPU node inuse
