@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -40,7 +40,7 @@ MOS_STATUS CodechalEncodeCscDs::AllocateSurfaceCsc()
     return m_encoder->m_trackedBuf->AllocateSurfaceCsc();
 }
 
-MOS_STATUS CodechalEncodeCscDs::CheckRawColorFormat(MOS_FORMAT format)
+MOS_STATUS CodechalEncodeCscDs::CheckRawColorFormat(MOS_FORMAT format, MOS_TILE_TYPE tileType)
 {
     CODECHAL_ENCODE_FUNCTION_ENTER;
 
@@ -445,7 +445,11 @@ MOS_STATUS CodechalEncodeCscDs::SetSurfacesToEncPak()
             CODECHAL_ENCODE_CHK_STATUS_RETURN(m_debugInterface->DumpYUVSurface(
                 cscSurface,
                 CodechalDbgAttr::attrEncodeRawInputSurface,
-                "Copied_SrcSurf")) // needs to consider YUV420
+                "Copied_SrcSurf")); // needs to consider YUV420
+            if (m_cscUsingSfc)
+            {
+                CODECHAL_ENCODE_CHK_STATUS_RETURN(m_sfcState->DumpBuffers(m_debugInterface));
+            }
         )
     }
 
@@ -1091,22 +1095,21 @@ MOS_STATUS CodechalEncodeCscDs::CheckCondition()
 
     auto cscFlagPrev = m_cscFlag;
     m_cscFlag = 0;
-    m_cscRawSurfWidth = details.dwWidth;
-    m_cscRawSurfHeight = details.dwHeight;
+    // Source surface width/height for CSC must be set using the lowest value between
+    // SequenceParametersSet width/height and real surface width/height
+    m_cscRawSurfWidth  = MOS_MIN(details.dwWidth,  m_encoder->m_frameWidth);
+    m_cscRawSurfHeight = MOS_MIN(details.dwHeight, m_encoder->m_frameHeight);
     m_colorRawSurface = cscColorNv12TileY; // by default assume NV12 Tile-Y format
     m_threadTraverseSizeX = 5;
     m_threadTraverseSizeY = 2;    // for NV12, thread space is 32x4
 
     // check raw surface's alignment
-    if (m_cscEnableCopy && (details.dwWidth % m_rawSurfAlignment || details.dwHeight % m_rawSurfAlignment))
-    {
-        m_cscRequireCopy = 1;
-    }
+    CODECHAL_ENCODE_CHK_STATUS_RETURN(CheckRawSurfaceAlignment(details));
 
     // check raw surface's color/tile format
     if (m_cscEnableColor && !m_encoder->CheckSupportedFormat(&details))
     {
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(CheckRawColorFormat(details.Format));
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(CheckRawColorFormat(details.Format, details.TileType));
     }
 
     // check raw surface's MMC state
@@ -1132,6 +1135,15 @@ MOS_STATUS CodechalEncodeCscDs::CheckCondition()
     return eStatus;
 }
 
+MOS_STATUS CodechalEncodeCscDs::CheckRawSurfaceAlignment(MOS_SURFACE surface)
+{
+    if (m_cscEnableCopy && (surface.dwWidth % m_rawSurfAlignment || surface.dwHeight % m_rawSurfAlignment))
+    {
+        m_cscRequireCopy = 1;
+    }
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS CodechalEncodeCscDs::CheckReconSurfaceAlignment(PMOS_SURFACE surface)
 {
     CODECHAL_ENCODE_FUNCTION_ENTER;
@@ -1228,6 +1240,13 @@ MOS_STATUS CodechalEncodeCscDs::KernelFunctions(
     // call 16x/32x DS
     if (m_scalingEnabled && m_16xMeSupported)
     {
+        //disable csc and reset colorFormat in 16x/32x stage since their inputs are 4x/16x DS results (only Y component)
+        if(m_cscFlag && m_encoder->m_vdencEnabled && CODECHAL_HEVC == m_standard)
+        {
+            m_colorRawSurface = cscColorNv12TileY;
+            m_cscFlag = false;
+        }
+
         // 4x downscaled images used as the input for 16x downscaling
         if (useDsConvInCombinedKernel)
         {
@@ -1363,6 +1382,14 @@ MOS_STATUS CodechalEncodeCscDs::CscKernel(
     // setup kernel params
     CODECHAL_ENCODE_CHK_STATUS_RETURN(SetKernelParamsCsc(params));
 
+    if(m_encoder->m_vdencEnabled && CODECHAL_HEVC == m_standard)
+    {
+        CODECHAL_DEBUG_TOOL(CODECHAL_ENCODE_CHK_STATUS_RETURN(m_debugInterface->DumpYUVSurface(
+            m_surfaceParamsCsc.psInputSurface,
+            CodechalDbgAttr::attrEncodeRawInputSurface,
+            m_curbeParams.downscaleStage == dsStage4x ? "4xDS_Input" : (m_curbeParams.downscaleStage == dsStage16x ? "16xDS_Input" : "32xDS_Input"))));
+    }
+
     PerfTagSetting perfTag;
     perfTag.Value = 0;
     perfTag.Mode = (uint16_t)m_mode & CODECHAL_ENCODE_MODE_BIT_MASK;
@@ -1401,6 +1428,14 @@ MOS_STATUS CodechalEncodeCscDs::CscKernel(
     // send CURBE
     CODECHAL_ENCODE_CHK_STATUS_RETURN(SetCurbeCsc());
 
+    if(m_encoder->m_vdencEnabled && CODECHAL_HEVC == m_standard)
+    {
+        CODECHAL_DEBUG_TOOL(CODECHAL_ENCODE_CHK_STATUS_RETURN(m_debugInterface->DumpCurbe(
+                m_curbeParams.downscaleStage == dsStage4x ? CODECHAL_MEDIA_STATE_4X_SCALING :
+                        (m_curbeParams.downscaleStage == dsStage16x ? CODECHAL_MEDIA_STATE_16X_SCALING : CODECHAL_MEDIA_STATE_32X_SCALING),
+                m_cscKernelState)));
+    }
+
     CODECHAL_MEDIA_STATE_TYPE encFunctionType = CODECHAL_MEDIA_STATE_CSC_DS_COPY;
     CODECHAL_DEBUG_TOOL(
         CODECHAL_ENCODE_CHK_STATUS_RETURN(m_debugInterface->DumpCurbe(
@@ -1433,48 +1468,57 @@ MOS_STATUS CodechalEncodeCscDs::CscKernel(
             m_cscKernelState));
     )
 
-    MHW_WALKER_PARAMS walkerParams;
-    MOS_ZeroMemory(&walkerParams, sizeof(walkerParams));
-    walkerParams.WalkerMode = m_walkerMode;
-    walkerParams.UseScoreboard = m_useHwScoreboard;
-    walkerParams.BlockResolution.x =
-    walkerParams.GlobalResolution.x =
-    walkerParams.GlobalOutlerLoopStride.x = m_walkerResolutionX;
-    walkerParams.BlockResolution.y =
-    walkerParams.GlobalResolution.y =
-    walkerParams.GlobalInnerLoopUnit.y = m_walkerResolutionY;
-    walkerParams.dwLocalLoopExecCount = 0xFFFF;  //MAX VALUE
-    walkerParams.dwGlobalLoopExecCount = 0xFFFF;  //MAX VALUE
+        // If m_pollingSyncEnabled is set, insert HW semaphore to wait for external
+        // raw surface processing to complete, before start CSC. Once the marker in
+        // raw surface is overwritten by external operation, HW semaphore will be
+        // signalled and CSC will start. This is to reduce SW latency between
+        // external raw surface processing and CSC, in usages like remote gaming.
+        if (m_pollingSyncEnabled)
+        {
+            MHW_MI_SEMAPHORE_WAIT_PARAMS miSemaphoreWaitParams;
+            MOS_ZeroMemory((&miSemaphoreWaitParams), sizeof(miSemaphoreWaitParams));
+            miSemaphoreWaitParams.presSemaphoreMem = &m_surfaceParamsCsc.psInputSurface->OsResource;
+            miSemaphoreWaitParams.dwResourceOffset = m_syncMarkerOffset;
+            miSemaphoreWaitParams.bPollingWaitMode = true;
+            miSemaphoreWaitParams.dwSemaphoreData = m_syncMarkerValue;
+            miSemaphoreWaitParams.CompareOperation = MHW_MI_SAD_NOT_EQUAL_SDD;
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(m_miInterface->AddMiSemaphoreWaitCmd(&cmdBuffer, &miSemaphoreWaitParams));
+        }
 
-    // Raster scan walking pattern
-    walkerParams.LocalOutLoopStride.y = 1;
-    walkerParams.LocalInnerLoopUnit.x = 1;
-    walkerParams.LocalEnd.x = m_walkerResolutionX - 1;
-
-    if (m_groupIdSelectSupported)
+    if (!m_encoder->m_computeContextEnabled)
     {
-        walkerParams.GroupIdLoopSelect = m_groupId;
-    }
+        MHW_WALKER_PARAMS walkerParams;
+        MOS_ZeroMemory(&walkerParams, sizeof(walkerParams));
+        walkerParams.WalkerMode = m_walkerMode;
+        walkerParams.UseScoreboard = m_useHwScoreboard;
+        walkerParams.BlockResolution.x =
+            walkerParams.GlobalResolution.x =
+            walkerParams.GlobalOutlerLoopStride.x = m_walkerResolutionX;
+        walkerParams.BlockResolution.y =
+            walkerParams.GlobalResolution.y =
+            walkerParams.GlobalInnerLoopUnit.y = m_walkerResolutionY;
 
-    // If m_pollingSyncEnabled is set, insert HW semaphore to wait for external 
-    // raw surface processing to complete, before start CSC. Once the marker in 
-    // raw surface is overwritten by external operation, HW semaphore will be 
-    // signalled and CSC will start. This is to reduce SW latency between 
-    // external raw surface processing and CSC, in usages like remote gaming.
-    if (m_pollingSyncEnabled)
+        //MAX VALUE
+        walkerParams.dwLocalLoopExecCount = 0xFFFF;
+        walkerParams.dwGlobalLoopExecCount = 0xFFFF;
+
+        // Raster scan walking pattern
+        walkerParams.LocalOutLoopStride.y = 1;
+        walkerParams.LocalInnerLoopUnit.x = 1;
+        walkerParams.LocalEnd.x = m_walkerResolutionX - 1;
+
+        if (m_groupIdSelectSupported)
+        {
+            walkerParams.GroupIdLoopSelect = m_groupId;
+        }
+
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_renderInterface->AddMediaObjectWalkerCmd(&cmdBuffer, &walkerParams));
+    }
+    else
     {
-        MHW_MI_SEMAPHORE_WAIT_PARAMS miSemaphoreWaitParams;
-        MOS_ZeroMemory((&miSemaphoreWaitParams), sizeof(miSemaphoreWaitParams));
-        miSemaphoreWaitParams.presSemaphoreMem = &m_surfaceParamsCsc.psInputSurface->OsResource;
-        miSemaphoreWaitParams.dwResourceOffset = m_syncMarkerOffset;
-        miSemaphoreWaitParams.bPollingWaitMode = true;
-        miSemaphoreWaitParams.dwSemaphoreData  = m_syncMarkerValue;
-        miSemaphoreWaitParams.CompareOperation = MHW_MI_SAD_NOT_EQUAL_SDD;
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_miInterface->AddMiSemaphoreWaitCmd(&cmdBuffer, &miSemaphoreWaitParams));
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(SetWalkerCmd(&cmdBuffer, m_cscKernelState));
     }
 
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(m_renderInterface->AddMediaObjectWalkerCmd(&cmdBuffer, &walkerParams));
-
     CODECHAL_ENCODE_CHK_STATUS_RETURN(m_encoder->EndStatusReport(&cmdBuffer, encFunctionType));
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(m_stateHeapInterface->SubmitBlocks(m_cscKernelState));
@@ -1507,12 +1551,12 @@ MOS_STATUS CodechalEncodeCscDs::CscKernel(
 
     if (!m_singleTaskPhaseSupported || m_lastTaskInPhase)
     {
-        HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+        HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface);
         m_osInterface->pfnSubmitCommandBuffer(m_osInterface, &cmdBuffer, m_renderContextUsesNullHw);
         m_lastTaskInPhase = false;
     }
 
-    if (dsDisabled == params->stageDsConversion)
+    if (dsDisabled == params->stageDsConversion && !(m_encoder->m_vdencEnabled && CODECHAL_HEVC == m_standard))
     {
         // send appropriate surface to Enc/Pak depending on different CSC operation type
         CODECHAL_ENCODE_CHK_STATUS_RETURN(SetSurfacesToEncPak());
@@ -1777,7 +1821,7 @@ MOS_STATUS CodechalEncodeCscDs::DsKernel(
 
     if (!m_singleTaskPhaseSupported || m_lastTaskInPhase)
     {
-        HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+        HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface);
         m_osInterface->pfnSubmitCommandBuffer(m_osInterface, &cmdBuffer, m_renderContextUsesNullHw);
         m_lastTaskInPhase = false;
     }
@@ -1785,6 +1829,18 @@ MOS_STATUS CodechalEncodeCscDs::DsKernel(
     return eStatus;
 }
 
+MOS_STATUS CodechalEncodeCscDs::SetHevcCscFlagAndRawColor()
+{
+    CODECHAL_ENCODE_FUNCTION_ENTER;
+
+    if(m_rawSurfaceToEnc->Format != Format_NV12 && CheckRawColorFormat(m_rawSurfaceToEnc->Format, m_rawSurfaceToEnc->TileType) == MOS_STATUS_SUCCESS)
+    {
+        m_cscFlag = true;
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
 CodechalEncodeCscDs::CodechalEncodeCscDs(CodechalEncoderState *encoder)
     : m_useRawForRef(encoder->m_useRawForRef),
       m_useCommonKernel(encoder->m_useCommonKernel),
