@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -457,6 +457,8 @@ public:
     //!
     MOS_STATUS KernelFunctions(KernelParams* params);
 
+    MOS_STATUS SetHevcCscFlagAndRawColor();
+
     //!
     //! \brief    CSC using SFC
     //!
@@ -494,8 +496,12 @@ protected:
         cscColorY210 = 4,           // Y210
         cscColorARGB = 5,           // ARGB
         cscColorNv12Linear = 6,     // NV12 linear
-        cscColorABGR = 7,           // ABGR
-        cscColorEnumNumber = 8
+        cscColorAYUV = 7,           // AYUV
+        cscColorARGB10 = 8,         // ARGB10
+        cscColorY410 = 9,           // Y410
+        cscColorABGR = 10,          // ABGR
+        cscColorABGR10 = 11,        // ABGR10
+        cscColorEnumNumber = 12
     };
 
     //!
@@ -663,6 +669,17 @@ protected:
     //!
     MOS_STATUS SetSurfacesToEncPak();
 
+    //!
+    //! \brief    Check alignment copy
+    //!
+    //! \param    surface
+    //!           Pointer to MOS_SURFACE
+    //!
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS CheckRawSurfaceAlignment(MOS_SURFACE surface);
+
 
     CodechalEncoderState*                   m_encoder = nullptr;                            //!< Pointer to ENCODER base class
     MOS_INTERFACE*                          m_osInterface = nullptr;                        //!< OS interface
@@ -771,7 +788,6 @@ protected:
     MOS_SURFACE*&               m_rawSurfaceToEnc;
     MOS_SURFACE*&               m_rawSurfaceToPak;
 
-private:
     //!
     //! \brief    CSC kernel binding table
     //!
@@ -1030,7 +1046,7 @@ private:
     //! \return   MOS_STATUS
     //!           MOS_STATUS_SUCCESS if success, else fail reason
     //!
-    virtual MOS_STATUS CheckRawColorFormat(MOS_FORMAT format);
+    virtual MOS_STATUS CheckRawColorFormat(MOS_FORMAT format, MOS_TILE_TYPE tileType);
 
     //!
     //! \brief    Initialize SFC state
@@ -1096,6 +1112,19 @@ private:
     //!
     MOS_STATUS SendSurfaceDS(PMOS_COMMAND_BUFFER cmdBuffer);
 
+    //!
+    //! \brief    Set walker command
+    //!
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS SetWalkerCmd(
+        MOS_COMMAND_BUFFER *cmdBuffer,
+        MHW_KERNEL_STATE *kernelState)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
     union
     {
         struct
