@@ -240,7 +240,7 @@ MOS_STATUS CodechalCmdInitializer::ConstructHevcHucCmd1ConstData(
     cmd1.num_ref_idx_l1_active_minus1 = sliceParams->num_ref_idx_l1_active_minus1;
     cmd1.ROIStreamInEnabled           = (uint8_t)m_roiStreamInEnabled;
     cmd1.UseDefaultQpDeltas           = (m_acqpEnabled && seqParams->QpAdjustment) || (m_brcEnabled && seqParams->MBBRC != mbBrcDisabled);
-    cmd1.TemporalMvpEnableFlag        = seqParams->sps_temporal_mvp_enable_flag;
+    cmd1.TemporalMvpEnableFlag        = sliceParams->slice_temporal_mvp_enable_flag;
     cmd1.PanicEnabled                 = m_panicEnabled;
 
     if (m_roiStreamInEnabled)
@@ -341,6 +341,7 @@ MOS_STATUS CodechalCmdInitializer::CmdInitializerSetConstData(
     bool                                        brcEnabled,
     bool                                        streaminEnabled,
     bool                                        roiStreamInEnabled,
+    bool                                        brcAdaptiveRegionBoostEnable,
     bool                                        roundingEnabled,
     bool                                        panicEnabled,
     int32_t                                     currentPass
@@ -378,6 +379,7 @@ MOS_STATUS CodechalCmdInitializer::CmdInitializerSetConstData(
     m_panicEnabled       = panicEnabled;
     m_roiStreamInEnabled = roiStreamInEnabled;
     m_currentPass        = currentPass;
+    m_brcAdaptiveRegionBoostEnabled = brcAdaptiveRegionBoostEnable;
 
     MOS_ZeroMemory(&lockFlagsWriteOnly, sizeof(MOS_LOCK_PARAMS));
     lockFlagsWriteOnly.WriteOnly = 1;
@@ -531,7 +533,7 @@ MOS_STATUS CodechalCmdInitializer::CommandInitializerSetVp9Params(CodechalVdencV
     m_vp9Params.segmentMapProvided           = state->m_segmentMapProvided;
     m_vp9Params.prevFrameSegEnabled          = state->m_prevFrameSegEnabled;
     m_vp9Params.numRefFrames                 = state->m_numRefFrames;
-    m_vp9Params.hmeEnabled                   = state->m_hmeEnabled;
+    m_vp9Params.me16Enabled                  = state->m_16xMeEnabled;
     m_vp9Params.dysVdencMultiPassEnabled     = state->m_dysVdencMultiPassEnabled;
     m_vp9Params.vdencPakOnlyMultipassEnabled = state->m_vdencPakonlyMultipassEnabled;
     m_vp9Params.pictureCodingType            = state->m_pictureCodingType;
@@ -683,8 +685,8 @@ MOS_STATUS CodechalCmdInitializer::CmdInitializerVp9SetDmem()
 
     HucInputCmd1  hucInputCmd1;
     MOS_ZeroMemory(&hucInputCmd1, sizeof(hucInputCmd1));
-    hucInputCmd1.VdencStreamInEnabled = m_vp9Params.segmentMapProvided || m_vp9Params.hmeEnabled;
-    hucInputCmd1.SegMapStreamInEnabled = m_vp9Params.segmentMapProvided || m_vp9Params.hmeEnabled;
+    hucInputCmd1.VdencStreamInEnabled = m_vp9Params.segmentMapProvided || m_vp9Params.me16Enabled;
+    hucInputCmd1.SegMapStreamInEnabled = m_vp9Params.segmentMapProvided || m_vp9Params.me16Enabled;
     hucInputCmd1.PakOnlyMultipassEnable = m_vp9Params.vdencPakOnlyMultipassEnabled;
     hucInputCmd1.num_ref_idx_l0_active_minus1 = (m_vp9Params.picParams->PicFlags.fields.frame_type) ? m_vp9Params.numRefFrames - 1 : 0;
 
