@@ -657,7 +657,8 @@ MOS_STATUS Mhw_CalcPolyphaseTablesY(
     MOS_FORMAT      srcFmt,
     float           fHPStrength,
     bool            bUse8x8Filter,
-    uint32_t        dwHwPhase);
+    uint32_t        dwHwPhase,
+    float           fLanczosT);
 
 MOS_STATUS Mhw_CalcPolyphaseTablesUV(
     int32_t  *piCoefs,
@@ -701,7 +702,7 @@ uint32_t Mhw_ConvertToTRMode(
 //*-----------------------------------------------------------------------------
 static __inline MOS_STATUS Mhw_AddCommandBB(
     PMHW_BATCH_BUFFER           pBatchBuffer,   // [in] Pointer to Batch Buffer
-    void                        *pCmd,           // [in] Command Pointer
+    const void                  *pCmd,          // [in] Command Pointer
     uint32_t                    dwCmdSize)      // [in] Size of command in bytes
 {
     uint8_t     *pbBatchPtr;
@@ -747,17 +748,22 @@ finish:
 static __inline MOS_STATUS Mhw_AddCommandCmdOrBB(
     void       *pCmdBuffer,     // [in] Pointer to Command Buffer
     void       *pBatchBuffer,   // [in] Pointer to Batch Buffer
-    void       *pCmd,           // [in] Command Pointer
-    uint32_t   dwCmdSize)      // [in] Size of command in bytes
+    const void *pCmd,           // [in] Command Pointer
+    uint32_t   dwCmdSize)       // [in] Size of command in bytes
 {
     if (pCmdBuffer)
     {
         return ((MOS_STATUS)Mos_AddCommand((PMOS_COMMAND_BUFFER)pCmdBuffer, pCmd, dwCmdSize));
     }
-    else
+    else if (pBatchBuffer)
     {
         return (Mhw_AddCommandBB((PMHW_BATCH_BUFFER)pBatchBuffer, pCmd, dwCmdSize));
     }
+    else
+    {
+        MHW_ASSERTMESSAGE("There is no valid command buffer or batch buffer.");
+        return MOS_STATUS_NULL_POINTER;
+    }
 }
 
 #endif // __MHW_UTILITIES_H__
