@@ -31,7 +31,7 @@
 #include "mos_os.h"
 #include "mhw_utilities.h"
 #include "mhw_cp_interface.h"
-
+#include "mhw_mi.h"
 #include <math.h>
 
 #define MHW_FORWARD_GAMMA_SEGMENT_COUNT       1024    //!< Forward Gamma Correction MAX Control Points
@@ -86,6 +86,8 @@
 #define MHW_VEBOX_WATCHDOG_DISABLE_COUNTER                0xFFFFFFFF
 #define MHW_VEBOX_TIMEOUT_MS                              60
 
+typedef MhwMiInterface *PMHW_MI_INTERFACE;
+
 //!
 //! \brief Color Spaces enum
 //!
@@ -169,7 +171,8 @@ typedef struct _MHW_VEBOX_MODE
     uint32_t    ForwardGammaCorrectionEnable        : 1;  // Gen9+
     uint32_t    Hdr1DLutEnable                      : 1;
     uint32_t    Fp16ModeEnable                      : 1;
-    uint32_t                                        : 8; // Reserved
+    uint32_t    Hdr1K1DLut                          : 1;
+    uint32_t                                        : 7; // Reserved
 } MHW_VEBOX_MODE, *PMHW_VEBOX_MODE;
 
 typedef enum _MHW_VEBOX_ADDRESS_SHIFT
@@ -347,6 +350,7 @@ typedef struct _MHW_COLORPIPE_PARAMS
     bool                bEnableTCC;
     bool                bAceLevelChanged;
     uint32_t            dwAceLevel;
+    uint32_t            dwAceStrength;
     bool                bEnableLACE;
     MHW_STE_PARAMS      SteParams;
     MHW_TCC_PARAMS      TccParams;
@@ -682,6 +686,8 @@ typedef struct _MHW_VEBOX_DI_IECP_CMD_PARAMS
 {
     uint32_t                            dwEndingX;
     uint32_t                            dwStartingX;
+    uint32_t                            dwEndingY;
+    uint32_t                            dwStartingY;
     uint32_t                            dwCurrInputSurfOffset;
     uint32_t                            dwPrevInputSurfOffset;
     uint32_t                            dwCurrOutputSurfOffset;
@@ -723,6 +729,7 @@ typedef struct _MHW_VEBOX_SURFACE_PARAMS
     uint32_t                    bActive;
     bool                        bIsCompressed;
     MOS_FORMAT                  Format;              //!<  Surface format
+    MOS_RESOURCE_MMC_MODE       CompressionMode;     //!<  Surface Compression Mode
     uint32_t                    dwCompressionFormat; //!<  Surface Compression Format
     uint32_t                    dwWidth;             //!<  Surface width
     uint32_t                    dwHeight;            //!<  Surface height
@@ -731,6 +738,7 @@ typedef struct _MHW_VEBOX_SURFACE_PARAMS
     uint32_t                    dwStreamID;          //!<  Surface StreamID
     uint32_t                    dwYoffset;           //!<  Surface Yoffset in Vertical
     uint32_t                    dwUYoffset;          //!<  Surface Uoffset in Vertical
+    uint32_t                    dwOffset;            //!<  Surface Offset from Start Point
     MOS_TILE_TYPE               TileType;            //!<  Tile Type
     MOS_TILE_MODE_GMM           TileModeGMM;         //!<  Tile Mode from GMM Definition
     bool                        bGMMTileEnabled;     //!<  GMM defined tile mode flag
@@ -751,6 +759,7 @@ typedef struct _MHW_VEBOX_SURFACE_STATE_CMD_PARAMS
     MHW_VEBOX_SURFACE_PARAMS         SurfDNOutput;
     MHW_VEBOX_SURFACE_PARAMS         SurfSkinScoreOutput;
     bool                             bDIEnable;
+    bool                             b3DlutEnable;
     bool                             bOutputValid;
 } MHW_VEBOX_SURFACE_STATE_CMD_PARAMS, *PMHW_VEBOX_SURFACE_STATE_CMD_PARAMS;
 
@@ -786,8 +795,7 @@ typedef struct _MHW_VEBOX_HEAP
     uint32_t                uiVertexTableOffset;                                // Vertex Table offset
     uint32_t                uiCapturePipeStateOffset;                           // Capture Pipe state offset
     uint32_t                uiGammaCorrectionStateOffset;                       // Gamma Correction state offset
-    uint32_t                ui3DLUTStateOffset;                                 // 3D LUT state offset
-    uint32_t                ui1DLUTStateOffset;                                 // Hdr State offset
+    uint32_t                uiHdrStateOffset;                                   // Hdr State offset
     uint32_t                uiInstanceSize;                                     // Size of single instance of VEBOX states
     uint32_t                uiStateHeapSize;                                    // Total size of VEBOX States heap
     PMHW_VEBOX_HEAP_STATE   pStates;                                            // Array of VEBOX Heap States
@@ -814,8 +822,7 @@ typedef struct
     uint32_t            uiVertexTableSize;                                      // Vertex Table Size
     uint32_t            uiCapturePipeStateSize;                                 // Capture Pipe State Size (Gen8+)
     uint32_t            uiGammaCorrectionStateSize;                             // Gamma Correction State Size (Gen9+)
-    uint32_t            ui3DLUTStateSize;                                       // 3D LUT State Size (Gen10+)
-    uint32_t            ui1DLUTStateSize;                                       // VEBOX Hdr 1DLUT State Size
+    uint32_t            uiHdrStateSize;                                         // HDR State Size
 } MHW_VEBOX_SETTINGS, *PMHW_VEBOX_SETTINGS;
 typedef const MHW_VEBOX_SETTINGS CMHW_VEBOX_SETTINGS, *PCMHW_VEBOX_SETTINGS;
 
@@ -977,6 +984,22 @@ public:
         PMHW_VEBOX_SURFACE_CNTL_PARAMS          pVeboxSurfCntlParams,
         uint32_t                                *pSurfCtrlBits) = 0;
 
+    //!
+    //! \brief    Add Vebox Tiling Convert Control Bits
+    //! \details  Add Vebox Tiling Convert Control Bits
+    //! \param    [in] cmdBuffer
+    //!           Pointers to the HW Cmd buffer
+    //! \param    [in] inSurParams
+    //!           Pointer to input vebox surface params
+    //! \param    [in] outSurParams
+    //!           Pointer to output vebox surface params
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    virtual MOS_STATUS AddVeboxTilingConvert(
+        PMOS_COMMAND_BUFFER cmdBuffer,
+        PMHW_VEBOX_SURFACE_PARAMS        inSurParams,
+        PMHW_VEBOX_SURFACE_PARAMS        outSurParams) = 0;
+
     //!
     //! \brief    Decide Which GPU Node to use for Vebox
     //! \details  Client facing function to create gpu context used by Vebox
@@ -1031,6 +1054,10 @@ public:
         return eStatus;
     }
 
+    virtual MOS_STATUS setVeboxPrologCmd(
+        PMHW_MI_INTERFACE   mhwMiInterface,
+        PMOS_COMMAND_BUFFER cmdBuffer) = 0;
+
 protected:
     MhwVeboxInterface(PMOS_INTERFACE pOsInterface);
 
@@ -1094,7 +1121,7 @@ public:
     //!                                                              --------------------
     //!                                                             | Gamma Correction State |
     //!                                                              ------------------------
-    //!                                                             | 3D LUT State           |
+    //!                                                             | HDR State              |
     //!                                                              ------------------------
     //! \return   MOS_STATUS
     //!
@@ -1135,6 +1162,28 @@ public:
     //!
     MOS_STATUS UpdateVeboxSync();
 
+    //!
+    //! \brief    Set which vebox can be used by HW
+    //! \details  VPHAL set which VEBOX can be use by HW
+    //! \param    [in] dwVeboxIndex
+    //!           set which Vebox can be used by HW
+    //! \param    [in] dwVeboxCount
+    //!           set Vebox Count
+    //! \param    [in] dwUsingSFC
+    //!           set whether using SFC
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    virtual MOS_STATUS SetVeboxIndex(
+        uint32_t dwVeboxIndex,
+        uint32_t dwVeboxCount,
+        uint32_t dwUsingSFC)
+    {
+        MOS_UNUSED(dwVeboxIndex);
+        MOS_UNUSED(dwVeboxCount);
+        MOS_UNUSED(dwUsingSFC);
+        return MOS_STATUS_SUCCESS;
+    }
+
 private:
     //!
     //! \brief    Refresh Vebox Sync
