@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2014-2018, Intel Corporation
+* Copyright (c) 2014-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -37,7 +37,6 @@
 #include "mos_os.h"
 #include "mhw_utilities.h"
 #include "mhw_cp_interface.h"
-#include "mhw_cmd_reader.h"
 
 #define MHW_VDBOX_VC1_BITPLANE_BUFFER_PITCH_SMALL         64
 #define MHW_VDBOX_VC1_BITPLANE_BUFFER_PITCH_LARGE         128
@@ -49,10 +48,9 @@
 #define MHW_VDBOX_HCP_RECON_UV_PLANE_ALIGNMENT            8
 
 #define MHW_VDBOX_PAK_BITSTREAM_OVERFLOW_SIZE             400
+#define MHW_VDBOX_PAK_SLICE_HEADER_OVERFLOW_SIZE          50
 #define MHW_VDBOX_VDENC_DYNAMIC_SLICE_WA_COUNT            1500
 
-#define MHW_VDBOX_NODE_MAX                                2
-
 // Rowstore Cache values
 #define MHW_VDBOX_PICWIDTH_1K                                                 1024
 #define MHW_VDBOX_PICWIDTH_2K                                                 2048
@@ -79,6 +77,9 @@
 #define VP9HVDROWSTORE_BASEADDRESS                                            0
 #define VP9DFROWSTORE_BASEADDRESS_PICWIDTH_LESS_THAN_OR_EQU_TO_2K             32
 #define MHW_CACHELINE_SIZE                                                    64
+#define BYTES_PER_DWORD                                                       4
+#define NUM_PAK_DWS_PER_LCU                                                   5
+#define NUM_DWS_PER_CU                                                        8
 
 #define VP9DFROWSTORE_BASEADDRESS_8BIT_PICWIDTH_LESS_THAN_OR_EQU_TO_4K          384
 #define VP9DATROWSTORE_BASEADDRESS_8BIT_PICWIDTH_LESS_THAN_OR_EQU_TO_4K         64
@@ -101,6 +102,7 @@ typedef enum _MHW_VDBOX_NODE_IND
 {
     MHW_VDBOX_NODE_1           = 0x0,
     MHW_VDBOX_NODE_2           = 0x1,
+    MHW_VDBOX_NODE_MAX
 } MHW_VDBOX_NODE_IND;
 
 typedef struct _MHW_VDBOX_AVC_QM_PARAMS
@@ -162,6 +164,13 @@ typedef enum _MULTI_ENGINE_MODE
     MHW_VDBOX_HCP_MULTI_ENGINE_MODE_MIDDLE        = 3,
 }MHW_VDBOX_HCP_MULTI_ENGINE_MODE;
 
+typedef enum
+{
+    MHW_VDBOX_HCP_RT_FIRST_PHASE    = 0, //!< First phase
+    MHW_VDBOX_HCP_RT_MIDDLE_PHASE   = 1, //!< Middle phase
+    MHW_VDBOX_HCP_RT_LAST_PHASE     = 2  //!< Last phase
+} MHW_HCP_RT_PHASE_INDICATOR;
+
 typedef enum _VDENC_PIPE_NUM_OF_PIPE
 {
     VDENC_PIPE_SINGLE_PIPE          = 0,
@@ -202,21 +211,11 @@ enum ROWSTORE_SCRATCH_BUFFER_CACHE
     BUFFER_TO_INTERNALMEDIASTORAGE = 0x1
 };
 
-//!
-//! \enum     SLICE_THRESHOLD_TABLE_MODE
-//! \brief    Slice thershold table mode, dynamic slice tuning params
-//!
-enum SLICE_THRESHOLD_TABLE_MODE
-{
-    NO_SLICE_THRESHOLD_TABLE = 0,
-    USE_SLICE_THRESHOLD_TABLE_100_PERCENT = 1,
-    USE_SLICE_THRESHOLD_TABLE_90_PERCENT = 2
-};
-
 struct MHW_VDBOX_PIPE_MODE_SELECT_PARAMS
 {
     uint32_t                    Mode = 0;
     bool                        bStreamOutEnabled = false;
+    bool                        bStreamOutEnabledExtEnabled = false;
     bool                        bShortFormatInUse = false;
     bool                        bVC1OddFrameHeight = false;
     bool                        pakFrmLvlStrmoutEnable = false;
@@ -241,6 +240,8 @@ struct MHW_VDBOX_PIPE_MODE_SELECT_PARAMS
     PMHW_BATCH_BUFFER           pBatchBuffer = nullptr;
     uint32_t                    ChromaType = 0;
     MOS_FORMAT                  Format = {};
+    bool                        isIFrame = false;
+    bool                        bIBCEnabled = false;
 
     // HuC specific
     uint32_t                    dwMediaSoftResetCounterValue = 0;
@@ -271,6 +272,7 @@ typedef struct _MHW_VDBOX_SURFACE_PARAMS
     uint32_t                    dwReconSurfHeight;
     MOS_MEMCOMP_STATE           mmcState;
     uint8_t                     mmcSkipMask;
+    uint32_t                    dwCompressionFormat;
 } MHW_VDBOX_SURFACE_PARAMS, *PMHW_VDBOX_SURFACE_PARAMS;
 
 struct MHW_VDBOX_PIPE_BUF_ADDR_PARAMS
@@ -310,6 +312,8 @@ struct MHW_VDBOX_PIPE_BUF_ADDR_PARAMS
     PMOS_RESOURCE               presVdenc4xDsSurface[CODEC_MAX_NUM_REF_FRAME] = {};
     PMOS_RESOURCE               presVdenc8xDsSurface[CODEC_MAX_NUM_REF_FRAME] = {};
 
+    PMOS_RESOURCE               presVdencColocatedMVWriteBuffer = nullptr;                 // For AVC only
+    PMOS_RESOURCE               presVdencColocatedMVReadBuffer    = nullptr;               // For AVC only
     PMOS_RESOURCE               presDeblockingFilterTileRowStoreScratchBuffer = nullptr;   // For HEVC, VP9
     PMOS_RESOURCE               presDeblockingFilterColumnRowStoreScratchBuffer = nullptr; // For HEVC, VP9
     PMOS_RESOURCE               presMetadataLineBuffer = nullptr;                          // For HEVC, VP9
@@ -331,6 +335,7 @@ struct MHW_VDBOX_PIPE_BUF_ADDR_PARAMS
     PMOS_SURFACE                presP010RTSurface = nullptr;                               // For HEVC only
     PMOS_RESOURCE               presFrameStatStreamOutBuffer = nullptr;
     PMOS_RESOURCE               presSseSrcPixelRowStoreBuffer = nullptr;
+    PMOS_RESOURCE               presSegmentMapStreamIn  = nullptr;
     PMOS_RESOURCE               presSegmentMapStreamOut = nullptr;
     PMOS_RESOURCE               presPakCuLevelStreamoutBuffer = nullptr;
     PMHW_VDBOX_SURFACE_PARAMS   pRawSurfParam = nullptr;
@@ -345,7 +350,11 @@ struct MHW_VDBOX_PIPE_BUF_ADDR_PARAMS
     uint32_t                    dwVdencStatsStreamOutOffset = 0;
     bool                        oneOnOneMapping = false;                 // Flag for indicating using 1:1 ref index mapping for vdenc
     bool                        isLowDelayB = true;                      // Flag to indicate if it is LDB
+    bool                        isIFrame    = false;                     // Flag to indicate if it is I frame
+    bool                        isPFrame    = false;                     // Flag to indicate if it is P frame
+    bool                        bIBCEnabled = false;
     uint8_t                     IBCRefIdxMask = 0;
+    PMOS_RESOURCE               presVdencCumulativeCuCountStreamoutSurface = nullptr;
     virtual ~MHW_VDBOX_PIPE_BUF_ADDR_PARAMS() {}
 };
 using PMHW_VDBOX_PIPE_BUF_ADDR_PARAMS = MHW_VDBOX_PIPE_BUF_ADDR_PARAMS * ;
@@ -361,6 +370,7 @@ typedef struct _MHW_VDBOX_IND_OBJ_BASE_ADDR_PARAMS
     uint32_t                    dwMvObjectOffset;
     PMOS_RESOURCE               presPakBaseObjectBuffer;
     uint32_t                    dwPakBaseObjectSize;
+    uint32_t                    dwPakBaseObjectOffset;
     PMOS_RESOURCE               presPakTileSizeStasBuffer;
     uint32_t                    dwPakTileSizeStasBufferSize;
     uint32_t                    dwPakTileSizeRecordOffset;
@@ -403,7 +413,7 @@ struct MHW_VDBOX_AVC_IMG_PARAMS
     uint8_t                                 ucKernelMode = 0;     // normal, performance, quality.
 
     //FEI multiple passes PAK ---max frame size
-    uint8_t                                 ucCurrPass = 0;
+    uint16_t                                currPass = 0;
     uint8_t                                *pDeltaQp = nullptr;
     uint32_t                                dwMaxFrameSize = 0;
 
@@ -415,13 +425,15 @@ struct MHW_VDBOX_AVC_IMG_PARAMS
     bool                                    bVdencBRCEnabled = false;
     bool                                    bSliceSizeStreamOutEnabled = false;
     bool                                    bCrePrefetchEnable = false;
+    bool                                    bPerMBStreamOut = false;
+    bool                                    bRollingIRestrictFracCand = false;
 
     uint32_t                                dwMbSlcThresholdValue = 0;  // For VDENC dynamic slice size control
-    uint32_t                                dwSliceThresholdTable = 0;
     uint32_t                                dwVdencSliceMinusBytes = 0;
     uint8_t                                *pVDEncModeCost = nullptr;
     uint8_t                                *pVDEncMvCost = nullptr;
     uint8_t                                *pVDEncHmeMvCost = nullptr;
+    uint32_t                               biWeight = 0;
     virtual ~MHW_VDBOX_AVC_IMG_PARAMS(){}
 };
 using PMHW_VDBOX_AVC_IMG_PARAMS = MHW_VDBOX_AVC_IMG_PARAMS * ;
@@ -514,8 +526,67 @@ struct MHW_VDBOX_STATE_CMDSIZE_PARAMS
     bool       bShortFormat = false;
     bool       bHucDummyStream = false;
     bool       bSfcInUse = false;
+    uint32_t   uNumStoreDataImm = 0;
+    uint32_t   uNumStoreReg = 0;
+    uint32_t   uNumMfxWait = 0;
+    uint32_t   uNumAddConBBEnd = 0;
+    uint32_t   uNumMiCopy = 0;
+    uint32_t   uNumMiFlush = 0;
+    uint32_t   bPerformHucStreamOut = false;
+    uint32_t   uNumVdPipelineFlush = 0;
     virtual ~MHW_VDBOX_STATE_CMDSIZE_PARAMS() {}
 };
 using PMHW_VDBOX_STATE_CMDSIZE_PARAMS = MHW_VDBOX_STATE_CMDSIZE_PARAMS * ;
 
+typedef struct _MHW_VDBOX_AVC_SLICE_STATE
+{
+    PCODEC_PIC_ID                           pAvcPicIdx;
+    PMOS_RESOURCE                           presDataBuffer;
+    uint32_t                                dwDataBufferOffset;
+    uint32_t                                dwOffset;
+    uint32_t                                dwLength;
+    uint32_t                                dwSliceIndex;
+    bool                                    bLastSlice;
+    uint32_t                                dwTotalBytesConsumed;
+
+    // Decoding Only
+    PCODEC_AVC_PIC_PARAMS                   pAvcPicParams;
+    PCODEC_MVC_EXT_PIC_PARAMS               pMvcExtPicParams;
+    PCODEC_AVC_SLICE_PARAMS                 pAvcSliceParams;
+    uint32_t                                dwNextOffset;
+    uint32_t                                dwNextLength;
+    bool                                    bIntelEntrypointInUse;
+    bool                                    bPicIdRemappingInUse;
+    bool                                    bShortFormatInUse;
+    bool                                    bPhantomSlice;
+    uint8_t                                 ucDisableDeblockingFilterIdc;
+    uint8_t                                 ucSliceBetaOffsetDiv2;
+    uint8_t                                 ucSliceAlphaC0OffsetDiv2;
+
+    // Encoding Only
+    PCODEC_AVC_ENCODE_SEQUENCE_PARAMS       pEncodeAvcSeqParams;
+    PCODEC_AVC_ENCODE_PIC_PARAMS            pEncodeAvcPicParams;
+    PCODEC_AVC_ENCODE_SLICE_PARAMS          pEncodeAvcSliceParams;
+    PBSBuffer                               pBsBuffer;
+    PCODECHAL_NAL_UNIT_PARAMS              *ppNalUnitParams;
+    PMHW_BATCH_BUFFER                       pBatchBufferForPakSlices;
+    bool                                    bSingleTaskPhaseSupported;
+    bool                                    bFirstPass;
+    bool                                    bLastPass;
+    bool                                    bBrcEnabled;
+    bool                                    bRCPanicEnable;
+    bool                                    bInsertBeforeSliceHeaders;
+    bool                                    bAcceleratorHeaderPackingCaps;
+    uint32_t                                dwBatchBufferForPakSlicesStartOffset;
+    uint32_t                                uiSkipEmulationCheckCount;
+    uint32_t                                dwRoundingValue;
+    uint32_t                                dwRoundingIntraValue;
+    bool                                    bRoundingInterEnable;
+    uint16_t                                wFrameFieldHeightInMB;  // Frame/field Height in MB
+    bool                                    bVdencInUse;
+    bool                                    bVdencNoTailInsertion;
+    bool                                    oneOnOneMapping = false;
+    bool                                    bFullFrameData;
+} MHW_VDBOX_AVC_SLICE_STATE, *PMHW_VDBOX_AVC_SLICE_STATE;
+
 #endif
