@@ -34,8 +34,6 @@
 #include "mos_util_user_interface.h"
 #include "mos_interface.h"
 
-uint32_t g_apoMosEnabled = 0;
-
 PerfUtility* g_perfutility = PerfUtility::getInstance();
 
 AutoPerfUtility::AutoPerfUtility(std::string tag, std::string comp, std::string level)
@@ -77,45 +75,7 @@ MOS_STATUS Mos_AddCommand(
     const void              *pCmd,
     uint32_t                dwCmdSize)
 {
-    uint32_t dwCmdSizeDwAligned = 0;
-
-    if (g_apoMosEnabled)
-    {
-        return MosInterface::AddCommand(pCmdBuffer, pCmd, dwCmdSize);
-    }
-
-    //---------------------------------------------
-    MOS_OS_CHK_NULL_RETURN(pCmdBuffer);
-    MOS_OS_CHK_NULL_RETURN(pCmd);
-    //---------------------------------------------
-
-    if (dwCmdSize == 0)
-    {
-        MOS_OS_ASSERTMESSAGE("Incorrect command size to add to command buffer.");
-        return MOS_STATUS_INVALID_PARAMETER;
-    }
-
-    dwCmdSizeDwAligned = MOS_ALIGN_CEIL(dwCmdSize, sizeof(uint32_t));
-
-    pCmdBuffer->iOffset    += dwCmdSizeDwAligned;
-    pCmdBuffer->iRemaining -= dwCmdSizeDwAligned;
-
-    if (pCmdBuffer->iRemaining < 0)
-    {
-        pCmdBuffer->iOffset    -= dwCmdSizeDwAligned;
-        pCmdBuffer->iRemaining += dwCmdSizeDwAligned;
-        MOS_OS_ASSERTMESSAGE("Unable to add command: remaining space = %d, command size = %d.",
-                            pCmdBuffer->iRemaining, dwCmdSizeDwAligned);
-        return MOS_STATUS_UNKNOWN;
-    }
-
-    MOS_OS_VERBOSEMESSAGE("The command was successfully added: remaining space = %d, buffer size = %d.",
-                        pCmdBuffer->iRemaining, pCmdBuffer->iOffset + pCmdBuffer->iRemaining);
-
-    MOS_SecureMemcpy(pCmdBuffer->pCmdPtr, dwCmdSize, pCmd, dwCmdSize);
-    pCmdBuffer->pCmdPtr += (dwCmdSizeDwAligned / sizeof(uint32_t));
-
-    return MOS_STATUS_SUCCESS;
+    return MosInterface::AddCommand(pCmdBuffer, pCmd, dwCmdSize);
 }
 
 //!
@@ -308,6 +268,7 @@ MOS_STATUS Mos_OsGetBitsPerPixel(
     case Format_Buffer:
     case Format_RAW:
     case Format_R8U:
+    case Format_R8UN:
        *piBpp = 8;
         break;
 
@@ -404,7 +365,7 @@ MOS_STATUS Mos_DumpCommandBuffer(
     MOS_OS_CHK_NULL_RETURN(pOsInterface);
     MOS_OS_CHK_NULL_RETURN(pCmdBuffer);
 
-    if (g_apoMosEnabled)
+    if (pOsInterface->apoMosEnabled)
     {
         return MosInterface::DumpCommandBuffer(pOsInterface->osStreamState, pCmdBuffer);
     }
@@ -425,8 +386,8 @@ MOS_STATUS Mos_DumpCommandBuffer(
         case MOS_GPU_CONTEXT_VIDEO7:
             MOS_SecureStrcpy(sEngName, sizeof(sEngName), MOS_COMMAND_BUFFER_VIDEO_ENGINE);
             break;
-        case MOS_GPU_CONTEXT_RTE:
-            MOS_SecureStrcpy(sEngName, sizeof(sEngName), MOS_COMMAND_BUFFER_RTE_ENGINE);
+        case MOS_GPU_CONTEXT_TEE:
+            MOS_SecureStrcpy(sEngName, sizeof(sEngName), MOS_COMMAND_BUFFER_TEE_ENGINE);
             break;
         case MOS_GPU_CONTEXT_RENDER:
         case MOS_GPU_CONTEXT_RENDER2:
@@ -562,7 +523,8 @@ MOS_STATUS Mos_DumpCommandBufferInit(
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_BUFFER_ENABLE_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        pOsInterface->pOsContext);
     pOsInterface->bDumpCommandBuffer = (UserFeatureData.i32Data != 0);
     pOsInterface->bDumpCommandBufferToFile = ((UserFeatureData.i32Data & 1) != 0);
     pOsInterface->bDumpCommandBufferAsMessages = ((UserFeatureData.i32Data & 2) != 0);
@@ -570,7 +532,7 @@ MOS_STATUS Mos_DumpCommandBufferInit(
     if (pOsInterface->bDumpCommandBufferToFile)
     {
         // Create output directory.
-        eStatus = MOS_LogFileNamePrefix(pOsInterface->sDirName);
+        eStatus = MOS_LogFileNamePrefix(pOsInterface->sDirName, pOsInterface->pOsContext);
         if (eStatus != MOS_STATUS_SUCCESS)
         {
             MOS_OS_NORMALMESSAGE("Failed to create log file prefix. Status = %d", eStatus);
@@ -607,23 +569,24 @@ finish:
 
 std::shared_ptr<GpuCmdResInfoDump> GpuCmdResInfoDump::m_instance = nullptr;
 
-const GpuCmdResInfoDump *GpuCmdResInfoDump::GetInstance()
+const GpuCmdResInfoDump *GpuCmdResInfoDump::GetInstance(PMOS_CONTEXT mosCtx)
 {
     if (m_instance == nullptr)
     {
-        m_instance = std::make_shared<GpuCmdResInfoDump>();
+        m_instance = std::make_shared<GpuCmdResInfoDump>(mosCtx);
     }
     return m_instance.get();
 }
 
-GpuCmdResInfoDump::GpuCmdResInfoDump()
+GpuCmdResInfoDump::GpuCmdResInfoDump(PMOS_CONTEXT mosCtx)
 {
     MOS_USER_FEATURE_VALUE_DATA userFeatureData;
     MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_INFO_ENABLE_ID,
-        &userFeatureData);
+        &userFeatureData,
+        mosCtx);
     m_dumpEnabled = userFeatureData.bData;
 
     if (!m_dumpEnabled)
@@ -638,7 +601,8 @@ GpuCmdResInfoDump::GpuCmdResInfoDump()
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_INFO_PATH_ID,
-        &userFeatureData);
+        &userFeatureData,
+        mosCtx);
     if (userFeatureData.StringData.uSize > MOS_MAX_PATH_LENGTH)
     {
         userFeatureData.StringData.uSize = 0;
@@ -777,17 +741,16 @@ MOS_STATUS Mos_InitInterface(
     MOS_UserFeature_WriteValues_ID(
         nullptr,
         &UserFeatureWriteData,
-        1);
+        1,
+        pOsInterface->pOsContext);
 
     // Apo wrapper
-    if (g_apoMosEnabled)
+    if (pOsInterface->apoMosEnabled && !pOsInterface->streamStateIniter)
     {
         pOsInterface->osStreamState->component                = pOsInterface->Component;
         pOsInterface->osStreamState->currentGpuContextHandle  = pOsInterface->CurrentGpuContextHandle;
-        pOsInterface->osStreamState->GpuResetCount            = pOsInterface->dwGPUResetCount;
         pOsInterface->osStreamState->mediaReset               = pOsInterface->bMediaReset;
         pOsInterface->osStreamState->nullHwAccelerationEnable = pOsInterface->NullHWAccelerationEnable;
-        pOsInterface->osStreamState->osCpInterface            = pOsInterface->osCpInterface;
         pOsInterface->osStreamState->osDeviceContext          = (OsDeviceContext *)pOsInterface->pOsContext->m_osDeviceContext;
         pOsInterface->osStreamState->simIsActive              = pOsInterface->bSimIsActive;
         pOsInterface->osStreamState->virtualEngineInterface   = nullptr; // Will be updated by HAL on demand
@@ -804,9 +767,15 @@ MOS_STATUS Mos_InitInterface(
 #endif  // _DEBUG || _RELEASE_INTERNAL
 
         pOsInterface->osStreamState->ctxBasedScheduling       = pOsInterface->ctxBasedScheduling;
+        pOsInterface->osStreamState->multiNodeScaling         = pOsInterface->multiNodeScaling;
         pOsInterface->osStreamState->perStreamParameters      = pOsInterface->pOsContext;
     }
 
+    if (pOsInterface->apoMosEnabled)
+    {
+        pOsInterface->osStreamState->osCpInterface = pOsInterface->osCpInterface;
+    }
+
     return eStatus;
 }
 
@@ -966,6 +935,9 @@ MEMORY_OBJECT_CONTROL_STATE Mos_CachePolicyGetMemoryObject(
         MHW_RESOURCE_USAGE_Sfc_AvsLineBufferSurface,                                //!< SFC AVS Line buffer Surface
         MHW_RESOURCE_USAGE_Sfc_IefLineBufferSurface,                                //!< SFC IEF Line buffer Surface
 
+        // Camera capture
+        GMM_RESOURCE_USAGE_CAMERA_CAPTURE,
+
     };
 
     MOS_OS_ASSERT(pGmmClientContext);
@@ -1006,7 +978,8 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
         eStatus = MOS_UserFeature_ReadValue_ID(
             nullptr,
             __MEDIA_USER_FEATURE_VALUE_ENABLE_DECODE_VIRTUAL_ENGINE_ID,
-            &userFeatureData);
+            &userFeatureData,
+            osInterface->pOsContext);
         osInterface->bSupportVirtualEngine = userFeatureData.u32Data ? true : false;
 
         // force bSupportVirtualEngine to false when virtual engine not enabled by default
@@ -1038,7 +1011,7 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
         MOS_USER_FEATURE_VALUE_WRITE_DATA  userFeatureWriteData = __NULL_USER_FEATURE_VALUE_WRITE_DATA__;
         userFeatureWriteData.Value.i32Data = osInterface->ctxBasedScheduling ? true : false;
         userFeatureWriteData.ValueID = __MEDIA_USER_FEATURE_VALUE_ENABLE_DECODE_VE_CTXSCHEDULING_ID;
-        MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
+        MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1, osInterface->pOsContext);
 #endif
     }
     else
@@ -1048,7 +1021,8 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
         eStatus = MOS_UserFeature_ReadValue_ID(
             nullptr,
             __MEDIA_USER_FEATURE_VALUE_ENABLE_ENCODE_VIRTUAL_ENGINE_ID,
-            &userFeatureData);
+            &userFeatureData,
+            osInterface->pOsContext);
         osInterface->bSupportVirtualEngine = userFeatureData.u32Data ? true : false;
 
         // force bSupportVirtualEngine to false when virtual engine not enabled by default
@@ -1070,11 +1044,12 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
         osInterface->multiNodeScaling = osInterface->ctxBasedScheduling && MEDIA_IS_SKU(skuTable, FtrVcs2) ? true : false;
     }
 
-    if (g_apoMosEnabled)
+    if (osInterface->apoMosEnabled)
     {
         // Update ctx based scheduling flag also in APO MOS stream state
         MOS_OS_CHK_NULL_RETURN(osInterface->osStreamState);
         osInterface->osStreamState->ctxBasedScheduling = osInterface->ctxBasedScheduling;
+        osInterface->osStreamState->multiNodeScaling   = osInterface->multiNodeScaling;
     }
     MOS_OS_VERBOSEMESSAGE("Virtual Engine Context based SCheduling enabled:%d.\n", osInterface->ctxBasedScheduling);
     MOS_OS_VERBOSEMESSAGE("Virtual Engine Multi-node Scaling enabled:%d.\n", osInterface->multiNodeScaling);
