@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2019, Intel Corporation
+* Copyright (c) 2009-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -36,6 +36,7 @@
 
 #include "mos_os.h"
 #include "vphal_common_hdr.h"
+#include "media_common_defs.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -211,6 +212,11 @@ extern "C" {
 #define VPHAL_MAX_TARGETS               8        //!< multi output support
 #define VPHAL_MAX_FUTURE_FRAMES         18       //!< maximum future frames supported in VPHAL
 
+#define VPHAL_TOP_FIELD           0
+#define VPHAL_BOTTOM_FIELD        1
+#define VPHAL_TOP_FIELD_FIRST     0
+#define VPHAL_BOTTOM_FIELD_FIRST  1
+
 typedef struct _VPHAL_COMPOSITE_CACHE_CNTL
 {
     bool                           bL3CachingEnabled;
@@ -266,6 +272,15 @@ typedef struct _VPHAL_FAST1TON_CACHE_CNTL
     VPHAL_MEMORY_OBJECT_CONTROL    SamplerParamsStatsSurfMemObjCtl;
 }VPHAL_FAST1TON_CACHE_CNTL, *PVPHAL_FAST1TON_CACHE_CNTL;
 
+typedef struct _VPHAL_HDR_CACHE_CNTL
+{
+    bool                           bL3CachingEnabled;
+    VPHAL_MEMORY_OBJECT_CONTROL    SourceSurfMemObjCtl;
+    VPHAL_MEMORY_OBJECT_CONTROL    TargetSurfMemObjCtl;
+    VPHAL_MEMORY_OBJECT_CONTROL    Lut2DSurfMemObjCtl;
+    VPHAL_MEMORY_OBJECT_CONTROL    Lut3DSurfMemObjCtl;
+    VPHAL_MEMORY_OBJECT_CONTROL    CoeffSurfMemObjCtl;
+} VPHAL_HDR_CACHE_CNTL, *PVPHAL_HDR_CACHE_CNTL;
 
 //!
 //! \brief  Feature specific cache control settings
@@ -288,14 +303,14 @@ typedef struct _VPHAL_RENDER_CACHE_CNTL
 //!
 typedef enum _VPHAL_ROTATION
 {
-    VPHAL_ROTATION_IDENTITY               = 0,   //!< Rotation 0 degrees
-    VPHAL_ROTATION_90                        ,   //!< Rotation 90 degrees
-    VPHAL_ROTATION_180                       ,   //!< Rotation 180 degrees
-    VPHAL_ROTATION_270                       ,   //!< Rotation 270 degrees
-    VPHAL_MIRROR_HORIZONTAL                  ,   //!< Horizontal Mirror
-    VPHAL_MIRROR_VERTICAL                    ,   //!< Vertical Mirror
-    VPHAL_ROTATE_90_MIRROR_VERTICAL          ,   //!< 90 + V Mirror
-    VPHAL_ROTATE_90_MIRROR_HORIZONTAL            //!< 90 + H Mirror
+    VPHAL_ROTATION_IDENTITY             = ROTATION_IDENTITY             ,   //!< Rotation 0 degrees
+    VPHAL_ROTATION_90                   = ROTATION_90                   ,   //!< Rotation 90 degrees
+    VPHAL_ROTATION_180                  = ROTATION_180                  ,   //!< Rotation 180 degrees
+    VPHAL_ROTATION_270                  = ROTATION_270                  ,   //!< Rotation 270 degrees
+    VPHAL_MIRROR_HORIZONTAL             = ROTATION_MIRROR_HORIZONTAL    ,   //!< Horizontal Mirror
+    VPHAL_MIRROR_VERTICAL               = ROTATION_MIRROR_VERTICAL      ,   //!< Vertical Mirror
+    VPHAL_ROTATE_90_MIRROR_VERTICAL     = ROTATION_90_MIRROR_VERTICAL   ,   //!< 90 + V Mirror
+    VPHAL_ROTATE_90_MIRROR_HORIZONTAL   = ROTATION_90_MIRROR_HORIZONTAL     //!< 90 + H Mirror
 } VPHAL_ROTATION;
 
 //!
@@ -373,35 +388,7 @@ C_ASSERT(SURF_TYPE_COUNT == 6);     //!< When adding, update assert & vphal_solo
 //!
 //! \brief Color Spaces enum
 //!
-typedef enum _VPHAL_CSPACE
-{
-    CSpace_None     = -5        ,   //!< Unidentified
-    CSpace_Source   = -4        ,   //!< Current source Color Space
-
-    // Groups of Color Spaces
-    CSpace_RGB      = -3        ,   //!< sRGB
-    CSpace_YUV      = -2        ,   //!< YUV BT601 or BT709 - non xvYCC
-    CSpace_Gray     = -1        ,   //!< Gray scale image with only Y component
-    CSpace_Any      =  0        ,   //!< Any
-
-    // Specific Color Spaces
-    CSpace_sRGB                 ,   //!< RGB - sRGB       -   RGB[0,255]
-    CSpace_stRGB                ,   //!< RGB - stRGB      -   RGB[16,235]
-    CSpace_BT601                ,   //!< YUV BT.601 Y[16,235] UV[16,240]
-    CSpace_BT601_FullRange      ,   //!< YUV BT.601 Y[0,255]  UV[-128,+127]
-    CSpace_BT709                ,   //!< YUV BT.709 Y[16,235] UV[16,240]
-    CSpace_BT709_FullRange      ,   //!< YUV BT.709 Y[0,255]  UV[-128,+127]
-    CSpace_xvYCC601             ,   //!< xvYCC 601 Y[16,235]  UV[16,240]
-    CSpace_xvYCC709             ,   //!< xvYCC 709 Y[16,235]  UV[16,240]
-    CSpace_BT601Gray            ,   //!< BT.601 Y[16,235]
-    CSpace_BT601Gray_FullRange  ,   //!< BT.601 Y[0,255]
-    CSpace_BT2020               ,   //!< BT.2020 YUV Limited Range 10bit Y[64, 940] UV[64, 960]
-    CSpace_BT2020_FullRange     ,   //!< BT.2020 YUV Full Range 10bit [0, 1023]
-    CSpace_BT2020_RGB           ,   //!< BT.2020 RGB Full Range 10bit [0, 1023]
-    CSpace_BT2020_stRGB         ,   //!< BT.2020 RGB Studio Range 10bit [64, 940]
-    CSpace_Count                    //!< Keep this at the end
-} VPHAL_CSPACE;
-C_ASSERT(CSpace_Count == 15);       //!< When adding, update assert & vphal_solo_scenario.cpp
+typedef MEDIA_CSPACE VPHAL_CSPACE;
 
 //!
 //! Structure VPHAL_GAMMA_TYPE
@@ -487,6 +474,29 @@ typedef enum _VPHAL_SAMPLE_TYPE
 } VPHAL_SAMPLE_TYPE;
 C_ASSERT(SAMPLE_INVALID == 7);      //!< When adding, update assert & vphal_solo_scenario.cpp
 
+//!
+//! \brief Frame Format enum
+//!
+typedef enum _VPHAL_FRAME_FORMAT
+{
+    FRAME_FORMAT_PROGRESSIVE,
+    FRAME_FORMAT_INTERLEAVED,
+    FRAME_FORMAT_FIELD
+} VPHAL_FRAME_FORMAT;
+
+//!
+//! \brief Interlaced Scaling Mode enum
+//!
+typedef enum _VPHAL_ISCALING_TYPE
+{
+    ISCALING_NONE,
+    ISCALING_INTERLEAVED_TO_INTERLEAVED,
+    ISCALING_INTERLEAVED_TO_FIELD,
+    ISCALING_FIELD_TO_INTERLEAVED,
+    ISCALING_FIELD_TO_FIELD
+} VPHAL_ISCALING_TYPE;
+C_ASSERT(ISCALING_FIELD_TO_FIELD == 4);
+
 //!
 //! \brief DI Mode enum
 //!
@@ -507,7 +517,8 @@ typedef enum _VPHAL_BLEND_TYPE
     BLEND_PARTIAL,
     BLEND_CONSTANT,
     BLEND_CONSTANT_SOURCE,
-    BLEND_CONSTANT_PARTIAL
+    BLEND_CONSTANT_PARTIAL,
+    BLEND_XOR_MONO
 } VPHAL_BLEND_TYPE;
 C_ASSERT(BLEND_CONSTANT == 3);      //!< When adding, update assert & vphal_solo_scenario.cpp
 
@@ -516,11 +527,12 @@ C_ASSERT(BLEND_CONSTANT == 3);      //!< When adding, update assert & vphal_solo
 //!
 typedef enum _VPHAL_SCALING_MODE
 {
-    VPHAL_SCALING_NEAREST,
+    VPHAL_SCALING_NEAREST = 0,
     VPHAL_SCALING_BILINEAR,
-    VPHAL_SCALING_AVS
+    VPHAL_SCALING_AVS,
+    VPHAL_SCALING_ADV_QUALITY        // !< Advance Perf mode
 } VPHAL_SCALING_MODE;
-C_ASSERT(VPHAL_SCALING_AVS == 2);   //!< When adding, update assert & vphal_solo_scenario.cpp
+C_ASSERT(VPHAL_SCALING_ADV_QUALITY == 3);   //!< When adding, update assert & vphal_solo_scenario.cpp
 
 typedef enum _VPHAL_SCALING_PREFERENCE
 {
@@ -567,7 +579,9 @@ typedef enum _VPHAL_DI_REPORT_MODE
 //!
 typedef enum _VPHAL_COLORPACK
 {
-    VPHAL_COLORPACK_420 = 0,
+    VPHAL_COLORPACK_400 = 0,
+    VPHAL_COLORPACK_420,
+    VPHAL_COLORPACK_411,
     VPHAL_COLORPACK_422,
     VPHAL_COLORPACK_444,
     VPHAL_COLORPACK_UNKNOWN
@@ -589,7 +603,11 @@ typedef enum _VPHAL_OUTPUT_PIPE_MODE
 //! \def SET_VPHAL_OUTPUT_PIPE(_a, _Pipe)
 //! Set the output pipe
 //!
-#define SET_VPHAL_OUTPUT_PIPE(_a, _Pipe)              (_a->OutputPipe =  _Pipe)
+#define SET_VPHAL_OUTPUT_PIPE(_a, _Pipe)                           \
+    {                                                              \
+        (_a->OutputPipe = _Pipe);                                  \
+        VPHAL_RENDER_NORMALMESSAGE("VPHAL_OUTPUT_PIPE %d", _Pipe); \
+    }
 
 //!
 //! \def IS_VPHAL_OUTPUT_PIPE_INVALID(_a)
@@ -844,19 +862,31 @@ typedef struct _VPHAL_HVSDENOISE_PARAMS
     uint32_t            dwDenoiseParamSize;
 } VPHAL_HVSDENOISE_PARAMS, *PVPHAL_HVSDENOISE_PARAMS;
 
+//!
+//! Structure VPHAL_SLIMIPU_DENOISE_PARAM
+//! \brief SLIMIPU Denoise Parameters
+//!
+typedef struct _VPHAL_SLIMIPU_DENOISE_PARAM
+{
+    uint32_t            MemSizeInBytes;
+    void *              pSystemMem;
+} VPHAL_SLIMIPU_DENOISE_PARAM, *PVPHAL_SLIMIPU_DENOISE_PARAM;
+
 //!
 //! Structure VPHAL_DENOISE_PARAMS
 //! \brief Denoise parameters
 //!
 typedef struct _VPHAL_DENOISE_PARAMS
 {
-    bool                            bEnableChroma;
-    bool                            bEnableLuma;
-    bool                            bAutoDetect;
-    float                           fDenoiseFactor;
-    VPHAL_NOISELEVEL                NoiseLevel;
-    bool                            bEnableHVSDenoise;
-    VPHAL_HVSDENOISE_PARAMS         HVSDenoise;
+    bool                                bEnableChroma;
+    bool                                bEnableLuma;
+    bool                                bAutoDetect;
+    float                               fDenoiseFactor;
+    VPHAL_NOISELEVEL                    NoiseLevel;
+    bool                                bEnableHVSDenoise;
+    VPHAL_HVSDENOISE_PARAMS             HVSDenoise;
+    bool                                bEnableSlimIPUDenoise;
+    VPHAL_SLIMIPU_DENOISE_PARAM         SlimIPUDenoise;
 } VPHAL_DENOISE_PARAMS, *PVPHAL_DENOISE_PARAMS;
 
 //!
@@ -906,91 +936,100 @@ typedef struct VPHAL_SURFACE           *PVPHAL_SURFACE;
 struct VPHAL_SURFACE
 {
     // Color Information
-    VPHAL_CSPACE                ColorSpace;         //!<Color Space
-    bool                        ExtendedGamut;      //!<Extended Gamut Flag
-    int32_t                     iPalette;           //!<Palette Allocation
-    VPHAL_PALETTE               Palette;            //!<Palette data
+    VPHAL_CSPACE                ColorSpace = CSpace_None;         //!<Color Space
+    bool                        ExtendedGamut = false;            //!<Extended Gamut Flag
+    int32_t                     iPalette = 0;                     //!<Palette Allocation
+    VPHAL_PALETTE               Palette = {};                     //!<Palette data
 
     // Rendering parameters
-    RECT                        rcSrc;              //!< Source rectangle
-    RECT                        rcDst;              //!< Destination rectangle
-    RECT                        rcMaxSrc;           //!< Max source rectangle
-    PVPHAL_BLENDING_PARAMS      pBlendingParams;    //!< Blending parameters
-    PVPHAL_LUMAKEY_PARAMS       pLumaKeyParams;     //!< Luma keying parameters
-    PVPHAL_PROCAMP_PARAMS       pProcampParams;     //!< Procamp parameters
-    PVPHAL_IEF_PARAMS           pIEFParams;         //!< IEF parameters
-    bool                        bCalculatingAlpha;  //!< Alpha calculation parameters
-    bool                        bInterlacedScaling; //!< Interlaced scaling
-    bool                        bFieldWeaving;      //!< Field Weaving
-    bool                        bQueryVariance;     //!< enable variance query
-    bool                        bDirectionalScalar; //!< Vebox Directional Scalar
-    bool                        bFastColorFill;     //!< enable fast color fill without copy surface
-    bool                        bMaxRectChanged;    //!< indicate rcMaxSrc been updated
+    RECT                        rcSrc = { 0, 0, 0, 0 };           //!< Source rectangle
+    RECT                        rcDst = { 0, 0, 0, 0 };           //!< Destination rectangle
+    RECT                        rcMaxSrc = { 0, 0, 0, 0 };        //!< Max source rectangle
+    PVPHAL_BLENDING_PARAMS      pBlendingParams = nullptr;        //!< Blending parameters
+    PVPHAL_LUMAKEY_PARAMS       pLumaKeyParams = nullptr;         //!< Luma keying parameters
+    PVPHAL_PROCAMP_PARAMS       pProcampParams  = nullptr;;       //!< Procamp parameters
+    PVPHAL_IEF_PARAMS           pIEFParams = nullptr;             //!< IEF parameters
+    bool                        bCalculatingAlpha = false;        //!< Alpha calculation parameters
+    bool                        bQueryVariance = false;           //!< enable variance query
+    bool                        bDirectionalScalar = false;       //!< Vebox Directional Scalar
+    bool                        bFastColorFill = false;           //!< enable fast color fill without copy surface
+    bool                        bMaxRectChanged = false;          //!< indicate rcMaxSrc been updated
+    bool                        b16UsrPtr = false;                //!< is 16 byte aligned system linear memory.
+    bool                        bVEBOXCroppingUsed = false;       //!< Vebox crop case need use rcSrc as vebox input.
+    bool                        bXORComp = false;                 //!< is mono-chroma composite mode.
+
+    // Interlaced Scaling
+    bool                        bInterlacedScaling = false;            //!< Interlaced scaling
+    bool                        bFieldWeaving = false;                 //!< Field Weaving
+    VPHAL_ISCALING_TYPE         InterlacedScalingType = ISCALING_NONE; //!< Interlaced scaling type for new interlaced scaling mode
 
     // Advanced Processing
-    PVPHAL_DI_PARAMS            pDeinterlaceParams;
-    PVPHAL_DENOISE_PARAMS       pDenoiseParams;     //!< Denoise
-    PVPHAL_COLORPIPE_PARAMS     pColorPipeParams;   //!< ColorPipe
+    PVPHAL_DI_PARAMS            pDeinterlaceParams = nullptr;
+    PVPHAL_DENOISE_PARAMS       pDenoiseParams = nullptr;     //!< Denoise
+    PVPHAL_COLORPIPE_PARAMS     pColorPipeParams = nullptr;   //!< ColorPipe
 
     // Frame ID and reference samples -> for advanced processing
-    int32_t                     FrameID;
-    uint32_t                    uFwdRefCount;
-    uint32_t                    uBwdRefCount;
-    PVPHAL_SURFACE              pFwdRef;
-    PVPHAL_SURFACE              pBwdRef;
+    int32_t                     FrameID = 0;
+    uint32_t                    uFwdRefCount = 0;
+    uint32_t                    uBwdRefCount = 0;
+    PVPHAL_SURFACE              pFwdRef = nullptr;
+    PVPHAL_SURFACE              pBwdRef = nullptr;
 
     // VPHAL_SURFACE Linked list
-    PVPHAL_SURFACE              pNext;
+    PVPHAL_SURFACE              pNext = nullptr;
 
     //--------------------------------------
     // FIELDS TO BE SETUP BY VPHAL int32_tERNALLY
     //--------------------------------------
-    uint32_t                    dwWidth;            //!<  Surface width
-    uint32_t                    dwHeight;           //!<  Surface height
-    uint32_t                    dwPitch;            //!<  Surface pitch
-    MOS_TILE_TYPE               TileType;           //!<  Tile Type
-    bool                        bOverlay;           //!<  Overlay Surface
-    bool                        bFlipChain;         //!<  FlipChain Surface
-    VPHAL_PLANE_OFFSET          YPlaneOffset;       //!<  Y surface plane offset
-    VPHAL_PLANE_OFFSET          UPlaneOffset;       //!<  U surface plane offset
-    VPHAL_PLANE_OFFSET          VPlaneOffset;       //!<  V surface plane offset
-    int32_t                     iLayerID;           //!<  Layer index (0-based index)
-    VPHAL_SCALING_MODE          ScalingMode;        //!<  Scaling Mode
-    VPHAL_SCALING_PREFERENCE    ScalingPreference;  //!<  Scaling preference
-    bool                        bIEF;               //!<  IEF flag
-    uint32_t                    dwSlicePitch;       //!<  SlicePitch of a 3D surface(GT-PIN support)
+    uint32_t                    dwWidth = 0;                                  //!<  Surface width
+    uint32_t                    dwHeight = 0;                                 //!<  Surface height
+    uint32_t                    dwPitch = 0;                                  //!<  Surface pitch
+    MOS_TILE_TYPE               TileType = MOS_TILE_X;                        //!<  Tile Type
+    MOS_TILE_MODE_GMM           TileModeGMM = MOS_TILE_LINEAR_GMM;            //!<  Tile Mode from GMM Definition
+    bool                        bGMMTileEnabled = false;                      //!<  GMM Tile Mode Flag
+    bool                        bOverlay= false;                              //!<  Overlay Surface
+    bool                        bFlipChain = false;                           //!<  FlipChain Surface
+    VPHAL_PLANE_OFFSET          YPlaneOffset =  { 0, 0, 0, 0 };               //!<  Y surface plane offset
+    VPHAL_PLANE_OFFSET          UPlaneOffset =  { 0, 0, 0, 0 };               //!<  U surface plane offset
+    VPHAL_PLANE_OFFSET          VPlaneOffset =  { 0, 0, 0, 0 };               //!<  V surface plane offset
+    int32_t                     iLayerID = 0;                                 //!<  Layer index (0-based index)
+    VPHAL_SCALING_MODE          ScalingMode = VPHAL_SCALING_NEAREST;          //!<  Scaling Mode
+    VPHAL_SCALING_PREFERENCE    ScalingPreference = VPHAL_SCALING_PREFER_SFC; //!<  Scaling preference
+    bool                        bIEF = false;                                 //!<  IEF flag
+    uint32_t                    dwSlicePitch = 0;                             //!<  SlicePitch of a 3D surface(GT-PIN support)
 
     //--------------------------------------
     // FIELDS TO BE PROVIDED BY DDI
     //--------------------------------------
     // Sample information
-    MOS_FORMAT                  Format;             //!<  Surface format
-    VPHAL_SURFACE_TYPE          SurfType;           //!<  Surface type (context)
-    VPHAL_SAMPLE_TYPE           SampleType;         //!<  Interlaced/Progressive sample type
-    uint32_t                    dwDepth;            //!<  Surface depth
-    MOS_S3D_CHANNEL             Channel;            //!<  Channel
-    uint32_t                    dwOffset;           //!<  Surface Offset (Y/Base)
-    MOS_RESOURCE                OsResource;         //!<  Surface resource
-    VPHAL_ROTATION              Rotation;           //!<  0: 0 degree, 1: 90 degree, 2: 180 degree, 3: 270 degreee
+    MOS_FORMAT                  Format = Format_None;               //!<  Surface format
+    VPHAL_SURFACE_TYPE          SurfType = SURF_NONE;               //!<  Surface type (context)
+    VPHAL_SAMPLE_TYPE           SampleType = SAMPLE_PROGRESSIVE;    //!<  Interlaced/Progressive sample type
+    uint32_t                    dwDepth = 0;                        //!<  Surface depth
+    MOS_S3D_CHANNEL             Channel = MOS_S3D_NONE;             //!<  Channel
+    uint32_t                    dwOffset = 0;                       //!<  Surface Offset (Y/Base)
+    MOS_RESOURCE                OsResource = {};                    //!<  Surface resource
+    VPHAL_ROTATION              Rotation = VPHAL_ROTATION_IDENTITY; //!<  0: 0 degree, 1: 90 degree, 2: 180 degree, 3: 270 degreee
 
     // Chroma siting
-    uint32_t                    ChromaSiting;
-    bool                        bChromaSiting;      //!<  Chromasiting flag
+    uint32_t                    ChromaSiting = CHROMA_SITING_NONE;
+    bool                        bChromaSiting = false;      //!<  Chromasiting flag
 
     // Surface compression mode, enable flags
-    bool                        bCompressible;      // The surface is compressible, means there are additional 128 bit for MMC no matter it is compressed or not
-                                                    // The bIsCompressed in surface allocation structure should use this flag to initialize to allocate a compressible surface
-    bool                        bIsCompressed;      // The surface is compressed, VEBox output can only support horizontal mode, but input can be horizontal / vertical
-    MOS_RESOURCE_MMC_MODE       CompressionMode;
-
-    bool                        bUseSampleUnorm;    //!<  true: sample unorm is used, false: DScaler or AVS is used.
-    bool                        bUseSamplerLumakey; //!<  true: sampler lumakey is used, false: lumakey is disabled or EU computed lumakey is used.
+    bool                        bCompressible = false;      // The surface is compressible, means there are additional 128 bit for MMC no matter it is compressed or not
+    // The bIsCompressed in surface allocation structure should use this flag to initialize to allocate a compressible surface
+    bool                        bIsCompressed = false;      // The surface is compressed, VEBox output can only support horizontal mode, but input can be horizontal / vertical
+    MOS_RESOURCE_MMC_MODE       CompressionMode = MOS_MMC_DISABLED;
+    uint32_t                    CompressionFormat = 0;
 
+    bool                        bUseSampleUnorm = false;    //!<  true: sample unorm is used, false: DScaler or AVS is used.
+    bool                        bUseSamplerLumakey = false; //!<  true: sampler lumakey is used, false: lumakey is disabled or EU computed lumakey is used.
     //------------------------------------------
     // HDR related parameters, provided by DDI
     //------------------------------------------
     PVPHAL_HDR_PARAMS           pHDRParams = nullptr;
-    VPHAL_GAMMA_TYPE            GammaType;          //!<Gamma Type
+    VPHAL_GAMMA_TYPE            GammaType = VPHAL_GAMMA_NONE;    //!<Gamma Type
+    bool                        bPreAPGWorkloadEnable = false;   //!< Previous Surface Execution Path
 };
 
 //!
@@ -1123,7 +1162,6 @@ struct VPHAL_RENDER_PARAMS
 
                                                                         // Status Report
     bool                                    bReportStatus;              //!< Report current media BB status (Pre-Processing)
-    bool                                    bUserPrt_16Align[VPHAL_MAX_TARGETS];           //!< is system memory 16 bytes alignment requirement.
     uint32_t                                StatusFeedBackID;           //!< Unique Staus ID;
 #if (_DEBUG || _RELEASE_INTERNAL)
     bool                                    bTriggerGPUHang;            //!< Trigger GPU HANG
@@ -1134,6 +1172,13 @@ struct VPHAL_RENDER_PARAMS
                                                                         // extension parameters
     void                                    *pExtensionData;            //!< Extension data
 
+    bool                                    bPathKernel;                // HDR path config if use kernel
+    bool                                    bAPGWorkloadEnable = false;         //!< Identify Whether APG workload Enabled or not
+
+    bool                                    bDisableVeboxFor8K = false;
+    bool                                    bUseVEHdrSfc       = false;  // use SFC for to perform CSC/Scaling/RGBSwap of HDR streaming; if false, use composite render.
+    bool                                    bNonFirstFrame     = false;  // first frame or not: first frame false, otherwise true considering zeromemory parameters.
+
     VPHAL_RENDER_PARAMS() :
         uSrcCount(0),
         pSrc(),
@@ -1154,12 +1199,11 @@ struct VPHAL_RENDER_PARAMS
         bTriggerGPUHang(false),
 #endif
         bCalculatingAlpha(false),
-        pExtensionData(nullptr)
+        pExtensionData(nullptr),
+        bPathKernel(false),
+        bUseVEHdrSfc(false),
+        bNonFirstFrame(false)
     {
-        for (int i=0; i<VPHAL_MAX_TARGETS; i++)
-        {
-            bUserPrt_16Align[i] = false;
-        }
     }
 
 };
@@ -1288,12 +1332,14 @@ MOS_STATUS VpHal_GetSurfaceInfo(
 //!           Expected Surface Width
 //! \param    [in] dwHeight
 //!           Expected Surface Height
-//! \param    [in] bCompressed
-//!           Compressed surface or not
+//! \param    [in] bCompressible
+//!           Surface being compressible or not
 //! \param    [in] CompressionMode
 //!           Compression Mode
 //! \param    [out] pbAllocated
 //!           true if allocated, false for not
+//! \param    [in] resUsageType
+//!           resource usage type for caching
 //! \return   MOS_STATUS
 //!           MOS_STATUS_SUCCESS if success. Error code otherwise
 //!
@@ -1306,9 +1352,11 @@ MOS_STATUS VpHal_ReAllocateSurface(
     MOS_TILE_TYPE           DefaultTileType,                                    // [in]    Default Resource Tile Type to use if resource has not be allocated yet
     uint32_t                dwWidth,                                            // [in]    Resource Width
     uint32_t                dwHeight,                                           // [in]    Resource Height
-    bool                    pbCompressed,                                       // [in]    Flag indaicated reource is compressed or not
+    bool                    bCompressible,                                      // [in]    Flag indaicated reource is compressible or not
     MOS_RESOURCE_MMC_MODE   CompressionMode,                                    // [in]    Compression mode
-    bool*                   pbAllocated);                                       // [out]   Flag indicating new allocation
+    bool*                   pbAllocated,                                        // [out]   Flag indicating new allocation
+    MOS_HW_RESOURCE_DEF     resUsageType = MOS_HW_RESOURCE_DEF_MAX,             // [in]    resource usage type
+    MOS_TILE_MODE_GMM       tileModeByForce = MOS_TILE_UNSET_GMM);              // [in]    Flag to indicate if GMM flag tile64 need set
 
 //!
 //! \brief    Reads the Surface contents and copy to the Dst Buffer
@@ -1453,6 +1501,9 @@ void VpHal_AllocParamsInitType(
     MOS_GFXRES_TYPE             DefaultResType,
     MOS_TILE_TYPE               DefaultTileType);
 
+MOS_SURFACE VpHal_ConvertVphalSurfaceToMosSurface(
+    PVPHAL_SURFACE pSurface);
+
 #ifdef __cplusplus
 }
 #endif
