@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019, Intel Corporation
+* Copyright (c) 2019-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -144,7 +144,7 @@ MOS_STATUS MediaVeboxDecompState::MemoryDecompress(PMOS_RESOURCE targetResource)
     MHW_FUNCTION_ENTER;
 
     VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(targetResource);
-    
+    MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_START, nullptr, 0, nullptr, 0);
 #if MOS_MEDIASOLO_SUPPORTED
     if (m_osInterface->bSoloInUse)
     {
@@ -174,7 +174,7 @@ MOS_STATUS MediaVeboxDecompState::MemoryDecompress(PMOS_RESOURCE targetResource)
             }
         }
     }
-
+    MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_END, nullptr, 0, nullptr, 0);
     return eStatus;
 }
 
@@ -189,6 +189,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
 
     VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(inputResource);
     VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(outputResource);
+    MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_START, nullptr, 0, nullptr, 0);
 
     MOS_SURFACE             sourceSurface;
     MOS_SURFACE             targetSurface;
@@ -209,11 +210,84 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
     VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(GetResourceInfo(&targetSurface));
     VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(GetResourceInfo(&sourceSurface));
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    {
+        // Read user feature key to force outputCompressed
+        MOS_USER_FEATURE_VALUE_DATA userFeatureData;
+        MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
+        MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
+            nullptr,
+            __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED_ID,
+            &userFeatureData,
+            m_osInterface ? m_osInterface->pOsContext : nullptr));
+
+        outputCompressed = userFeatureData.bData ? true : false;
+
+    }
+#endif
+
     if (!outputCompressed && targetSurface.CompressionMode != MOS_MMC_DISABLED)
     {
         targetSurface.CompressionMode = MOS_MMC_RC;
     }
 
+    //if surface is linear buffer, use mos copy
+    if (sourceSurface.TileType == MOS_TILE_LINEAR          &&
+        targetSurface.TileType == MOS_TILE_LINEAR          &&
+        sourceSurface.Type     == MOS_GFXRES_BUFFER        &&
+        targetSurface.Type     == MOS_GFXRES_BUFFER )
+    {
+        DumpSurfaceMemDecomp(sourceSurface, m_surfaceDumpCounter, 1, VPHAL_DBG_DUMP_TYPE_PRE_MEMDECOMP);
+        do
+        {
+            MOS_LOCK_PARAMS lockSourceFlags;
+            MOS_ZeroMemory(&lockSourceFlags, sizeof(MOS_LOCK_PARAMS));
+            lockSourceFlags.ReadOnly     = 1;
+            lockSourceFlags.WriteOnly    = 0;
+
+            MOS_LOCK_PARAMS lockTargetFlags;
+            MOS_ZeroMemory(&lockTargetFlags, sizeof(MOS_LOCK_PARAMS));
+            lockTargetFlags.ReadOnly     = 0;
+            lockTargetFlags.WriteOnly    = 1;
+
+            uint8_t *lockedSrcAddr       = (uint8_t *)m_osInterface->pfnLockResource(m_osInterface, &sourceSurface.OsResource, &lockSourceFlags);
+
+            if (lockedSrcAddr == nullptr)
+            {
+                //non lockable resource enabled, we can't lock source surface
+                eStatus = MOS_STATUS_NULL_POINTER;
+                VPHAL_MEMORY_DECOMP_ASSERTMESSAGE("Failed to lock non-lockable input resource, buffer copy failed, eStatus:%d.\n", eStatus);
+                break;
+            }
+
+            uint8_t *lockedTarAddr       = (uint8_t *)m_osInterface->pfnLockResource(m_osInterface, &targetSurface.OsResource, &lockTargetFlags);
+
+            if (lockedTarAddr == nullptr)
+            {
+                eStatus = MOS_STATUS_NULL_POINTER;
+                m_osInterface->pfnUnlockResource(m_osInterface, &sourceSurface.OsResource);
+                VPHAL_MEMORY_DECOMP_ASSERTMESSAGE("Failed to lock non-lockable output resource, buffer copy failed, eStatus:%d.\n", eStatus);
+                break;
+            }
+            // This resource is a series of bytes. Is not 2 dimensional.
+            uint32_t sizeSrcMain    = sourceSurface.dwWidth;
+            uint32_t sizeTargetMain = targetSurface.dwWidth;
+            eStatus                 = MOS_SecureMemcpy(lockedTarAddr, sizeTargetMain, lockedSrcAddr, sizeSrcMain);
+            m_osInterface->pfnUnlockResource(m_osInterface, &sourceSurface.OsResource);
+            m_osInterface->pfnUnlockResource(m_osInterface, &targetSurface.OsResource);
+
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                VPHAL_MEMORY_DECOMP_ASSERTMESSAGE("Failed to copy linear buffer from source to target, eStatus:%d.\n", eStatus);
+                break;
+            }
+        } while (false);
+
+        DumpSurfaceMemDecomp(targetSurface, m_surfaceDumpCounter++, 1, VPHAL_DBG_DUMP_TYPE_POST_MEMDECOMP);
+        MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_END, nullptr, 0, nullptr, 0);
+        return eStatus;
+    }
+
     //Get context before proceeding
     auto gpuContext = m_osInterface->CurrentGpuContextOrdinal;
 
@@ -236,7 +310,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy(
     VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(RenderDoubleBufferDecompCMD(&sourceSurface, &targetSurface));
 
     DumpSurfaceMemDecomp(targetSurface, m_surfaceDumpCounter++, 1, VPHAL_DBG_DUMP_TYPE_POST_MEMDECOMP);
-
+    MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_END, nullptr, 0, nullptr, 0);
     return eStatus;
 }
 
@@ -247,6 +321,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy2D(
     uint32_t      copyHeight,
     uint32_t      copyInputOffset,
     uint32_t      copyOutputOffset,
+    uint32_t      bpp,
     bool          outputCompressed)
 {
     MOS_STATUS                          eStatus = MOS_STATUS_SUCCESS;
@@ -255,6 +330,7 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy2D(
 
     VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(inputResource);
     VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(outputResource);
+    MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_START, nullptr, 0, nullptr, 0);
 
     MOS_SURFACE             sourceSurface;
     MOS_SURFACE             targetSurface;
@@ -275,6 +351,21 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy2D(
     VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(GetResourceInfo(&targetSurface));
     VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(GetResourceInfo(&sourceSurface));
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    {
+        // Read user feature key to Force outputCompressed
+        MOS_USER_FEATURE_VALUE_DATA userFeatureData;
+        MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
+        MOS_USER_FEATURE_INVALID_KEY_ASSERT(MOS_UserFeature_ReadValue_ID(
+            nullptr,
+            __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED_ID,
+            &userFeatureData,
+            m_osInterface ? m_osInterface->pOsContext : nullptr));
+
+        outputCompressed = userFeatureData.bData ? true : false;
+    }
+#endif
+
     if (!outputCompressed && targetSurface.CompressionMode != MOS_MMC_DISABLED)
     {
         targetSurface.CompressionMode = MOS_MMC_RC;
@@ -282,16 +373,44 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy2D(
 
     //Get context before proceeding
     auto gpuContext = m_osInterface->CurrentGpuContextOrdinal;
+    uint32_t pixelInByte = 1;
+
+    switch (bpp)
+    {
+    case 8:
+        targetSurface.Format = Format_Y8;
+        sourceSurface.Format = Format_Y8;
+        pixelInByte = 1;
+        break;
+    case 16:
+        targetSurface.Format = Format_Y16U;
+        sourceSurface.Format = Format_Y16U;
+        pixelInByte = 2;
+        break;
+    case 32:
+        targetSurface.Format = Format_AYUV;
+        sourceSurface.Format = Format_AYUV;
+        pixelInByte = 4;
+        break;
+    case 64:
+        targetSurface.Format = Format_Y416;
+        sourceSurface.Format = Format_Y416;
+        pixelInByte = 8;
+        break;
+    default:
+        targetSurface.Format = Format_Y8;
+        sourceSurface.Format = Format_Y8;
+        pixelInByte = 1;
+        break;
+    }
 
-    targetSurface.Format = Format_Y8;
-    sourceSurface.Format = Format_Y8;
 
     sourceSurface.dwOffset = copyInputOffset;
     targetSurface.dwOffset = copyOutputOffset;
 
-    sourceSurface.dwWidth  = copyWidth;
+    sourceSurface.dwWidth  = copyWidth / pixelInByte;
     sourceSurface.dwHeight = copyHeight;
-    targetSurface.dwWidth  = copyWidth;
+    targetSurface.dwWidth  = copyWidth / pixelInByte;
     targetSurface.dwHeight = copyHeight;
 
     // Sync for Vebox write
@@ -306,7 +425,110 @@ MOS_STATUS MediaVeboxDecompState::MediaMemoryCopy2D(
     VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(RenderDoubleBufferDecompCMD(&sourceSurface, &targetSurface));
 
     DumpSurfaceMemDecomp(targetSurface, m_surfaceDumpCounter++, 1, VPHAL_DBG_DUMP_TYPE_POST_MEMDECOMP);
+    MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_END, nullptr, 0, nullptr, 0);
+    return eStatus;
+}
 
+MOS_STATUS MediaVeboxDecompState::MediaMemoryTileConvert(
+        PMOS_RESOURCE inputResource,
+        PMOS_RESOURCE outputResource,
+        uint32_t      copyWidth,
+        uint32_t      copyHeight,
+        uint32_t      copyInputOffset,
+        uint32_t      copyOutputOffset,
+        bool          isTileToLinear,
+        bool          outputCompressed)
+{
+    MOS_STATUS                          eStatus = MOS_STATUS_SUCCESS;
+
+    MHW_FUNCTION_ENTER;
+
+    VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(inputResource);
+    VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(outputResource);
+    MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_START, nullptr, 0, nullptr, 0);
+
+    MOS_SURFACE             sourceSurface;
+    MOS_SURFACE             targetSurface;
+
+    MOS_ZeroMemory(&targetSurface, sizeof(MOS_SURFACE));
+    MOS_ZeroMemory(&sourceSurface, sizeof(MOS_SURFACE));
+
+    targetSurface.Format = Format_Invalid;
+    targetSurface.OsResource = *outputResource;
+
+#if !defined(LINUX) && !defined(ANDROID) && !EMUL
+    // for Double Buffer copy, clear the allocationInfo temply
+    MOS_ZeroMemory(&targetSurface.OsResource.AllocationInfo, sizeof(SResidencyInfo));
+#endif
+
+    sourceSurface.Format = Format_Invalid;
+    sourceSurface.OsResource = *inputResource;
+    VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(GetResourceInfo(&targetSurface));
+    VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(GetResourceInfo(&sourceSurface));
+
+    if (targetSurface.TileType == MOS_TILE_LINEAR &&
+        sourceSurface.TileType == MOS_TILE_LINEAR)
+    {
+        VPHAL_MEMORY_DECOMP_NORMALMESSAGE("unsupport linear to linear convert, return unsupport feature");
+        return MOS_STATUS_PLATFORM_NOT_SUPPORTED;
+    }
+
+    MOS_FORMAT format = Format_Any;
+    if (isTileToLinear)
+    {
+        if (!IsFormatSupported(&sourceSurface))
+        {
+            VPHAL_MEMORY_DECOMP_NORMALMESSAGE("unsupport processing format, return unsupport feature");
+            return MOS_STATUS_PLATFORM_NOT_SUPPORTED;
+        }
+
+        format = sourceSurface.Format;
+        copyHeight = sourceSurface.dwHeight;
+    }
+    else
+    {
+        if (!IsFormatSupported(&targetSurface))
+        {
+            VPHAL_MEMORY_DECOMP_NORMALMESSAGE("unsupport processing format, return unsupport feature");
+            return MOS_STATUS_PLATFORM_NOT_SUPPORTED;
+        }
+
+        format = targetSurface.Format;
+        copyHeight = targetSurface.dwHeight;
+    }
+
+    if (!outputCompressed && targetSurface.CompressionMode != MOS_MMC_DISABLED)
+    {
+        targetSurface.CompressionMode = MOS_MMC_RC;
+    }
+
+    //Get context before proceeding
+    auto gpuContext = m_osInterface->CurrentGpuContextOrdinal;
+
+    targetSurface.Format = format;
+    sourceSurface.Format = format;
+
+    sourceSurface.dwOffset = copyInputOffset;
+    targetSurface.dwOffset = copyOutputOffset;
+
+    sourceSurface.dwWidth = copyWidth;
+    sourceSurface.dwHeight = copyHeight;
+    targetSurface.dwWidth = copyWidth;
+    targetSurface.dwHeight = copyHeight;
+
+    // Sync for Vebox write
+    m_osInterface->pfnSyncOnResource(
+        m_osInterface,
+        &targetSurface.OsResource,
+        MOS_GPU_CONTEXT_VEBOX,
+        false);
+
+    DumpSurfaceMemDecomp(sourceSurface, m_surfaceDumpCounter, 1, VPHAL_DBG_DUMP_TYPE_PRE_MEMDECOMP);
+
+    VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(RenderDoubleBufferDecompCMD(&sourceSurface, &targetSurface));
+
+    DumpSurfaceMemDecomp(targetSurface, m_surfaceDumpCounter++, 1, VPHAL_DBG_DUMP_TYPE_POST_MEMDECOMP);
+    MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_END, nullptr, 0, nullptr, 0);
     return eStatus;
 }
 
@@ -454,6 +676,11 @@ MOS_STATUS MediaVeboxDecompState::SetupVeboxSurfaceState(
     PMOS_SURFACE                        outputSurface)
 {
     MOS_STATUS              eStatus = MOS_STATUS_SUCCESS;
+    bool  inputIsLinearBuffer = false;
+    bool  outputIsLinearBuffer = false;
+    uint32_t bpp = 1;
+    uint32_t inputWidth = 0;
+    uint32_t outputWidth = 0;
 
     VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(inputSurface);
     VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(mhwVeboxSurfaceStateCmdParams);
@@ -462,21 +689,75 @@ MOS_STATUS MediaVeboxDecompState::SetupVeboxSurfaceState(
 
     mhwVeboxSurfaceStateCmdParams->SurfInput.bActive    = mhwVeboxSurfaceStateCmdParams->SurfOutput.bActive    = true;
     mhwVeboxSurfaceStateCmdParams->SurfInput.dwBitDepth = mhwVeboxSurfaceStateCmdParams->SurfOutput.dwBitDepth = inputSurface->dwDepth;
-    mhwVeboxSurfaceStateCmdParams->SurfInput.dwHeight   = mhwVeboxSurfaceStateCmdParams->SurfOutput.dwHeight   = inputSurface->dwHeight;
-    mhwVeboxSurfaceStateCmdParams->SurfInput.dwWidth    = mhwVeboxSurfaceStateCmdParams->SurfOutput.dwWidth    = inputSurface->dwWidth;
+    mhwVeboxSurfaceStateCmdParams->SurfInput.dwHeight   = mhwVeboxSurfaceStateCmdParams->SurfOutput.dwHeight   =
+        MOS_MIN(inputSurface->dwHeight, ((outputSurface!= nullptr) ? outputSurface->dwHeight : inputSurface->dwHeight));
+    mhwVeboxSurfaceStateCmdParams->SurfInput.dwWidth    = mhwVeboxSurfaceStateCmdParams->SurfOutput.dwWidth    =
+        MOS_MIN(inputSurface->dwWidth, ((outputSurface != nullptr) ? outputSurface->dwWidth : inputSurface->dwWidth));
     mhwVeboxSurfaceStateCmdParams->SurfInput.Format     = mhwVeboxSurfaceStateCmdParams->SurfOutput.Format     = inputSurface->Format;
 
+    MOS_SURFACE inputDetails, outputDetails;
+    MOS_ZeroMemory(&inputDetails, sizeof(inputDetails));
+    MOS_ZeroMemory(&outputDetails, sizeof(outputDetails));
+    inputDetails.Format = Format_Invalid;
+    outputDetails.Format = Format_Invalid;
+
+    if (inputSurface)
+    {
+        VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(m_osInterface->pfnGetResourceInfo(
+            m_osInterface,
+            &inputSurface->OsResource,
+            &inputDetails));
+    }
+
+    if (outputSurface)
+    {
+        VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(m_osInterface->pfnGetResourceInfo(
+            m_osInterface,
+            &outputSurface->OsResource,
+            &outputDetails));
+
+        // Following settings are enabled only when outputSurface is availble
+        inputIsLinearBuffer  = (inputDetails.dwHeight == 1) ? true : false;
+        outputIsLinearBuffer = (outputDetails.dwHeight == 1) ? true : false;
+
+        inputWidth = inputSurface->dwWidth;
+        outputWidth = outputSurface->dwWidth;
+
+        if (inputIsLinearBuffer)
+        {
+            bpp = outputDetails.dwPitch / outputDetails.dwWidth;
+            if (outputDetails.dwPitch % outputDetails.dwWidth != 0)
+            {
+                inputWidth = outputDetails.dwPitch / bpp;
+            }
+        }
+        else if (outputIsLinearBuffer)
+        {
+            bpp = inputDetails.dwPitch / inputDetails.dwWidth;
+            if (inputDetails.dwPitch % inputDetails.dwWidth != 0)
+            {
+                outputWidth = inputDetails.dwPitch / bpp;
+            }
+        }
+        else
+        {
+            VPHAL_MEMORY_DECOMP_NORMALMESSAGE("2D to 2D, no need for bpp setting.");
+        }
+    }
+
 
     if (inputSurface->dwPitch > 0            &&
        (inputSurface->Format == Format_P010  ||
         inputSurface->Format == Format_P016  ||
         inputSurface->Format == Format_NV12))
     {
-        mhwVeboxSurfaceStateCmdParams->SurfInput.dwUYoffset = SURFACE_DW_UY_OFFSET(inputSurface);
+        mhwVeboxSurfaceStateCmdParams->SurfInput.dwUYoffset = (!inputIsLinearBuffer) ? SURFACE_DW_UY_OFFSET(inputSurface) :
+                                                              inputSurface->dwHeight;
 
         if (outputSurface)
         {
-            mhwVeboxSurfaceStateCmdParams->SurfOutput.dwUYoffset = SURFACE_DW_UY_OFFSET(outputSurface);
+            mhwVeboxSurfaceStateCmdParams->SurfOutput.dwUYoffset = (!outputIsLinearBuffer) ? SURFACE_DW_UY_OFFSET(outputSurface) :
+                                                                   outputSurface->dwHeight;
         }
         else
         {
@@ -485,20 +766,20 @@ MOS_STATUS MediaVeboxDecompState::SetupVeboxSurfaceState(
     }
 
     mhwVeboxSurfaceStateCmdParams->SurfInput.rcMaxSrc.left   = mhwVeboxSurfaceStateCmdParams->SurfOutput.rcMaxSrc.left   = 0;
-    mhwVeboxSurfaceStateCmdParams->SurfInput.rcMaxSrc.right  = mhwVeboxSurfaceStateCmdParams->SurfOutput.rcMaxSrc.right  = (long)inputSurface->dwWidth;
+    mhwVeboxSurfaceStateCmdParams->SurfInput.rcMaxSrc.right  = mhwVeboxSurfaceStateCmdParams->SurfOutput.rcMaxSrc.right  = (long)(mhwVeboxSurfaceStateCmdParams->SurfInput.dwWidth);
     mhwVeboxSurfaceStateCmdParams->SurfInput.rcMaxSrc.top    = mhwVeboxSurfaceStateCmdParams->SurfOutput.rcMaxSrc.top    = 0;
-    mhwVeboxSurfaceStateCmdParams->SurfInput.rcMaxSrc.bottom = mhwVeboxSurfaceStateCmdParams->SurfOutput.rcMaxSrc.bottom = (long)inputSurface->dwHeight;
+    mhwVeboxSurfaceStateCmdParams->SurfInput.rcMaxSrc.bottom = mhwVeboxSurfaceStateCmdParams->SurfOutput.rcMaxSrc.bottom = (long)(mhwVeboxSurfaceStateCmdParams->SurfInput.dwHeight);
     mhwVeboxSurfaceStateCmdParams->bOutputValid = true;
 
     // if output surface is null, then Inplace resolve happens
     if (!outputSurface)
     {
-        mhwVeboxSurfaceStateCmdParams->SurfInput.TileType    = mhwVeboxSurfaceStateCmdParams->SurfOutput.TileType    = inputSurface->TileType;
-        mhwVeboxSurfaceStateCmdParams->SurfInput.TileModeGMM = mhwVeboxSurfaceStateCmdParams->SurfOutput.TileModeGMM = inputSurface->TileModeGMM;
-        mhwVeboxSurfaceStateCmdParams->SurfInput.bGMMTileEnabled = mhwVeboxSurfaceStateCmdParams->SurfOutput.bGMMTileEnabled = inputSurface->bGMMTileEnabled;
-        mhwVeboxSurfaceStateCmdParams->SurfOutput.dwPitch    = mhwVeboxSurfaceStateCmdParams->SurfInput.dwPitch      = inputSurface->dwPitch;
-        mhwVeboxSurfaceStateCmdParams->SurfInput.pOsResource = mhwVeboxSurfaceStateCmdParams->SurfOutput.pOsResource = &(inputSurface->OsResource);
-        mhwVeboxSurfaceStateCmdParams->SurfInput.dwYoffset   = mhwVeboxSurfaceStateCmdParams->SurfOutput.dwYoffset   = inputSurface->YPlaneOffset.iYOffset;
+        mhwVeboxSurfaceStateCmdParams->SurfInput.TileType        = mhwVeboxSurfaceStateCmdParams->SurfOutput.TileType            = inputSurface->TileType;
+        mhwVeboxSurfaceStateCmdParams->SurfInput.TileModeGMM     = mhwVeboxSurfaceStateCmdParams->SurfOutput.TileModeGMM         = inputSurface->TileModeGMM;
+        mhwVeboxSurfaceStateCmdParams->SurfInput.bGMMTileEnabled = mhwVeboxSurfaceStateCmdParams->SurfOutput.bGMMTileEnabled     = inputSurface->bGMMTileEnabled;
+        mhwVeboxSurfaceStateCmdParams->SurfOutput.dwPitch        = mhwVeboxSurfaceStateCmdParams->SurfInput.dwPitch              = inputSurface->dwPitch;
+        mhwVeboxSurfaceStateCmdParams->SurfInput.pOsResource     = mhwVeboxSurfaceStateCmdParams->SurfOutput.pOsResource         = &(inputSurface->OsResource);
+        mhwVeboxSurfaceStateCmdParams->SurfInput.dwYoffset       = mhwVeboxSurfaceStateCmdParams->SurfOutput.dwYoffset           = inputSurface->YPlaneOffset.iYOffset;
 
         mhwVeboxSurfaceStateCmdParams->SurfInput.dwCompressionFormat = mhwVeboxSurfaceStateCmdParams->SurfOutput.dwCompressionFormat =
             inputSurface->CompressionFormat;
@@ -514,10 +795,10 @@ MOS_STATUS MediaVeboxDecompState::SetupVeboxSurfaceState(
         mhwVeboxSurfaceStateCmdParams->SurfOutput.bGMMTileEnabled     = outputSurface->bGMMTileEnabled;
 
         // When surface is 1D but processed as 2D, fake a min(pitch, width) is needed as the pitch API passed may less surface width in 1D surface
-        mhwVeboxSurfaceStateCmdParams->SurfInput.dwPitch              = (inputSurface->TileType == MOS_TILE_LINEAR) ? 
-                                                                         MOS_MIN(inputSurface->dwWidth, inputSurface->dwPitch) : inputSurface->dwPitch;
-        mhwVeboxSurfaceStateCmdParams->SurfOutput.dwPitch             = (outputSurface->TileType == MOS_TILE_LINEAR) ? 
-                                                                         MOS_MIN(outputSurface->dwPitch, outputSurface->dwWidth) : outputSurface->dwPitch;
+        mhwVeboxSurfaceStateCmdParams->SurfInput.dwPitch              = (inputIsLinearBuffer) ?
+                                                                         MOS_MIN(inputWidth * bpp, inputSurface->dwPitch) : inputSurface->dwPitch;
+        mhwVeboxSurfaceStateCmdParams->SurfOutput.dwPitch             = (outputIsLinearBuffer) ?
+                                                                         MOS_MIN(outputWidth * bpp, outputSurface->dwPitch) : outputSurface->dwPitch;
         mhwVeboxSurfaceStateCmdParams->SurfInput.pOsResource          = &(inputSurface->OsResource);
         mhwVeboxSurfaceStateCmdParams->SurfOutput.pOsResource         = &(outputSurface->OsResource);
         mhwVeboxSurfaceStateCmdParams->SurfInput.dwYoffset            = inputSurface->YPlaneOffset.iYOffset;
@@ -534,10 +815,9 @@ MOS_STATUS MediaVeboxDecompState::InitCommandBuffer(
 {
     PMOS_INTERFACE              pOsInterface;
     MOS_STATUS                  eStatus = MOS_STATUS_SUCCESS;
-    MEDIA_SYSTEM_INFO           *pGtSystemInfo;
     uint32_t                    iRemaining;
     RENDERHAL_GENERIC_PROLOG_PARAMS         GenericPrologParams = {};
-    MOS_RESOURCE                            GpuStatusBuffer;
+    PMOS_RESOURCE                           gpuStatusBuffer     = nullptr;
 
     //---------------------------------------------
     VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(cmdBuffer);
@@ -554,13 +834,13 @@ MOS_STATUS MediaVeboxDecompState::InitCommandBuffer(
     if (pOsInterface->bEnableKmdMediaFrameTracking)
     {
         // Get GPU Status buffer
-        VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(pOsInterface->pfnGetGpuStatusBufferResource(pOsInterface, &GpuStatusBuffer));
-
+        VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(pOsInterface->pfnGetGpuStatusBufferResource(pOsInterface, gpuStatusBuffer));
+        VPHAL_MEMORY_DECOMP_CHK_NULL_RETURN(gpuStatusBuffer);
         // Register the buffer
-        VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(pOsInterface->pfnRegisterResource(pOsInterface, &GpuStatusBuffer, true, true));
+        VPHAL_MEMORY_DECOMP_CHK_STATUS_RETURN(pOsInterface->pfnRegisterResource(pOsInterface, gpuStatusBuffer, true, true));
 
         GenericPrologParams.bEnableMediaFrameTracking      = true;
-        GenericPrologParams.presMediaFrameTrackingSurface  = &GpuStatusBuffer;
+        GenericPrologParams.presMediaFrameTrackingSurface  = gpuStatusBuffer;
         GenericPrologParams.dwMediaFrameTrackingTag        = pOsInterface->pfnGetGpuStatusTag(pOsInterface, pOsInterface->CurrentGpuContextOrdinal);
         GenericPrologParams.dwMediaFrameTrackingAddrOffset = pOsInterface->pfnGetGpuStatusTagOffset(pOsInterface, pOsInterface->CurrentGpuContextOrdinal);
 
@@ -575,7 +855,7 @@ MOS_STATUS MediaVeboxDecompState::InitCommandBuffer(
         cmdBuffer->Attributes.bEnableMediaFrameTracking       = GenericPrologParams.bEnableMediaFrameTracking;
         cmdBuffer->Attributes.dwMediaFrameTrackingTag         = GenericPrologParams.dwMediaFrameTrackingTag;
         cmdBuffer->Attributes.dwMediaFrameTrackingAddrOffset  = GenericPrologParams.dwMediaFrameTrackingAddrOffset;
-        cmdBuffer->Attributes.resMediaFrameTrackingSurface    = *(GenericPrologParams.presMediaFrameTrackingSurface);
+        cmdBuffer->Attributes.resMediaFrameTrackingSurface    = GenericPrologParams.presMediaFrameTrackingSurface;
     }
 
     // initialize command buffer attributes
@@ -596,15 +876,17 @@ MOS_STATUS MediaVeboxDecompState::InitCommandBuffer(
     return eStatus;
 }
 
-bool MediaVeboxDecompState::IsDecompressionFormatSupported(PMOS_SURFACE surface)
+bool MediaVeboxDecompState::IsFormatSupported(PMOS_SURFACE surface)
 {
     bool    bRet = false;
 
     if (surface->Format == Format_R10G10B10A2 ||
-        surface->Format == Format_B10G10R10A2)
+        surface->Format == Format_B10G10R10A2 ||
+        surface->Format == Format_Y410 ||
+        surface->Format == Format_Y210)
     {
-        //For Vebox comsume RGB10, Re-map RGB10 as Y410
-        surface->Format = Format_Y410;
+        // Re-map RGB10/RGB10/Y410/Y210 as AYUV
+        surface->Format = Format_AYUV;
     }
 
     if (surface->Format == Format_A8 ||
@@ -643,7 +925,8 @@ bool MediaVeboxDecompState::IsDecompressionFormatSupported(PMOS_SURFACE surface)
         surface->Format != Format_A8B8G8R8    &&
         surface->Format != Format_X8R8G8B8    &&
         surface->Format != Format_X8B8G8R8    &&
-        surface->Format != Format_P8)
+        surface->Format != Format_P8          &&
+        surface->Format != Format_Y16U)
     {
         VPHAL_MEMORY_DECOMP_NORMALMESSAGE("Unsupported Source Format '0x%08x' for VEBOX Decompression.", surface->Format);
         goto finish;
