@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2014-2018, Intel Corporation
+* Copyright (c) 2014-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -110,7 +110,11 @@ MOS_STATUS VpHal_InitVeboxSurfaceParams(
     pMhwVeboxSurface->dwPitch                = pVpHalVeboxSurface->dwPitch;
     pMhwVeboxSurface->dwBitDepth             = pVpHalVeboxSurface->dwDepth;
     pMhwVeboxSurface->TileType               = pVpHalVeboxSurface->TileType;
+    pMhwVeboxSurface->TileModeGMM            = pVpHalVeboxSurface->TileModeGMM;
+    pMhwVeboxSurface->bGMMTileEnabled        = pVpHalVeboxSurface->bGMMTileEnabled;
+    pMhwVeboxSurface->rcSrc                  = pVpHalVeboxSurface->rcSrc;
     pMhwVeboxSurface->rcMaxSrc               = pVpHalVeboxSurface->rcMaxSrc;
+    pMhwVeboxSurface->bVEBOXCroppingUsed     = pVpHalVeboxSurface->bVEBOXCroppingUsed;
     pMhwVeboxSurface->pOsResource            = &pVpHalVeboxSurface->OsResource;
     pMhwVeboxSurface->bIsCompressed          = pVpHalVeboxSurface->bIsCompressed;
     pMhwVeboxSurface->dwCompressionFormat    = pVpHalVeboxSurface->CompressionFormat;
@@ -136,6 +140,7 @@ MOS_STATUS VpHal_InitVeboxSurfaceStateCmdParams(
     MOS_ZeroMemory(pMhwVeboxSurfaceStateCmdParams, sizeof(*pMhwVeboxSurfaceStateCmdParams));
 
     pMhwVeboxSurfaceStateCmdParams->bDIEnable       = pVpHalVeboxSurfaceStateCmdParams->bDIEnable;
+    pMhwVeboxSurfaceStateCmdParams->b3DlutEnable    = pVpHalVeboxSurfaceStateCmdParams->b3DlutEnable;
 
     if (pVpHalVeboxSurfaceStateCmdParams->pSurfInput)
     {
