@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2018, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -193,7 +193,6 @@ MOS_STATUS CodechalDecodeAvcG11::DecodeStateLevel()
 MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-    CODECHAL_DECODE_PROCESSING_PARAMS *decProcessingParams = nullptr;
 
     CODECHAL_DECODE_FUNCTION_ENTER;
 
@@ -231,15 +230,15 @@ MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
     }
 
 #ifdef _DECODE_PROCESSING_SUPPORTED
-    decProcessingParams = (CODECHAL_DECODE_PROCESSING_PARAMS *)m_decodeParams.m_procParams;
-    if (decProcessingParams != nullptr && decProcessingParams->bIsReferenceOnlyPattern)
+    DecodeProcessingParams *decProcessingParams = (DecodeProcessingParams *)m_decodeParams.m_procParams;
+    if (decProcessingParams != nullptr && decProcessingParams->m_isReferenceOnlyPattern)
     {
         HucCopy(&cmdBuffer, 
             &m_destSurface.OsResource, 
-            &decProcessingParams->pOutputSurface->OsResource, 
-            decProcessingParams->pOutputSurface->dwSize,
+            &decProcessingParams->m_outputSurface->OsResource, 
+            decProcessingParams->m_outputSurface->dwSize,
             m_destSurface.dwOffset,
-            decProcessingParams->pOutputSurface->dwOffset
+            decProcessingParams->m_outputSurface->dwOffset
         );
     }
 #endif
@@ -330,14 +329,14 @@ MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
         CodecHalDecodeSinglePipeVE_PopulateHintParams(m_veState, &cmdBuffer, true);
     }
 
-    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface);
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(m_osInterface, &cmdBuffer, m_videoContextUsesNullHw));
 
     CODECHAL_DEBUG_TOOL(
         m_mmc->UpdateUserFeatureKey(&m_destSurface);)
 #ifdef _DECODE_PROCESSING_SUPPORTED
-    decProcessingParams = (CODECHAL_DECODE_PROCESSING_PARAMS *)m_decodeParams.m_procParams;
+    decProcessingParams = (DecodeProcessingParams *)m_decodeParams.m_procParams;
     if (decProcessingParams != nullptr && !m_sfcState->m_sfcPipeOut && (m_isSecondField || m_avcPicParams->seq_fields.mb_adaptive_frame_field_flag))
     {
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_fieldScalingInterface->DoFieldScaling(
@@ -372,7 +371,7 @@ MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
         {
             syncParams = g_cInitSyncParams;
             syncParams.GpuContext = m_renderContext;
-            syncParams.presSyncResource = &decProcessingParams->pOutputSurface->OsResource;
+            syncParams.presSyncResource = &decProcessingParams->m_outputSurface->OsResource;
 
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnResourceSignal(m_osInterface, &syncParams));
         }
@@ -382,12 +381,12 @@ MOS_STATUS CodechalDecodeAvcG11::DecodePrimitiveLevel()
 #ifdef _DECODE_PROCESSING_SUPPORTED
     CODECHAL_DEBUG_TOOL(
         // Dump out downsampling result
-        if (decProcessingParams && decProcessingParams->pOutputSurface)
+        if (decProcessingParams && decProcessingParams->m_outputSurface)
         {
             MOS_SURFACE dstSurface;
             MOS_ZeroMemory(&dstSurface, sizeof(dstSurface));
             dstSurface.Format = Format_NV12;
-            dstSurface.OsResource = decProcessingParams->pOutputSurface->OsResource;
+            dstSurface.OsResource = decProcessingParams->m_outputSurface->OsResource;
 
             CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalGetResourceInfo(
                 m_osInterface,
