@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2018, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -309,7 +309,7 @@ MOS_STATUS CodechalDecodeJpegG11::DecodePrimitiveLevel()
     MHW_VDBOX_QM_PARAMS qmParams;
     MOS_ZeroMemory(&qmParams, sizeof(qmParams));
     qmParams.Standard = CODECHAL_JPEG;
-    qmParams.pJpegQuantMatrix = (CodecJpegQuantMatrix *)m_jpegQMatrix;
+    qmParams.pJpegQuantMatrix = m_jpegQMatrix;
 
     // Swapping QM(x,y) to QM(y,x) for 90/270 degree rotation
     if ((m_jpegPicParams->m_rotation == jpegRotation90) ||
@@ -510,7 +510,7 @@ MOS_STATUS CodechalDecodeJpegG11::DecodePrimitiveLevel()
         CodecHalDecodeSinglePipeVE_PopulateHintParams(m_veState, &cmdBuffer, true);
     }
 
-    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface);
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
         m_osInterface,
