@@ -1,17 +1,23 @@
 /*
-// Copyright (C) 2017-2019, Intel Corporation
-//
-// Licensed under the Apache License,Version 2.0(the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//      http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing,software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
+* Copyright (c) 2017-2020, Intel Corporation
+*
+* Permission is hereby granted, free of charge, to any person obtaining a
+* copy of this software and associated documentation files (the "Software"),
+* to deal in the Software without restriction, including without limitation
+* the rights to use, copy, modify, merge, publish, distribute, sublicense,
+* and/or sell copies of the Software, and to permit persons to whom the
+* Software is furnished to do so, subject to the following conditions:
+*
+* The above copyright notice and this permission notice shall be included
+* in all copies or substantial portions of the Software.
+*
+* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+* OTHER DEALINGS IN THE SOFTWARE.
 */
 //!
 //! \file     codechal_decode_scalability_g12.cpp
@@ -46,10 +52,22 @@ static MOS_STATUS CodecHalDecodeScalability_CalculateScdryCmdBufIndex_G12(
 
     CODECHAL_DECODE_CHK_NULL(pScalabilityStateBase);
     CODECHAL_DECODE_CHK_NULL(pdwBufIdxPlus1);
+    CODECHAL_DECODE_CHK_NULL(pScalabilityStateBase->pHwInterface);
+    CODECHAL_DECODE_CHK_NULL(pScalabilityStateBase->pHwInterface->GetOsInterface());
 
     if (pScalabilityState->HcpDecPhase == CODECHAL_HCP_DECODE_PHASE_REAL_TILE)
     {
         *pdwBufIdxPlus1 = pScalabilityState->u8RtCurPipe + 1;
+        if(pScalabilityStateBase->pHwInterface->GetOsInterface()->phasedSubmission)
+        {
+            /*  3 tiles 2 pipe for example:
+                cur phase               cur pip
+                0                       0, 1                2 cmd buffer needed
+                1                       0                   1 cmd buffer needed
+                all of 3 tiles cmd ready, submit 3 cmd togather
+             */
+            *pdwBufIdxPlus1 += (pScalabilityState->u8RtCurPhase * pScalabilityState->u8RtPhaseNum);
+        }
     }
     else
     {
@@ -450,7 +468,7 @@ MOS_STATUS CodecHalDecodeScalability_InitScalableParams_G12(
     {
         if (!MOS_VE_CTXBASEDSCHEDULING_SUPPORTED(pOsInterface))
         {
-            if (g_apoMosEnabled)
+            if (pOsInterface->apoMosEnabled)
             {
                 CODECHAL_DECODE_CHK_NULL(pVEInterface->veInterface);
                 pScalabilityState->ucScalablePipeNum = pVEInterface->veInterface->GetEngineCount() - 1;
@@ -492,7 +510,8 @@ MOS_STATUS CodecHalDecodeScalability_InitScalableParams_G12(
             u8MaxTileColumn = pScalabilityState->ucScalablePipeNum;
 #endif
         bCanEnableRealTile = bCanEnableRealTile && pInitParams->bIsTileEnabled && (pInitParams->u8NumTileColumns > 1) &&
-            (pInitParams->u8NumTileColumns <= u8MaxTileColumn) && (pInitParams->u8NumTileRows <= HEVC_NUM_MAX_TILE_ROW);
+            (pInitParams->u8NumTileColumns <= u8MaxTileColumn) && (pInitParams->u8NumTileRows <= HEVC_NUM_MAX_TILE_ROW) &&
+            pInitParams->bHasSubsetParams;
         if (bCanEnableRealTile)
         {
             pScalabilityState->bIsRtMode = true;
@@ -514,6 +533,7 @@ MOS_STATUS CodecHalDecodeScalability_InitScalableParams_G12(
         else
         {
             *pucDecPassNum = pScalabilityState->ucScalablePipeNum + 1; // FE + all BEs
+            pScalabilityState->bFESeparateSubmission = pScalabilityState->bFESeparateSubmissionVT;
         }
     }
     else
@@ -607,6 +627,7 @@ MOS_STATUS CodecHalDecodeScalability_DbgDumpCmdBuffer_G12(
     MOS_STATUS                      eStatus = MOS_STATUS_SUCCESS;
     MOS_COMMAND_BUFFER              ScdryCmdBuffer;
     PMOS_COMMAND_BUFFER             pCmdBufferInUse;
+    std::string                     cmdName = "DEC";
 
     CODECHAL_DECODE_FUNCTION_ENTER;
 
@@ -628,6 +649,10 @@ MOS_STATUS CodecHalDecodeScalability_DbgDumpCmdBuffer_G12(
     }
     else
     {
+        //calculate bufidx for getting secondary cmd buffer.
+        uint32_t dwBufIdxPlus1 = 0;
+        CODECHAL_DECODE_CHK_STATUS(CodecHalDecodeScalability_CalculateScdryCmdBufIndex_G12(pScalabilityState, &dwBufIdxPlus1));
+        cmdName = cmdName + "_secondary_" + std::to_string(dwBufIdxPlus1);
         CODECHAL_DECODE_CHK_STATUS(CodecHalDecodeScalability_GetVESecondaryCmdBuffer_G12(pScalabilityState, &ScdryCmdBuffer));
         pCmdBufferInUse = &ScdryCmdBuffer;
     }
@@ -635,7 +660,7 @@ MOS_STATUS CodecHalDecodeScalability_DbgDumpCmdBuffer_G12(
     CODECHAL_DECODE_CHK_STATUS_RETURN(debugInterface->DumpCmdBuffer(
         pCmdBufferInUse,
         CODECHAL_NUM_MEDIA_STATES,
-        "DEC"));
+        cmdName.c_str()));
 
 finish:
     return eStatus;
@@ -650,6 +675,7 @@ MOS_STATUS CodecHalDecodeScalability_FEBESync_G12(
     PMOS_INTERFACE                      pOsInterface;
     MhwMiInterface                      *pMiInterface;
     uint32_t                            HcpDecPhase;
+    uint32_t                            curPipeInUse = 0;
     MOS_STATUS                          eStatus = MOS_STATUS_SUCCESS;
 
     CODECHAL_DECODE_FUNCTION_ENTER;
@@ -711,6 +737,24 @@ MOS_STATUS CodecHalDecodeScalability_FEBESync_G12(
             MHW_MI_SAD_EQUAL_SDD,
             pCmdBufferInUse));
 
+        //add additional BEs Sync for two pipes
+        if (u8PipeNum == 2 && !phasedSubmission)
+        {
+            if (pScalabilityState->bIsRtMode)
+            {
+                curPipeInUse = pScalabilityState->u8RtCurPipe;
+            }
+            else
+            {
+                curPipeInUse = HcpDecPhase == CODECHAL_HCP_DECODE_PHASE_BE0 ? 0 : 1;
+            }
+            //pipe 0: resSemaMemBEsAdditional[0] + 1, pipe 1: resSemaMemBEsAdditional[1] + 1
+            CODECHAL_DECODE_CHK_STATUS(pScalabilityState->pHwInterface->SendMiAtomicDwordCmd(&pScalabilityState->resSemaMemBEsAdditional[curPipeInUse],
+                1,
+                MHW_MI_ATOMIC_INC,
+                pCmdBufferInUse));
+        }
+
         // Program some placeholder cmds to resolve the hazard between BEs sync
         MHW_MI_STORE_DATA_PARAMS dataParams;
         dataParams.pOsResource = &pScalabilityState->resDelayMinus;
@@ -722,9 +766,26 @@ MOS_STATUS CodecHalDecodeScalability_FEBESync_G12(
                 pCmdBufferInUse,
                 &dataParams));
         }
-
+        //additional Semaphore Wait: pipe 0 wait resSemaMemBEsAdditional[1] == 1, pipe 1 wait resSemaMemBEsAdditional[0] == 1
+        if (u8PipeNum == 2 && !phasedSubmission)
+        {
+            CODECHAL_DECODE_CHK_STATUS(pScalabilityState->pHwInterface->SendHwSemaphoreWaitCmd(
+                &pScalabilityState->resSemaMemBEsAdditional[CODECHAL_SCALABILITY_MAX_PIPE_INDEX_OF_TWO_PIPE - curPipeInUse],
+                1,
+                MHW_MI_SAD_EQUAL_SDD,
+                pCmdBufferInUse));
+        }
         //reset HW semaphore
         CODECHAL_DECODE_CHK_STATUS(pScalabilityState->pHwInterface->SendMiAtomicDwordCmd(&pScalabilityState->resSemaMemBEs, 1, MHW_MI_ATOMIC_DEC, pCmdBufferInUse));
+        //pipe 0 reset resSemaMemBEsAdditional[1], pipe 1 reset resSemaMemBEsAdditional[0]
+        if (u8PipeNum == 2 && !phasedSubmission)
+        {
+            CODECHAL_DECODE_CHK_STATUS(pScalabilityState->pHwInterface->SendMiAtomicDwordCmd(
+                &pScalabilityState->resSemaMemBEsAdditional[CODECHAL_SCALABILITY_MAX_PIPE_INDEX_OF_TWO_PIPE - curPipeInUse],
+                1,
+                MHW_MI_ATOMIC_DEC,
+                pCmdBufferInUse));
+        }
 
         if (!pScalabilityState->bIsRtMode)
         {
@@ -840,7 +901,8 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
     CodechalDecode                     *pDecoder,
     PCODECHAL_DECODE_SCALABILITY_STATE  pScalabilityStateBase,
     CodechalHwInterface                *hwInterface,
-    bool                                bShortFormat)
+    bool                                bShortFormat,
+    CodechalSetting                    *settings)
 {
     PMOS_VIRTUALENGINE_INTERFACE   pVEInterface;
     MOS_VIRTUALENGINE_INIT_PARAMS  VEInitParms;
@@ -887,44 +949,50 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_MODE_SWITCH_THRESHOLD1_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dwHcpDecModeSwtichTh1Width = UserFeatureData.u32Data;
 
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_MODE_SWITCH_THRESHOLD2_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dwHcpDecModeSwtichTh2Width = UserFeatureData.u32Data;
 
     // Reg key to control hevc real tile decoding
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
-        __MEDIA_USER_FEATURE_VALUE_DISABLE_HEVC_REALTILE_DECODE_ID_G12,
-        &UserFeatureData);
+        __MEDIA_USER_FEATURE_VALUE_DISABLE_HEVC_REALTILE_DECODE_ID,
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->bDisableRtMode = (UserFeatureData.u32Data != 0);
 
     // Reg key to control hevc real tile multi-phase decoding
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
-        __MEDIA_USER_FEATURE_VALUE_ENABLE_HEVC_REALTILE_MULTI_PHASE_DECODE_ID_G12,
-        &UserFeatureData);
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_HEVC_REALTILE_MULTI_PHASE_DECODE_ID,
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->bEnableRtMultiPhase = (UserFeatureData.u32Data != 0);
 
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_SCALABILITY_OVERRIDE_SPLIT_WIDTH_IN_MINCB,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dbgOvrdWidthInMinCb = UserFeatureData.u32Data;
 
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
-        __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_USER_PIPE_NUM_ID_G12,
-        &UserFeatureData);
+        __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_USER_PIPE_NUM_ID,
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dbgOverUserPipeNum = (uint8_t)UserFeatureData.u32Data;
 #endif
 
@@ -955,17 +1023,23 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
     }
 #endif
 
+    pScalabilityState->bFESeparateSubmissionVT = pScalabilityState->bFESeparateSubmission;
+
     if (pScalabilityState->bFESeparateSubmission)
     {
         MOS_GPU_CONTEXT         GpuContext = MOS_VE_CTXBASEDSCHEDULING_SUPPORTED(osInterface) ? MOS_GPU_CONTEXT_VIDEO : MOS_GPU_CONTEXT_VIDEO4;
         GpuContext                         = MOS_VE_MULTINODESCALING_SUPPORTED(osInterface) ? MOS_GPU_CONTEXT_VIDEO4 : GpuContext;
-        MOS_GPUCTX_CREATOPTIONS createOpts;
 
+        MOS_GPUCTX_CREATOPTIONS_ENHANCED createOpts;
+        createOpts.UsingSFC = settings->sfcInUseHinted && settings->downsamplingHinted
+                              && (MEDIA_IS_SKU(hwInterface->GetSkuTable(), FtrSFCPipe)
+                              && !MEDIA_IS_SKU(hwInterface->GetSkuTable(), FtrDisableVDBox2SFC));
         CODECHAL_DECODE_CHK_STATUS(osInterface->pfnCreateGpuContext(
-            osInterface,
-            GpuContext,
-            MOS_GPU_NODE_VIDEO,
-            &createOpts));
+              osInterface,
+              GpuContext,
+              MOS_GPU_NODE_VIDEO,
+              &createOpts));
+
         pScalabilityState->VideoContextForFE = GpuContext;
     }
 
@@ -999,7 +1073,8 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_ALWAYS_FRAME_SPLIT_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->bAlwaysFrameSplit = UserFeatureData.u32Data ? true : false;
 #endif
 
@@ -1032,7 +1107,7 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
 #endif
 
     pScalabilityState->sliceStateCLs = CODECHAL_SCALABILITY_SLICE_STATE_CACHELINES_PER_SLICE_TGL;
-    CODECHAL_DECODE_CHK_STATUS(CodecHalDecodeScalability_AllocateResources_FixedSizes(pScalabilityState));
+    CODECHAL_DECODE_CHK_STATUS(CodecHalDecodeScalability_AllocateResources_FixedSizes_G12(pScalabilityState));
 
 finish:
     return eStatus;
@@ -1047,6 +1122,7 @@ MOS_STATUS CodecHalDecodeScalability_AdvanceRealTilePass(
 
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalabilityStateBase);
     CODECHAL_DECODE_ASSERT(pScalabilityState->bIsRtMode);
+    CODECHAL_DECODE_ASSERT(pScalabilityState->u8RtCurPhase < pScalabilityState->u8RtPhaseNum);
 
     pScalabilityState->u8RtCurPipe++;
     if (pScalabilityState->u8RtCurPipe >= pScalabilityState->ucScalablePipeNum)
@@ -1055,8 +1131,6 @@ MOS_STATUS CodecHalDecodeScalability_AdvanceRealTilePass(
         pScalabilityState->u8RtCurPhase++;
     }
 
-    CODECHAL_DECODE_ASSERT(pScalabilityState->u8RtCurPhase < pScalabilityState->u8RtPhaseNum);
-
     return eStatus;
 }
 
@@ -1077,8 +1151,8 @@ MOS_STATUS CodecHalDecodeScalability_GetCurrentRealTileColumnId(
 MOS_STATUS CodecHalDecodeScalability_SetSfcState(
     PCODECHAL_DECODE_SCALABILITY_STATE          scalabilityStateBase,
     void                                       *picParams,
-    CODECHAL_RECTANGLE                         *srcRegion,
-    CODECHAL_RECTANGLE                         *dstRegion,
+    CodecRectangle                             *srcRegion,
+    CodecRectangle                             *dstRegion,
     PCODECHAL_DECODE_SFC_SCALABILITY_PARAMS     sfcScalabilityParams)
 {
     MOS_STATUS  eStatus = MOS_STATUS_SUCCESS;
@@ -1167,7 +1241,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
             }
             if (col == hevcPicParams->num_tile_columns_minus1)
             {
-                srcEndX = srcRegion->X + srcRegion->Width - 1;
+                srcEndX = srcRegion->m_x + srcRegion->m_width - 1;
             }
             else
             {
@@ -1200,7 +1274,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
         srcStartX *= maxCbSize;
         if (pipeIndex == scalabilityState->ucScalablePipeNum - 1)
         {
-            srcEndX = srcRegion->X + srcRegion->Width - 1;
+            srcEndX = srcRegion->m_x + srcRegion->m_width - 1;
         }
         else
         {
@@ -1213,7 +1287,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
             if (pipeIndex == 1)
             {
                 srcStartX = scalabilityState->dbgOvrdWidthInMinCb * minCbSize;
-                srcEndX = srcRegion->X + srcRegion->Width - 1;
+                srcEndX = srcRegion->m_x + srcRegion->m_width - 1;
             }
             else
             {
@@ -1232,14 +1306,14 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
         engMode = 0;
         tileType = 0;
         srcStartX = 0;
-        srcEndX = srcRegion->X + srcRegion->Width - 1;
+        srcEndX = srcRegion->m_x + srcRegion->m_width - 1;
     }
 
     // Clamp srcStartX, srcEndX into source region
-    if (srcStartX < srcRegion->X)
-        srcStartX = srcRegion->X;
-    if (srcEndX > srcRegion->X + srcRegion->Width - 1)
-        srcEndX = srcRegion->X + srcRegion->Width - 1;
+    if (srcStartX < srcRegion->m_x)
+        srcStartX = srcRegion->m_x;
+    if (srcEndX > srcRegion->m_x + srcRegion->m_width - 1)
+        srcEndX = srcRegion->m_x + srcRegion->m_width - 1;
 
     if (tileColumnIndex == 0)
     {
@@ -1249,16 +1323,16 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
     }
 
     ildbXOffset = (scalabilityState->Standard == CODECHAL_HEVC) ? 5 : 8;  // 1 : HEVC; 0 : VP9
-    oneBySf = (uint64_t)((double)((uint64_t)(srcRegion->Width) * 524288 / (dstRegion->Width)));
+    oneBySf = (uint64_t)((double)((uint64_t)(srcRegion->m_width) * 524288 / (dstRegion->m_width)));
 
     //------------------ start ildb offset correction -----------------------------//
     srcEndXTemp = srcEndX - ildbXOffset;
 
     //---------------------- destination startX determination logic ---------------//
-    if ((srcRegion->X + srcRegion->Width - 1) <= srcEndXTemp)
+    if ((srcRegion->m_x + srcRegion->m_width - 1) <= srcEndXTemp)
     {
         xOffset = 0;
-        tileEndX = (srcRegion->X + srcRegion->Width);
+        tileEndX = (srcRegion->m_x + srcRegion->m_width);
     }
     else
     {
@@ -1268,7 +1342,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
 
     while (true)
     {
-        if (srcEndXTemp - srcRegion->X < (xOffset + 1))
+        if (srcEndXTemp - srcRegion->m_x < (xOffset + 1))
         {
             dstEndX = 0;
             break;
@@ -1283,14 +1357,14 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
         {
             const uint32_t one_by_sf_fraction_precision = 19;
             const uint32_t beta_precision = 5;
-            uint32_t xPhaseShift = MOS_CLAMP_MIN_MAX(MOS_F_ROUND((((double)srcRegion->Width / dstRegion->Width - 1.0) / 2.0) * 524288.0F), -(1 << (4 + 19)), ((1 << (4 + 19)) - 1));
+            uint32_t xPhaseShift = MOS_CLAMP_MIN_MAX(MOS_F_ROUND((((double)srcRegion->m_width / dstRegion->m_width - 1.0) / 2.0) * 524288.0F), -(1 << (4 + 19)), ((1 << (4 + 19)) - 1));
 
             double tempDestCntx = (((double)scalabilityState->dstXLandingCount * (double)oneBySf) + xPhaseShift);
             if (tempDestCntx < 0)
             {
                 tempDestCntx = 0;
             }
-            xLandingPoint = (double)(((tempDestCntx + ((double)(1 << (one_by_sf_fraction_precision - beta_precision - 1)))) / 524288) + srcRegion->X);
+            xLandingPoint = (double)(((tempDestCntx + ((double)(1 << (one_by_sf_fraction_precision - beta_precision - 1)))) / 524288) + srcRegion->m_x);
         }
 
         if (xLandingPoint >= (double)(tileEndX - xOffset))
@@ -1312,7 +1386,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
     // Last column end at destination region right border.
     if (tileColumnIndex == scalabilityState->lastValidTileIndex)
     {
-        dstEndX = dstRegion->X + dstRegion->Width - 1;
+        dstEndX = dstRegion->m_x + dstRegion->m_width - 1;
     }
 
     if (tileColumnIndex <= scalabilityState->fistValidTileIndex)
@@ -1397,6 +1471,94 @@ MOS_STATUS CodecHalDecodeScalability_AllocateResources_VariableSizes_G12(
     return eStatus;
 }
 
+MOS_STATUS CodecHalDecodeScalability_AllocateResources_FixedSizes_G12(
+    PCODECHAL_DECODE_SCALABILITY_STATE_G12 pScalabilityState)
+{
+    PMOS_INTERFACE          pOsInterface;
+    MOS_ALLOC_GFXRES_PARAMS AllocParamsForBufferLinear;
+    MOS_LOCK_PARAMS         LockFlagsWriteOnly;
+    uint8_t *               pData = nullptr;
+    MOS_STATUS              eStatus = MOS_STATUS_SUCCESS;
+
+    CODECHAL_DECODE_FUNCTION_ENTER;
+
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalabilityState);
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalabilityState->pHwInterface);
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalabilityState->pHwInterface->GetOsInterface());
+
+    pOsInterface = pScalabilityState->pHwInterface->GetOsInterface();
+
+    MOS_ZeroMemory(&LockFlagsWriteOnly, sizeof(MOS_LOCK_PARAMS));
+    LockFlagsWriteOnly.WriteOnly = 1;
+
+    // initiate allocation paramters
+    MOS_ZeroMemory(&AllocParamsForBufferLinear, sizeof(MOS_ALLOC_GFXRES_PARAMS));
+    AllocParamsForBufferLinear.Type     = MOS_GFXRES_BUFFER;
+    AllocParamsForBufferLinear.TileType = MOS_TILE_LINEAR;
+    AllocParamsForBufferLinear.Format   = Format_Buffer;
+
+    CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalDecodeScalability_AllocateResources_FixedSizes(pScalabilityState));
+
+    //Allocate additional BEs Semaphore memory for two pipes to avoid race condition
+    if (!pOsInterface->phasedSubmission)
+    {
+        AllocParamsForBufferLinear.pBufName = "AdditionalBESemaphoreMemory";
+        AllocParamsForBufferLinear.dwBytes  = sizeof(uint32_t);
+        for (uint32_t i = 0; i < 2; i++)
+        {
+            eStatus = (MOS_STATUS)pOsInterface->pfnAllocateResource(
+                pOsInterface,
+                &AllocParamsForBufferLinear,
+                &pScalabilityState->resSemaMemBEsAdditional[i]);
+
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                CODECHAL_DECODE_ASSERTMESSAGE("Failed to allocate Additional BE Semaphore memory.");
+                return eStatus;
+            }
+
+            pData = (uint8_t *)pOsInterface->pfnLockResource(
+                pOsInterface,
+                &pScalabilityState->resSemaMemBEsAdditional[i],
+                &LockFlagsWriteOnly);
+
+            CODECHAL_DECODE_CHK_NULL_RETURN(pData);
+
+            MOS_ZeroMemory(pData, sizeof(uint32_t));
+
+            CODECHAL_DECODE_CHK_STATUS_RETURN(pOsInterface->pfnUnlockResource(
+                pOsInterface,
+                &pScalabilityState->resSemaMemBEsAdditional[i]));
+        }
+    }
+
+    return eStatus;
+}
+
+void CodecHalDecodeScalability_Destroy_G12(
+    PCODECHAL_DECODE_SCALABILITY_STATE_G12 pScalabilityState)
+{
+    PMOS_INTERFACE pOsInterface;
+
+    CODECHAL_DECODE_FUNCTION_ENTER;
+
+    CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(pScalabilityState);
+    CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(pScalabilityState->pHwInterface);
+    CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(pScalabilityState->pHwInterface->GetOsInterface());
+    pOsInterface = pScalabilityState->pHwInterface->GetOsInterface();
+
+    CodecHalDecodeScalability_Destroy(pScalabilityState);
+
+    for (int i = 0; i < 2; i++)
+    {
+        pOsInterface->pfnFreeResource(
+            pOsInterface,
+            &pScalabilityState->resSemaMemBEsAdditional[i]);
+    }
+
+    return;
+}
+
 MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
     PCODECHAL_DECODE_SCALABILITY_STATE         pScalState,
     PCODECHAL_DECODE_SCALABILITY_INIT_PARAMS   pInitParams)
@@ -1409,24 +1571,35 @@ MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalState);
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pVEInterface);
     CODECHAL_DECODE_CHK_NULL_RETURN(pInitParams);
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pHwInterface);
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pHwInterface->GetOsInterface());
 
     pVEInterface                                                     = pScalState->pVEInterface;
     pScalState->ucScalablePipeNum                                    = CODECHAL_DECODE_HCP_Legacy_PIPE_NUM_1;
     PCODECHAL_DECODE_SCALABILITY_STATE_G12       pScalStateG12        = static_cast<PCODECHAL_DECODE_SCALABILITY_STATE_G12>(pScalState);
     PCODECHAL_DECODE_SCALABILITY_INIT_PARAMS_G12 pInitParamsG12       = static_cast<PCODECHAL_DECODE_SCALABILITY_INIT_PARAMS_G12>(pInitParams);
-    uint8_t                                     u8MaxTileColumn      = HEVC_NUM_MAX_TILE_COLUMN;
-    bool                                        bCanEnableRealTile   = true;
+    uint8_t                                      u8MaxTileColumn      = HEVC_NUM_MAX_TILE_COLUMN;
+    bool                                         bCanEnableRealTile   = true;
+    bool                                         bCanEnableScalability = !pScalState->pHwInterface->IsDisableScalability();
+    PMOS_INTERFACE pOsInterface                                        = pScalState->pHwInterface->GetOsInterface();
+
 #if (_DEBUG || _RELEASE_INTERNAL)
     bCanEnableRealTile = !(static_cast<PCODECHAL_DECODE_SCALABILITY_STATE_G12>(pScalState))->bDisableRtMode;
     if (!pScalStateG12->bEnableRtMultiPhase)
         u8MaxTileColumn = 2;
+    if(!bCanEnableScalability
+        && pOsInterface
+        && (pOsInterface->bHcpDecScalabilityMode == MOS_SCALABILITY_ENABLE_MODE_USER_FORCE))
+    {
+        bCanEnableScalability = true;
+    }
 #endif
     bCanEnableRealTile = bCanEnableRealTile && pInitParamsG12->bIsTileEnabled && (pInitParams->u8NumTileColumns > 1) &&
-                         (pInitParams->u8NumTileColumns <= u8MaxTileColumn) && (pInitParams->u8NumTileRows <= HEVC_NUM_MAX_TILE_ROW);
+                         (pInitParams->u8NumTileColumns <= u8MaxTileColumn) && (pInitParams->u8NumTileRows <= HEVC_NUM_MAX_TILE_ROW) &&
+                         pInitParamsG12->bHasSubsetParams;
 
-    if (pInitParams->usingSFC)
+    if (pInitParams->usingSFC || !bCanEnableScalability)
     {
-        //using SFC can only work in single pipe mode.
         return MOS_STATUS_SUCCESS;
     }
 
@@ -1464,11 +1637,11 @@ MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
                         pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_SCALABLE_PIPE_NUM_2;
                     }
                 }
-                else if ((!CodechalDecodeNonRextFormat(pInitParams->format)
+                else if ((!pInitParams->usingHistogram) && ((!CodechalDecodeNonRextFormat(pInitParams->format)
                                     && CodechalDecodeResolutionEqualLargerThan4k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel))
                                 || (CodechalDecodeNonRextFormat(pInitParams->format)
                                     && CodechalDecodeResolutionEqualLargerThan5k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel))
-                                || (bCanEnableRealTile && !pInitParams->usingSecureDecode))
+                                || (bCanEnableRealTile && (!pOsInterface->osCpInterface->IsCpEnabled() || pOsInterface->bCanEnableSecureRt))))
                 {
                     pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_SCALABLE_PIPE_NUM_2;
                 }
@@ -1484,33 +1657,7 @@ MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
             }
             else
             {
-                if (pScalState->dwHcpDecModeSwtichTh1Width != 0 &&
-                    pScalState->dwHcpDecModeSwtichTh2Width != 0)
-                {
-                    if (pInitParams->u32PicWidthInPixel >= pScalState->dwHcpDecModeSwtichTh2Width)
-                    {
-                        pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_SCALABLE_PIPE_NUM_RESERVED;
-                    }
-                    else if (pInitParams->u32PicWidthInPixel >= pScalState->dwHcpDecModeSwtichTh1Width)
-                    {
-                        pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_SCALABLE_PIPE_NUM_2;
-                    }
-                }
-                else
-                {
-                    if ((pInitParams->u32PicWidthInPixel * pInitParams->u32PicHeightInPixel) >= (CODECHAL_HCP_DECODE_SCALABLE_THRESHOLD4_WIDTH * CODECHAL_HCP_DECODE_SCALABLE_THRESHOLD4_HEIGHT))
-                    {
-                        pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_SCALABLE_PIPE_NUM_RESERVED;
-                    }
-                    else if ((!CodechalDecodeNonRextFormat(pInitParams->format)
-                                    && CodechalDecodeResolutionEqualLargerThan4k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel))
-                                || (CodechalDecodeNonRextFormat(pInitParams->format)
-                                    && CodechalDecodeResolutionEqualLargerThan5k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel))
-                                || (bCanEnableRealTile && !pInitParams->usingSecureDecode))
-                    {
-                        pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_SCALABLE_PIPE_NUM_2;
-                    }
-                }
+                pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_Legacy_PIPE_NUM_1;
             }
         }
     }
@@ -1568,14 +1715,16 @@ MOS_STATUS CodechalDecodeScalability_DebugOvrdDecidePipeNum_G12(
     PCODECHAL_DECODE_SCALABILITY_STATE         pScalState)
 {
     PMOS_VIRTUALENGINE_INTERFACE pVEInterface;
-    MOS_STATUS                   eStatus = MOS_STATUS_SUCCESS;
-
+    MOS_STATUS                   eStatus        = MOS_STATUS_SUCCESS;
+    PMOS_INTERFACE               pOsInterface   = nullptr;
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalState);
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pVEInterface);
 
     pVEInterface = pScalState->pVEInterface;
+    pOsInterface = pVEInterface->pOsInterface;
+    CODECHAL_DECODE_CHK_NULL_RETURN(pOsInterface);
 
-    if (g_apoMosEnabled)
+    if (pOsInterface->apoMosEnabled)
     {
         CODECHAL_DECODE_CHK_NULL_RETURN(pVEInterface->veInterface);
         auto veInterface = pVEInterface->veInterface;
