@@ -1,17 +1,23 @@
 /*
-// Copyright (C) 2018-2019, Intel Corporation
-//
-// Licensed under the Apache License,Version 2.0(the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//      http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing,software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
+* Copyright (c) 2018-2020, Intel Corporation
+*
+* Permission is hereby granted, free of charge, to any person obtaining a
+* copy of this software and associated documentation files (the "Software"),
+* to deal in the Software without restriction, including without limitation
+* the rights to use, copy, modify, merge, publish, distribute, sublicense,
+* and/or sell copies of the Software, and to permit persons to whom the
+* Software is furnished to do so, subject to the following conditions:
+*
+* The above copyright notice and this permission notice shall be included
+* in all copies or substantial portions of the Software.
+*
+* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+* OTHER DEALINGS IN THE SOFTWARE.
 */
 //!
 //! \file     codechal_decode_scalability_g12.h
@@ -50,17 +56,6 @@ inline static uint8_t CodecHalDecodeMaxNumPipesInUseG12(uint8_t vdboxNum)
     return maxNumPipesInUs;
 }
 
-//!
-//! \enum   HCP_RT_PHASE_INDICATOR
-//! \brief  Phase indicator for HEVC multiple phase
-//!
-typedef enum
-{
-    HCP_RT_FIRST_PHASE = 0,                                //!< First phase
-    HCP_RT_MIDDLE_PHASE = 1,                                //!< Middle phase
-    HCP_RT_LAST_PHASE = 2                                 //!< Last phase
-} HCP_RT_PHASE_INDICATOR;
-
 typedef struct _CODECHAL_DECODE_SCALABILITY_INIT_PARAMS_G12 : public _CODECHAL_DECODE_SCALABILITY_INIT_PARAMS
 {
     bool             bIsTileEnabled;                 //!< The picture can be partitioned into tiles
@@ -100,15 +95,15 @@ typedef struct _CODECHAL_DECODE_SCALABILITY_STATE_G12 : public _CODECHAL_DECODE_
 {                                                                                                                      \
     if (m_scalabilityState->u8RtCurPhase == 0)                                                                         \
     {                                                                                                                  \
-        PhaseIndicator = HCP_RT_FIRST_PHASE;                                                                           \
+        PhaseIndicator = MHW_VDBOX_HCP_RT_FIRST_PHASE;                                                                 \
     }                                                                                                                  \
     else if (m_scalabilityState->u8RtCurPhase == m_scalabilityState->u8RtPhaseNum - 1)                                 \
     {                                                                                                                  \
-        PhaseIndicator = HCP_RT_LAST_PHASE;                                                                            \
+        PhaseIndicator = MHW_VDBOX_HCP_RT_LAST_PHASE;                                                                  \
     }                                                                                                                  \
     else                                                                                                               \
     {                                                                                                                  \
-        PhaseIndicator = HCP_RT_MIDDLE_PHASE;                                                                          \
+        PhaseIndicator = MHW_VDBOX_HCP_RT_MIDDLE_PHASE;                                                                \
     }                                                                                                                  \
 }while (0)
 
@@ -182,7 +177,7 @@ do
         if(((m_hcpDecPhase - CODECHAL_HCP_DECODE_PHASE_FE) <= m_scalabilityState->ucScalablePipeNum) &&                 \
            (m_hcpDecPhase > CODECHAL_HCP_DECODE_PHASE_BE0))                                                             \
         {                                                                                                               \
-            CODECHAL_DECODE_ASSERT(m_scalabilityState->ucScalablePipeNum > 2);                                          \
+            CODECHAL_DECODE_ASSERT(m_scalabilityState->ucScalablePipeNum >= 2);                                          \
             EngineMode    = (m_scalabilityState->ucScalablePipeNum == (m_hcpDecPhase - CODECHAL_HCP_DECODE_PHASE_FE)) ? \
                               MHW_VDBOX_HCP_MULTI_ENGINE_MODE_RIGHT : MHW_VDBOX_HCP_MULTI_ENGINE_MODE_MIDDLE;           \
             PipeWorkMode  = MHW_VDBOX_HCP_PIPE_WORK_MODE_CODEC_BE;                                                      \
@@ -394,8 +389,8 @@ MOS_STATUS CodecHalDecodeScalability_GetCurrentRealTileColumnId(
 MOS_STATUS CodecHalDecodeScalability_SetSfcState(
     PCODECHAL_DECODE_SCALABILITY_STATE          scalabilityState,
     void                                       *picParams,
-    CODECHAL_RECTANGLE                         *srcRegion,
-    CODECHAL_RECTANGLE                         *dstRegion,
+    CodecRectangle                             *srcRegion,
+    CodecRectangle                             *dstRegion,
     PCODECHAL_DECODE_SFC_SCALABILITY_PARAMS     sfcScalabilityParams);
 
 MOS_STATUS CodecHalDecodeScalability_AllocateResources_VariableSizes_G12(
