@@ -77,6 +77,18 @@ CodecHalHevcMbencG12::~CodecHalHevcMbencG12() {
         m_intraDistKernel = nullptr;
     }
 
+    if (m_hmeKernel)
+    {
+        MOS_Delete(m_hmeKernel);
+        m_hmeKernel = nullptr;
+    }
+
+    if (m_swScoreboardState)
+    {
+        MOS_Delete(m_swScoreboardState);
+        m_swScoreboardState = nullptr;
+    }
+
     DestroyMDFResources();
 }
 
@@ -360,6 +372,12 @@ MOS_STATUS CodecHalHevcMbencG12::FreeEncResources()
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(CodechalEncHevcStateG12::FreeEncResources());
 
+    if (m_threadSpace)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_cmDev->DestroyThreadSpace(m_threadSpace));
+        m_threadSpace = nullptr;
+    }
+
     return eStatus;
 }
 
@@ -698,7 +716,6 @@ MOS_STATUS CodecHalHevcMbencG12::SetupKernelArgsB()
         CODECHAL_ENCODE_CHK_STATUS_RETURN(cmKrn->SetKernelArg(idx++, sizeof(SurfaceIndex), surfIndex));
 
         //load Balance surface
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_loadBalance->WriteSurface(m_FrameBalance, nullptr));
         CODECHAL_ENCODE_CHK_STATUS_RETURN(m_loadBalance->GetIndex(surfIndex));
         CODECHAL_ENCODE_CHK_STATUS_RETURN(cmKrn->SetKernelArg(idx++, sizeof(SurfaceIndex), surfIndex));
 
@@ -846,9 +863,6 @@ MOS_STATUS CodecHalHevcMbencG12::EncodeMbEncKernel(
     CODECHAL_ENCODE_FUNCTION_ENTER;
     MOS_STATUS  eStatus = MOS_STATUS_SUCCESS;
 
-    CODECHAL_WALKER_CODEC_PARAMS    walkerCodecParams;
-    CODECHAL_WALKER_DEGREE          walkerDegree;
-    MHW_WALKER_PARAMS               walkerParams;
     uint32_t                        walkerResolutionX, walkerResolutionY, maxthreadWidth, maxthreadHeight;
 
     PerfTagSetting perfTag;
@@ -986,13 +1000,22 @@ MOS_STATUS CodecHalHevcMbencG12::EncodeMbEncKernel(
         return eStatus;
     }
 
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(m_cmDev->CreateThreadSpace(
-        maxthreadWidth,
-        maxthreadHeight,
-        m_threadSpace));
+    if (m_threadSpace != nullptr && m_resolutionChanged)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_cmDev->DestroyThreadSpace(m_threadSpace));
+        m_threadSpace = nullptr;
+    }
 
-    m_threadSpace->SetThreadSpaceColorCount(totalColor);
+    if (m_threadSpace == nullptr)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_cmDev->CreateThreadSpace(
+                                              maxthreadWidth,
+                                              maxthreadHeight,
+                                              m_threadSpace));
 
+        m_threadSpace->SetThreadSpaceColorCount(totalColor);
+    }
+    
     switch (m_swScoreboardState->GetDependencyPattern())
     {
     case dependencyWavefront26Degree:
@@ -1228,13 +1251,13 @@ MOS_STATUS CodecHalHevcMbencG12::InitCurbeDataB()
         curbe.LastFrameIsIntra = false;
     }
 
-    curbe.SliceType             = (m_hevcPicParams->CodingType == P_TYPE) ? PicCodingTypeToSliceType(B_TYPE) : PicCodingTypeToSliceType(m_hevcPicParams->CodingType);
+    curbe.SliceType             = PicCodingTypeToSliceType(m_hevcPicParams->CodingType);
     curbe.TemporalMvpEnableFlag = m_hevcSliceParams->slice_temporal_mvp_enable_flag;
     curbe.CollocatedFromL0Flag  = m_hevcSliceParams->collocated_from_l0_flag;
     curbe.theSameRefList        = m_sameRefList;
     curbe.IsLowDelay            = m_lowDelay;
     curbe.NumRefIdxL0           = m_hevcSliceParams->num_ref_idx_l0_active_minus1 + 1;
-    curbe.NumRefIdxL1           = m_hevcSliceParams->num_ref_idx_l1_active_minus1 + 1;
+    curbe.NumRefIdxL1           = (curbe.SliceType == CODECHAL_ENCODE_HEVC_P_SLICE) ? 0 : (m_hevcSliceParams->num_ref_idx_l1_active_minus1 + 1);
     if (m_hevcSeqParams->TargetUsage == 1)
     {
         // MaxNumMergeCand C Model uses 4 for TU1, 
@@ -1250,14 +1273,14 @@ MOS_STATUS CodecHalHevcMbencG12::InitCurbeDataB()
 
     int32_t tbRefListL0[CODECHAL_ENCODE_HEVC_NUM_MAX_VME_L0_REF_G10] = { 0 }, tbRefListL1[CODECHAL_ENCODE_HEVC_NUM_MAX_VME_L1_REF_G10] = { 0 };
     curbe.FwdPocNumber_L0_mTb_0 = tbRefListL0[0] = ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[0][0]);
-    curbe.BwdPocNumber_L1_mTb_0 = tbRefListL1[0] = ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[1][0]);
+    curbe.BwdPocNumber_L1_mTb_0 = tbRefListL1[0] = (curbe.SliceType == CODECHAL_ENCODE_HEVC_P_SLICE) ? ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[0][0]) : ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[1][0]);
     curbe.FwdPocNumber_L0_mTb_1 = tbRefListL0[1] = ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[0][1]);
-    curbe.BwdPocNumber_L1_mTb_1 = tbRefListL1[1] = ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[1][1]);
+    curbe.BwdPocNumber_L1_mTb_1 = tbRefListL1[1] = (curbe.SliceType == CODECHAL_ENCODE_HEVC_P_SLICE) ? ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[0][1]) : ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[1][1]);
 
     curbe.FwdPocNumber_L0_mTb_2 = tbRefListL0[2] = ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[0][2]);
-    curbe.BwdPocNumber_L1_mTb_2 = tbRefListL1[2] = ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[1][2]);
+    curbe.BwdPocNumber_L1_mTb_2 = tbRefListL1[2] = (curbe.SliceType == CODECHAL_ENCODE_HEVC_P_SLICE) ? ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[0][2]) : ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[1][2]);
     curbe.FwdPocNumber_L0_mTb_3 = tbRefListL0[3] = ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[0][3]);
-    curbe.BwdPocNumber_L1_mTb_3 = tbRefListL1[3] = ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[1][3]);
+    curbe.BwdPocNumber_L1_mTb_3 = tbRefListL1[3] = (curbe.SliceType == CODECHAL_ENCODE_HEVC_P_SLICE) ? ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[0][3]) : ComputeTemporalDifferent(m_hevcSliceParams->RefPicList[1][3]);
 
     curbe.RefFrameWinHeight = m_frameHeight;
     curbe.RefFrameWinWidth = m_frameWidth;
@@ -1454,6 +1477,19 @@ MOS_STATUS CodecHalHevcMbencG12::InitCurbeDataB()
         m_initEncConstTable = false;
     }
 
+    if (m_resolutionChanged)
+    {
+        m_initEncLoadBalence = true;
+    }
+
+    if (m_initEncLoadBalence)
+    {
+        // Initialize the Enc Constant Table surface
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_loadBalance->WriteSurface((unsigned char *)m_FrameBalance, nullptr, sizeof(m_FrameBalance)));
+
+        m_initEncLoadBalence = false;
+    }
+
     return eStatus;
 }
 
