@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2019, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -46,12 +46,15 @@ CodechalKernelHmeMdfG12::CodechalKernelHmeMdfG12(
 
 CodechalKernelHmeMdfG12::~CodechalKernelHmeMdfG12()
 {
+    ReleaseResources();
 }
 
 MOS_STATUS CodechalKernelHmeMdfG12::ReleaseResources()
 {
     CODECHAL_ENCODE_FUNCTION_ENTER;
 
+    CODECHAL_ENCODE_CHK_NULL_RETURN(m_encoder->m_cmDev);
+
     DestroyYUVSurfaces(m_HME4xYUVInfo);
     DestroyYUVSurfaces(m_HME16xYUVInfo);
     DestroyYUVSurfaces(m_HME32xYUVInfo);
@@ -220,28 +223,52 @@ MOS_STATUS CodechalKernelHmeMdfG12::Execute(CurbeParam &curbeParam, SurfaceParam
 
     if (m_16xMeInUse)
     {
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(cmDev->CreateThreadSpace(
-            xResolution,
-            yResolution,
-            m_threadSpace16x));
+        if(m_encoder->m_resolutionChanged && m_threadSpace16x != nullptr)
+        {
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(cmDev->DestroyThreadSpace(m_threadSpace16x));
+            m_threadSpace16x = nullptr;
+        }
+        if (m_threadSpace16x == nullptr)
+        {
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(cmDev->CreateThreadSpace(
+                                                  xResolution,
+                                                  yResolution,
+                                                  m_threadSpace16x));
+        }
         threadSpace = m_threadSpace16x;
         cmKrn = m_cmKrnME16x;
     }
     else if (m_32xMeInUse)
     {
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(cmDev->CreateThreadSpace(
-            xResolution,
-            yResolution,
-            m_threadSpace32x));
+        if(m_encoder->m_resolutionChanged && m_threadSpace32x != nullptr)
+        {
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(cmDev->DestroyThreadSpace(m_threadSpace32x));
+            m_threadSpace32x = nullptr;
+        }
+        if (m_threadSpace32x == nullptr)
+        {
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(cmDev->CreateThreadSpace(
+                                                  xResolution,
+                                                  yResolution,
+                                                  m_threadSpace32x));
+        }
         threadSpace = m_threadSpace32x;
         cmKrn = m_cmKrnME32x;
     }
     else
     {
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(cmDev->CreateThreadSpace(
-            xResolution,
-            yResolution,
-            m_threadSpace4x));
+        if(m_encoder->m_resolutionChanged && m_threadSpace4x != nullptr)
+        {
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(cmDev->DestroyThreadSpace(m_threadSpace4x));
+            m_threadSpace4x = nullptr;
+        }
+        if (m_threadSpace4x == nullptr)
+        {
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(cmDev->CreateThreadSpace(
+                                                  xResolution,
+                                                  yResolution,
+                                                  m_threadSpace4x));
+        }
         threadSpace = m_threadSpace4x;
         cmKrn = m_cmKrnME4x;
     }
@@ -546,7 +573,6 @@ MOS_STATUS CodechalKernelHmeMdfG12::SetupSurfaces()
     uint8_t      currVDirection = (!currFieldPicture) ? CODECHAL_VDIRECTION_FRAME : ((currBottomField) ? CODECHAL_VDIRECTION_BOT_FIELD : CODECHAL_VDIRECTION_TOP_FIELD);
 
     HmeYUVInfo *YuvInfo = nullptr;
-    PMOS_SURFACE psurface = nullptr;
    
     if (m_32xMeInUse)
     {
@@ -810,8 +836,7 @@ MOS_STATUS CodechalKernelHmeMdfG12::SetupKernelArgs(CmKernel *cmKrn)
     }
     else
     {
-        // bwd ref surfaces. if not provided, set to previous surface
-        cmKrn->SetKernelArg(idx++, sizeof(SurfaceIndex), YuvInfo->VMEFwdIdx);
+        cmKrn->SetKernelArg(idx++, sizeof(SurfaceIndex), (SurfaceIndex *)CM_NULL_SURFACE);
     }
 
     if (m_surfaceParam.vdencStreamInEnabled && m_4xMeInUse)
