@@ -53,8 +53,6 @@ CmDeviceRT::~CmDeviceRT()
     m_mosContext->SkuTable.reset();
     m_mosContext->WaTable.reset();
 
-    DestructCommon();
-
     DestroyAuxDevice();
 };
 
@@ -104,22 +102,29 @@ int32_t CmDeviceRT::Create(MOS_CONTEXT *umdContext,
 //! OUTPUT :
 //!     CM_SUCCESS if CmDevice_RT is successfully destroyed.
 //*-----------------------------------------------------------------------------
-int32_t CmDeviceRT::Destroy(CmDeviceRT* &device)
+int32_t CmDeviceRT::Destroy(CmDeviceRT*& device)
 {
-    INSERT_API_CALL_LOG();
+    INSERT_API_CALL_LOG(device->GetHalState());
 
     int32_t result = CM_SUCCESS;
-
     int32_t refCount = device->Release();
 
     if (refCount == 0)
     {
+        //check CmDevice remaining memory objects count and return 4bit encoded value
+        result = device->CheckObjectCount();
+        //destory remaining CM objects
+        device->DestructCommon();
+
         CmSafeDelete(device);
     }
 
+    //if return value is non-zero, return memory object counters 4 bit encoded value
     return result;
 }
 
+
+
 //*-----------------------------------------------------------------------------
 //| Purpose:    Initialize the OS-Specific part in the Initialize() function
 //| Returns:    None.
@@ -212,7 +217,7 @@ CM_RT_API int32_t CmDeviceRT::CreateSurface2D(VASurfaceID vaSurface,
                                               VADriverContext *vaDriverCtx,
                                               CmSurface2D* & surface)
 {
-    INSERT_API_CALL_LOG();
+    INSERT_API_CALL_LOG(GetHalState());
 
     MOS_RESOURCE mosResource;
     int32_t hr = CmFillMosResource( vaSurface, vaDriverCtx, &mosResource);
@@ -596,7 +601,7 @@ int32_t CmDeviceRT::ReadVtuneProfilingFlag()
 CM_RT_API int32_t CmDeviceRT::CreateSurface2D(PMOS_RESOURCE mosResource,
                                               CmSurface2D* & surface)
 {
-    INSERT_API_CALL_LOG();
+    INSERT_API_CALL_LOG(GetHalState());
 
     if (mosResource == nullptr)
     {
@@ -624,7 +629,7 @@ CM_RT_API int32_t CmDeviceRT::CreateSurface2D(uint32_t width,
                                               CM_SURFACE_FORMAT format,
                                               CmSurface2D* & surface)
 {
-    INSERT_API_CALL_LOG();
+    INSERT_API_CALL_LOG(GetHalState());
 
     CLock locker(m_criticalSectionSurface);
 
@@ -642,7 +647,7 @@ int32_t CmDeviceRT::CreateSurface2D(PMOS_RESOURCE mosResource,
                                     bool isCmCreated,
                                     CmSurface2D* & surface)
 {
-    INSERT_API_CALL_LOG();
+    INSERT_API_CALL_LOG(GetHalState());
 
     if (mosResource == nullptr)
     {
