@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2019, Intel Corporation
+* Copyright (c) 2017-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -128,6 +128,7 @@ uint8_t DdiEncodeAvc::ConvertSliceStruct(uint32_t vaSliceStruct)
         return CODECHAL_SLICE_STRUCT_POW2ROWS;
     case VA_ENC_SLICE_STRUCTURE_ARBITRARY_MACROBLOCKS:
         return CODECHAL_SLICE_STRUCT_ARBITRARYMBSLICE;
+    case VA_ENC_SLICE_STRUCTURE_EQUAL_MULTI_ROWS:
     case VA_ENC_SLICE_STRUCTURE_EQUAL_ROWS:
         return CODECHAL_SLICE_STRUCT_ROWSLICE;
     default:
@@ -241,7 +242,9 @@ VAStatus DdiEncodeAvc::ParseMiscParamRC(void *data)
     picParams->ucMaximumQP = encMiscParamRC->max_qp;
     if (picParams->ucMaximumQP == 0 && picParams->ucMinimumQP)
         picParams->ucMaximumQP = 51;
-
+#if VA_CHECK_VERSION(1, 10, 0)
+    picParams->TargetFrameSize = encMiscParamRC->target_frame_size;
+#endif
     if ((VA_RC_CBR == m_encodeCtx->uiRCMethod) || ((VA_RC_CBR | VA_RC_MB) == m_encodeCtx->uiRCMethod))
     {
         seqParams->MaxBitRate = seqParams->TargetBitRate;
@@ -550,32 +553,19 @@ VAStatus DdiEncodeAvc::ParseMiscParamQualityLevel(void *data)
     VAEncMiscParameterBufferQualityLevel *vaEncMiscParamQualityLevel = (VAEncMiscParameterBufferQualityLevel *)data;
 
     m_encodeCtx->targetUsage = (uint8_t)vaEncMiscParamQualityLevel->quality_level;
-    uint8_t qualityUpperBoundary = TARGETUSAGE_BEST_SPEED;
-#ifdef _FULL_OPEN_SOURCE
-    if (!GFX_IS_PRODUCT(m_encodeCtx->pMediaCtx->platform, IGFX_ICELAKE_LP))
-        qualityUpperBoundary = 5;
-#endif
+
     // check if TU setting is valid, otherwise change to default
-    if ((m_encodeCtx->targetUsage > qualityUpperBoundary) || (0 == m_encodeCtx->targetUsage))
+    if ((m_encodeCtx->targetUsage > TARGETUSAGE_BEST_SPEED) || (0 == m_encodeCtx->targetUsage))
     {
         m_encodeCtx->targetUsage = TARGETUSAGE_RT_SPEED;
-        DDI_ASSERTMESSAGE("Quality Level setting from application is not correct, should be in (0,%d].", qualityUpperBoundary);
-        return VA_STATUS_SUCCESS;
+        DDI_ASSERTMESSAGE("Quality Level setting from application is not correct, should be in (0,%d].", TARGETUSAGE_BEST_SPEED);
     }
 
 #ifdef _FULL_OPEN_SOURCE
-    if (!GFX_IS_PRODUCT(m_encodeCtx->pMediaCtx->platform, IGFX_ICELAKE_LP))
+    if (!GFX_IS_PRODUCT(m_encodeCtx->pMediaCtx->platform, IGFX_ICELAKE_LP) && m_encodeCtx->targetUsage <= 3)
     {
-        if (m_encodeCtx->targetUsage >= 1 && m_encodeCtx->targetUsage <= 2)
-        {
-            m_encodeCtx->targetUsage = 4;
-        }
-        else if (m_encodeCtx->targetUsage >= 3 &&m_encodeCtx->targetUsage <= 5)
-        {
-            m_encodeCtx->targetUsage = 7;
-        }
+        m_encodeCtx->targetUsage = 4;
     }
-
 #endif
 
     return VA_STATUS_SUCCESS;
@@ -935,7 +925,7 @@ VAStatus DdiEncodeAvc::RenderPicture(
             break;
 
         case VAEncPackedHeaderDataBufferType:
-            vaStatus = ParsePackedHeaderData(data);
+            DDI_CHK_STATUS(ParsePackedHeaderData(data), VA_STATUS_ERROR_INVALID_BUFFER);
             break;
 
         case VAEncMiscParameterBufferType:
@@ -1466,6 +1456,7 @@ VAStatus DdiEncodeAvc::ParsePicParams(
     picParams->transform_8x8_mode_flag         = pic->pic_fields.bits.transform_8x8_mode_flag;
     picParams->pic_order_present_flag          = pic->pic_fields.bits.pic_order_present_flag;
     picParams->pic_scaling_matrix_present_flag = pic->pic_fields.bits.pic_scaling_matrix_present_flag;
+    picParams->bDisplayFormatSwizzle           = NeedDisplayFormatSwizzle(rtTbl->pCurrentRT);
     for (uint32_t i = 0; i < 12; i++)
     {
         picParams->pic_scaling_list_present_flag[i] = pic->pic_fields.bits.pic_scaling_matrix_present_flag;
