@@ -250,8 +250,7 @@ VAStatus DdiEncodeBase::StatusReport(
         {
             bool inlineEncodeStatusUpdate;
             CodechalEncoderState *encoder = dynamic_cast<CodechalEncoderState *>(m_encodeCtx->pCodecHal);
-            DDI_CHK_NULL(encoder, "Null codechal encoder", VA_STATUS_ERROR_INVALID_CONTEXT);
-            inlineEncodeStatusUpdate = encoder->m_inlineEncodeStatusUpdate;
+            inlineEncodeStatusUpdate = encoder == nullptr ? false : encoder->m_inlineEncodeStatusUpdate;
 
             if (inlineEncodeStatusUpdate)
             {
@@ -285,7 +284,7 @@ VAStatus DdiEncodeBase::StatusReport(
         }
         else if (CODECHAL_STATUS_ERROR == encodeStatusReport[0].CodecStatus)
         {
-            DDI_NORMALMESSAGE("Encoding failure due to HW issue");
+            DDI_ASSERTMESSAGE("Encoding failure due to HW issue");
             m_encodeCtx->BufMgr.pCodedBufferSegment->buf  = DdiMediaUtil_LockBuffer(mediaBuf, MOS_LOCKFLAG_READONLY);
             m_encodeCtx->BufMgr.pCodedBufferSegment->size = 0;
             m_encodeCtx->BufMgr.pCodedBufferSegment->status |= VA_CODED_BUF_STATUS_BAD_BITSTREAM;
@@ -1243,6 +1242,19 @@ VAStatus DdiEncodeBase::CreateBuffer(
         }
         break;
     }
+#if VA_CHECK_VERSION(1, 10, 0)
+    case VAContextParameterUpdateBufferType:
+    {
+        bufSize       = size;
+        if (bufSize < sizeof(VAContextParameterUpdateBuffer))
+        {
+            va = VA_STATUS_ERROR_INVALID_PARAMETER;
+            CleanUpBufferandReturn(buf);
+            return va;
+        }
+        break;
+    }
+#endif
     default:
     {
         bufSize = size * elementsNum;
@@ -1316,7 +1328,20 @@ VAStatus DdiEncodeBase::CreateBuffer(
 
     DdiMediaUtil_LockBuffer(buf, MOS_LOCKFLAG_WRITEONLY | MOS_LOCKFLAG_READONLY);
 
-    MOS_STATUS eStatus = MOS_SecureMemcpy((void*)(buf->pData + buf->uiOffset), bufSize, (void*)data, bufSize);
+    // HW may use bigger than 64 pitch alignment for 2D. In such a case linear copying spoils the data
+    // and has to be executed line by line. 'size' is in fact input data pitch.
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+    if (elementsNum > 1 && buf->format == Media_Format_2DBuffer && size < buf->uiPitch)
+    {
+        uint8_t *pDst = buf->pData + buf->uiOffset;
+        uint8_t *pSrc = (uint8_t *) data;
+        for (int32_t i = 0; i < elementsNum && eStatus == MOS_STATUS_SUCCESS; i++)
+            eStatus = MOS_SecureMemcpy(pDst + i*buf->uiPitch, size, pSrc + i*size, size);
+    }
+    else
+    {
+        eStatus = MOS_SecureMemcpy((void*)(buf->pData + buf->uiOffset), bufSize, (void*)data, bufSize);
+    }
 
     DdiMediaUtil_UnlockBuffer(buf);
 
