@@ -84,6 +84,8 @@ MOS_STATUS RenderHal_GetSurfaceInfo(
     pSurface->dwQPitch        = ResDetails.dwQPitch;
     pSurface->dwDepth         = ResDetails.dwDepth;
     pSurface->TileType        = ResDetails.TileType;
+    pSurface->TileModeGMM     = ResDetails.TileModeGMM;
+    pSurface->bGMMTileEnabled = ResDetails.bGMMTileEnabled;
     pSurface->bOverlay        = ResDetails.bOverlay;
     pSurface->bFlipChain      = ResDetails.bFlipChain;
     pSurface->Format          = ResDetails.Format;
