@@ -242,6 +242,10 @@ mosdrmIoctl(int fd, unsigned long request, void *arg)
                     *(int *)(gp->value) = DeviceConfigTable[DevIdx].has_exec_softpin;
                     ret = 0;
                     break;
+                case I915_PARAM_HAS_EXEC_ASYNC:
+                    *(int *)(gp->value) = DeviceConfigTable[DevIdx].has_exec_async;
+                    ret = 0;
+                    break;
                 case I915_PARAM_NUM_FENCES_AVAIL:
                     *(int *)(gp->value) = DeviceConfigTable[DevIdx].num_fences_avail;
                     ret = 0;
@@ -313,6 +317,15 @@ mosdrmIoctl(int fd, unsigned long request, void *arg)
             ret = 0;
         }
             break;
+        case DRM_IOCTL_I915_GEM_CONTEXT_CREATE_EXT:
+        {
+            typedef struct drm_i915_gem_context_create_ext create_t;
+            create_t* create = (create_t *)arg;
+            create->ctx_id = 1;
+            ret = 0;
+        }
+            break;
+
         case DRM_IOCTL_I915_GEM_USERPTR:
         case DRM_IOCTL_I915_GEM_CONTEXT_DESTROY:
         case DRM_IOCTL_GEM_CLOSE:
@@ -344,6 +357,18 @@ mosdrmIoctl(int fd, unsigned long request, void *arg)
             ret = -1;
         }
         break;
+        case DRM_IOCTL_I915_GEM_VM_CREATE:
+        {
+            struct drm_i915_gem_vm_control * vm = (struct drm_i915_gem_vm_control *)arg;
+            vm->vm_id = 1;
+            ret = 0;
+        }
+        break;
+        case DRM_IOCTL_I915_GEM_VM_DESTROY:
+        {
+            ret = 0;
+        }
+        break;
         default:
             printf("drmIoctl: with unsupport IOType\n");
             do {
@@ -765,37 +790,38 @@ static int drmOpenByBusid(const char *busid, int type)
 
     drmMsg("drmOpenByBusid: Searching for BusID %s\n", busid);
     for (i = base; i < base + DRM_MAX_MINOR; i++) {
-    fd = drmOpenMinor(i, 1, type);
-    drmMsg("drmOpenByBusid: drmOpenMinor returns %d\n", fd);
-    if (fd >= 0) {
-        /* We need to try for 1.4 first for proper PCI domain support
-         * and if that fails, we know the kernel is busted
-         */
-        sv.drm_di_major = 1;
-        sv.drm_di_minor = 4;
-        sv.drm_dd_major = -1;    /* Don't care */
-        sv.drm_dd_minor = -1;    /* Don't care */
-        if (drmSetInterfaceVersion(fd, &sv)) {
+        fd = drmOpenMinor(i, 1, type);
+        drmMsg("drmOpenByBusid: drmOpenMinor returns %d\n", fd);
+        if (fd >= 0) {
+            /* We need to try for 1.4 first for proper PCI domain support
+             * and if that fails, we know the kernel is busted
+             */
+            sv.drm_di_major = 1;
+            sv.drm_di_minor = 4;
+            sv.drm_dd_major = -1;    /* Don't care */
+            sv.drm_dd_minor = -1;    /* Don't care */
+            if (drmSetInterfaceVersion(fd, &sv)) {
 #ifndef __alpha__
-        pci_domain_ok = 0;
+                pci_domain_ok = 0;
 #endif
-        sv.drm_di_major = 1;
-        sv.drm_di_minor = 1;
-        sv.drm_dd_major = -1;       /* Don't care */
-        sv.drm_dd_minor = -1;       /* Don't care */
-        drmMsg("drmOpenByBusid: Interface 1.4 failed, trying 1.1\n");
-        drmSetInterfaceVersion(fd, &sv);
+                sv.drm_di_major = 1;
+                sv.drm_di_minor = 1;
+                sv.drm_dd_major = -1;       /* Don't care */
+                sv.drm_dd_minor = -1;       /* Don't care */
+                drmMsg("drmOpenByBusid: Interface 1.4 failed, trying 1.1\n");
+                drmSetInterfaceVersion(fd, &sv);
+            }
+            buf = drmGetBusid(fd);
+            if (buf) {
+                drmMsg("drmOpenByBusid: drmGetBusid reports %s\n", buf);
+                if (drmMatchBusID(buf, busid, pci_domain_ok)) {
+                    drmFreeBusid(buf);
+                    return fd;
+                }
+                drmFreeBusid(buf);
+            }
+            close(fd);
         }
-        buf = drmGetBusid(fd);
-        drmMsg("drmOpenByBusid: drmGetBusid reports %s\n", buf);
-        if (buf && drmMatchBusID(buf, busid, pci_domain_ok)) {
-        drmFreeBusid(buf);
-        return fd;
-        }
-        if (buf)
-        drmFreeBusid(buf);
-        close(fd);
-    }
     }
     return -1;
 }
