@@ -34,6 +34,7 @@
 #include <string.h>    // memset
 #include <stdlib.h>    // atoi atol
 #include <math.h>
+#include "mos_os.h"
 
 #if MOS_MESSAGES_ENABLED
 #include <time.h>     //for simulate random memory allcation failure
@@ -86,7 +87,7 @@ uint32_t MosUtilities::m_mosAllocMemoryFailSimulateAllocCounter = 0;
     (m_mosAllocMemoryFailSimulateMode == MEMORY_ALLOC_FAIL_SIMULATE_MODE_RANDOM ||  \
      m_mosAllocMemoryFailSimulateMode == MEMORY_ALLOC_FAIL_SIMULATE_MODE_TRAVERSE)
 
-void MosUtilities::MosInitAllocMemoryFailSimulateFlag()
+void MosUtilities::MosInitAllocMemoryFailSimulateFlag(MOS_CONTEXT_HANDLE mosCtx)
 {
     MOS_USER_FEATURE_VALUE_DATA userFeatureValueData;
     MOS_STATUS                  eStatus = MOS_STATUS_SUCCESS;
@@ -102,7 +103,8 @@ void MosUtilities::MosInitAllocMemoryFailSimulateFlag()
     MosUserFeatureReadValueID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_MODE_ID,
-        &userFeatureValueData);
+        &userFeatureValueData,
+        mosCtx);
 
     if ((userFeatureValueData.u32Data == MEMORY_ALLOC_FAIL_SIMULATE_MODE_DEFAULT) ||
         (userFeatureValueData.u32Data == MEMORY_ALLOC_FAIL_SIMULATE_MODE_RANDOM) ||
@@ -122,7 +124,8 @@ void MosUtilities::MosInitAllocMemoryFailSimulateFlag()
     MosUserFeatureReadValueID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_FREQ_ID,
-        &userFeatureValueData);
+        &userFeatureValueData,
+        mosCtx);
 
     if ((userFeatureValueData.u32Data >= MIN_MEMORY_ALLOC_FAIL_FREQ) &&
         (userFeatureValueData.u32Data <= MAX_MEMORY_ALLOC_FAIL_FREQ))
@@ -146,7 +149,8 @@ void MosUtilities::MosInitAllocMemoryFailSimulateFlag()
     MosUserFeatureReadValueID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_HINT_ID,
-        &userFeatureValueData);
+        &userFeatureValueData,
+        mosCtx);
 
     if (userFeatureValueData.u32Data <= m_mosAllocMemoryFailSimulateFreq)
     {
@@ -214,18 +218,17 @@ bool MosUtilities::MosSimulateAllocMemoryFail(
 }
 #endif  // #if (_DEBUG || _RELEASE_INTERNAL)
 
-
-MOS_STATUS MosUtilities::MosUtilitiesInit(PMOS_USER_FEATURE_KEY_PATH_INFO userFeatureKeyPathInfo)
+MOS_STATUS MosUtilities::MosUtilitiesInit(MOS_CONTEXT_HANDLE mosCtx)
 {
     MOS_STATUS                  eStatus = MOS_STATUS_SUCCESS;
 
     MOS_OS_FUNCTION_ENTER;
 
-    eStatus = MosOsUtilitiesInit(userFeatureKeyPathInfo);
+    eStatus = MosOsUtilitiesInit(mosCtx);
 
 #if (_DEBUG || _RELEASE_INTERNAL)
     //Initialize MOS simulate random alloc memorflag
-    MosInitAllocMemoryFailSimulateFlag();
+    MosInitAllocMemoryFailSimulateFlag(mosCtx);
 
     MOS_USER_FEATURE_VALUE_DATA userFeatureValueData;
 
@@ -233,14 +236,15 @@ MOS_STATUS MosUtilities::MosUtilitiesInit(PMOS_USER_FEATURE_KEY_PATH_INFO userFe
     MosUserFeatureReadValueID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_RESOURCE_ADDR_DUMP_ENABLE_ID,
-        &userFeatureValueData);
+        &userFeatureValueData,
+        mosCtx);
     MosUtilities::m_enableAddressDump = userFeatureValueData.i32Data ? true : false;
 #endif
 
     return eStatus;
 }
 
-MOS_STATUS MosUtilities::MosUtilitiesClose()
+MOS_STATUS MosUtilities::MosUtilitiesClose(MOS_CONTEXT_HANDLE mosCtx)
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
@@ -250,12 +254,12 @@ MOS_STATUS MosUtilities::MosUtilitiesClose()
 
     // MOS_OS_Utilitlies_Close must be called right before end of function
     // Because Memninja will calc mem leak here.
-    // Any memory allocation release after MOS_OS_UtilitiesNext_Close() will be treated as mem leak.
-    eStatus = MosOsUtilitiesClose();
+    // Any memory allocation release after MosOsUtilitiesClose() will be treated as mem leak.
+    eStatus = MosOsUtilitiesClose(mosCtx);
 
 #if (_DEBUG || _RELEASE_INTERNAL)
     //Reset Simulate Alloc Memory Fail flags
-    MosInitAllocMemoryFailSimulateFlag();
+    MosInitAllocMemoryFailSimulateFlag(mosCtx);
 #endif
 
     return eStatus;
@@ -270,6 +274,7 @@ void MosUtilities::MosFreeUserFeatureValueString(PMOS_USER_FEATURE_VALUE_STRING
             if (pUserString->pStringData)
             {
                 MOS_FreeMemAndSetNull(pUserString->pStringData);
+                m_mosMemAllocFakeCounter--;
             }
             pUserString->uSize = 0;
         }
@@ -774,7 +779,7 @@ MOS_STATUS MosUtilities::MosWriteOneUserFeatureGroupToXML(MOS_USER_FEATURE_VALUE
     return eStatus;
 }
 
-MOS_STATUS MosUtilities::MosGenerateUserFeatureKeyXML()
+MOS_STATUS MosUtilities::MosGenerateUserFeatureKeyXML(MOS_CONTEXT_HANDLE mosCtx)
 {
     char                                sOutBuf[MAX_USER_FEATURE_FIELD_LENGTH];
     uint32_t                            uiIndex=0;
@@ -789,7 +794,8 @@ MOS_STATUS MosUtilities::MosGenerateUserFeatureKeyXML()
     eStatus = MosUserFeatureReadValueID(
                     nullptr,
                     __MOS_USER_FEATURE_KEY_XML_AUTOGEN_ID,
-                    &UserFeatureData);
+                    &UserFeatureData,
+                    mosCtx);
     if (UserFeatureData.u32Data == 0)
     {
         eStatus = MOS_STATUS_INVALID_PARAMETER;
@@ -800,7 +806,8 @@ MOS_STATUS MosUtilities::MosGenerateUserFeatureKeyXML()
     eStatus = MosUserFeatureReadValueID(
                     nullptr,
                     __MOS_USER_FEATURE_KEY_XML_FILEPATH_ID,
-                    &UserFeatureData);
+                    &UserFeatureData,
+                    mosCtx);
     // User Feature Key Header Start
     MosZeroMemory(sOutBuf, sizeof(sOutBuf));
     MosSecureStringPrint(
@@ -953,9 +960,6 @@ MOS_STATUS MosUtilities::MosCopyUserFeatureValueData(
                 pDstData->StringData.uSize,
                 pSrcData->StringData.pStringData,
                 pSrcData->StringData.uSize);
-
-            MOS_SafeFreeMemory(pSrcData->StringData.pStringData);
-            pSrcData->StringData.pStringData = nullptr;
         }
         break;
     case MOS_USER_FEATURE_VALUE_TYPE_MULTI_STRING:
@@ -1039,7 +1043,7 @@ MOS_STATUS MosUtilities::MosAssignUserFeatureValueData(
         pDstData->StringData.uMaxSize = MOS_USER_CONTROL_MAX_DATA_SIZE;
         if ((pData != nullptr) && (strlen(pData) != 0))
         {
-            pDstData->StringData.uSize = (uint32_t)strlen(pData);
+            pDstData->StringData.uSize = (uint32_t)strlen(pData) + 1;
             if (pDstData->StringData.uSize > pDstData->StringData.uMaxSize)
             {
                 pDstData->StringData.uSize = pDstData->StringData.uMaxSize;
@@ -1050,9 +1054,10 @@ MOS_STATUS MosUtilities::MosAssignUserFeatureValueData(
                 MOS_OS_ASSERTMESSAGE("Failed to allocate memory.");
                 return MOS_STATUS_NULL_POINTER;
             }
+            m_mosMemAllocFakeCounter++;
             eStatus = MosSecureStrcpy(
                 pDstData->StringData.pStringData,
-                pDstData->StringData.uSize + 1,
+                pDstData->StringData.uSize,
                 (char *)pData);
         }
         break;
@@ -1418,7 +1423,8 @@ MOS_STATUS MosUtilities::MosUserFeatureOpen(
     MOS_USER_FEATURE_TYPE KeyType,
     const char            *pSubKey,
     uint32_t              dwAccess,
-    void                  **pUFKey)
+    void                  **pUFKey,
+    MOS_USER_FEATURE_KEY_PATH_INFO  *ufInfo)
 {
     MOS_STATUS  eStatus;
     void        *RootKey = 0;
@@ -1445,7 +1451,8 @@ MOS_STATUS MosUtilities::MosUserFeatureOpen(
                              pSubKey,
                              0,
                              dwAccess,
-                             pUFKey)) !=  MOS_STATUS_SUCCESS)
+                             pUFKey,
+                             ufInfo)) !=  MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to open user feature key %s.", pSubKey);
     }
@@ -1555,10 +1562,23 @@ MOS_STATUS MosUtilities::MosUserFeatureReadValueString(
     }
     if (strlen(pcTmpStr) > 0)
     {
-        pFeatureValue->Value.StringData.pStringData = (char *)MOS_AllocAndZeroMemory(strlen(pcTmpStr) + 1);
+        if (!pFeatureValue->Value.StringData.pStringData)
+        {
+            m_mosMemAllocFakeCounter++;
+        }
 
-        MosSecureMemcpy(pFeatureValue->Value.StringData.pStringData, strlen(pcTmpStr), pcTmpStr, strlen(pcTmpStr));
-        pFeatureValue->Value.StringData.uSize = dwUFSize;
+        if (pFeatureValue->Value.StringData.uSize < strlen(pcTmpStr) + 1)
+        {
+            pFeatureValue->Value.StringData.pStringData =
+                (char *)MOS_ReallocMemory(pFeatureValue->Value.StringData.pStringData, strlen(pcTmpStr) + 1);
+            pFeatureValue->Value.StringData.uSize = strlen(pcTmpStr) + 1;
+        }
+
+        MOS_OS_CHK_NULL_RETURN(pFeatureValue->Value.StringData.pStringData);
+
+        MosZeroMemory(pFeatureValue->Value.StringData.pStringData, pFeatureValue->Value.StringData.uSize);
+
+        MosSecureMemcpy(pFeatureValue->Value.StringData.pStringData, pFeatureValue->Value.StringData.uSize, pcTmpStr, strlen(pcTmpStr));
     }
     return eStatus;
 }
@@ -1878,9 +1898,10 @@ MOS_STATUS MosUtilities::MosUserFeatureWriteValuePrimitive(
 
 MOS_STATUS MosUtilities::MosUserFeatureReadValueFromMapID(
     uint32_t                        ValueID,
-    PMOS_USER_FEATURE_VALUE_DATA    pValueData)
+    PMOS_USER_FEATURE_VALUE_DATA    pValueData,
+    MOS_USER_FEATURE_KEY_PATH_INFO  *ufInfo)
 {
-    void                        *UFKey           = nullptr;
+    void                        *ufKey           = nullptr;
     PMOS_USER_FEATURE_VALUE     pUserFeature    = nullptr;
     int32_t                     iDataFlag       = MOS_USER_FEATURE_VALUE_DATA_FLAG_NONE_CUSTOM_DEFAULT_VALUE_TYPE;
     MOS_STATUS                  eStatus         = MOS_STATUS_SUCCESS;
@@ -1899,13 +1920,14 @@ MOS_STATUS MosUtilities::MosUserFeatureReadValueFromMapID(
     }
 
     // Open the user feature
-    // Assigned the pUserFeature to UFKey for future reading
-    UFKey = pUserFeature;
+    // Assigned the pUserFeature to ufKey for future reading
+    ufKey = pUserFeature;
     if((eStatus = MosUserFeatureOpen(
                        pUserFeature->Type,
                        pUserFeature->pcPath,
                        KEY_READ,
-                       &UFKey)) != MOS_STATUS_SUCCESS)
+                       &ufKey,
+                       ufInfo)) != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Failed to open user feature for reading eStatus:%d.", eStatus);
         eStatus = MOS_STATUS_USER_FEATURE_KEY_OPEN_FAILED;
@@ -1933,16 +1955,16 @@ MOS_STATUS MosUtilities::MosUserFeatureReadValueFromMapID(
     switch(pUserFeature->ValueType)
     {
        case MOS_USER_FEATURE_VALUE_TYPE_BINARY:
-           eStatus = MosUserFeatureReadValueBinary(UFKey, pUserFeature);
+           eStatus = MosUserFeatureReadValueBinary(ufKey, pUserFeature);
            break;
        case MOS_USER_FEATURE_VALUE_TYPE_STRING:
-           eStatus = MosUserFeatureReadValueString(UFKey, pUserFeature);
+           eStatus = MosUserFeatureReadValueString(ufKey, pUserFeature);
            break;
        case MOS_USER_FEATURE_VALUE_TYPE_MULTI_STRING:
-           eStatus = MosUserFeatureReadValueMultiString(UFKey, pUserFeature);
+           eStatus = MosUserFeatureReadValueMultiString(ufKey, pUserFeature);
            break;
        default:
-           eStatus = MosUserFeatureReadValuePrimitive(UFKey, pUserFeature);
+           eStatus = MosUserFeatureReadValuePrimitive(ufKey, pUserFeature);
            break;
     }
 
@@ -1963,18 +1985,33 @@ finish:
             pValueData,
             pUserFeature->ValueType);
     }
-    MosUserFeatureCloseKey(UFKey);      // Closes the key if not nullptr
+    MosUserFeatureCloseKey(ufKey);  // Closes the key if not nullptr
     return eStatus;
 }
 
 MOS_STATUS MosUtilities::MosUserFeatureReadValueID(
     PMOS_USER_FEATURE_INTERFACE     pOsUserFeatureInterface,
     uint32_t                        ValueID,
-    PMOS_USER_FEATURE_VALUE_DATA    pValueData)
+    PMOS_USER_FEATURE_VALUE_DATA    pValueData,
+    MOS_CONTEXT_HANDLE              mosCtx)
+{
+    MOS_USER_FEATURE_KEY_PATH_INFO *ufInfo = Mos_GetDeviceUfPathInfo((PMOS_CONTEXT)mosCtx);
+    return MosUserFeatureReadValueFromMapID(
+        ValueID,
+        pValueData,
+        ufInfo);
+}
+
+MOS_STATUS MosUtilities::MosUserFeatureReadValueID(
+    PMOS_USER_FEATURE_INTERFACE     pOsUserFeatureInterface,
+    uint32_t                        ValueID,
+    PMOS_USER_FEATURE_VALUE_DATA    pValueData,
+    MOS_USER_FEATURE_KEY_PATH_INFO *ufInfo)
 {
     return MosUserFeatureReadValueFromMapID(
         ValueID,
-        pValueData);
+        pValueData,
+        ufInfo);
 }
 
 const char* MosUtilities::MosUserFeatureLookupValueName(uint32_t ValueID)
@@ -2024,7 +2061,8 @@ const char *MosUtilities::MosUserFeatureLookupWritePath(uint32_t ValueID)
 
 MOS_STATUS MosUtilities::MosUserFeatureWriteValuesTblID(
     PMOS_USER_FEATURE_VALUE_WRITE_DATA      pWriteValues,
-    uint32_t                                uiNumOfValues)
+    uint32_t                                uiNumOfValues,
+    MOS_USER_FEATURE_KEY_PATH_INFO          *ufInfo)
 {
     uint32_t                            ui;
     PMOS_USER_FEATURE_VALUE             pFeatureValue      = nullptr;
@@ -2035,6 +2073,8 @@ MOS_STATUS MosUtilities::MosUserFeatureWriteValuesTblID(
     MOS_STATUS                          eStatus            = MOS_STATUS_SUCCESS;
     char                                WritePathWithPID[MAX_PATH];
     int32_t                             pid;
+    uint64_t                            ulTraceData         = 0;
+    bool                                isValid             = false;
 
     //--------------------------------------------------
     MOS_OS_CHK_NULL_RETURN(pWriteValues);
@@ -2058,21 +2098,47 @@ MOS_STATUS MosUtilities::MosUserFeatureWriteValuesTblID(
         //append write path with pid
         sprintf_s(WritePathWithPID, MAX_PATH, "%s\\%d", pUserFeature->pcWritePath, pid);
 
+        // Trace data in case opening user feature for write fails
+        switch (pUserFeature->ValueType)
+        {
+            case MOS_USER_FEATURE_VALUE_TYPE_BOOL:
+            case MOS_USER_FEATURE_VALUE_TYPE_INT32:
+            case MOS_USER_FEATURE_VALUE_TYPE_UINT32:
+            case MOS_USER_FEATURE_VALUE_TYPE_FLOAT:
+                ulTraceData = pWriteValues[ui].Value.u32Data;
+                isValid = true;
+                break;
+            case MOS_USER_FEATURE_VALUE_TYPE_INT64:
+            case MOS_USER_FEATURE_VALUE_TYPE_UINT64:
+                ulTraceData = pWriteValues[ui].Value.u64Data;
+                isValid = true;
+                break;
+            default:
+                MOS_OS_NORMALMESSAGE("Unknown value type %d", pUserFeature->ValueType);
+        }
+
+        if (isValid)
+        {
+            MosTraceDataDictionary(pUserFeature->pValueName, &ulTraceData, sizeof(ulTraceData));
+        }
+
         //try to open Write path with pid first
         if ((eStatus = MosUserFeatureOpen(
                  pUserFeature->Type,
                  WritePathWithPID,
                  KEY_WRITE,
-                 &UFKey)) != MOS_STATUS_SUCCESS)
+                 &UFKey,
+                 ufInfo)) != MOS_STATUS_SUCCESS)
         {
             MOS_OS_NORMALMESSAGE("Failed to open user feature for concurrency.");
             if ((eStatus = MosUserFeatureOpen(
                      pUserFeature->Type,
                      pUserFeature->pcWritePath,
                      KEY_WRITE,
-                     &UFKey)) != MOS_STATUS_SUCCESS)
+                     &UFKey,
+                     ufInfo)) != MOS_STATUS_SUCCESS)
             {
-                MOS_OS_NORMALMESSAGE("Failed to open user feature for reading.");
+                MOS_OS_NORMALMESSAGE("Failed to open user feature for writing.");
                 eStatus = MOS_STATUS_USER_FEATURE_KEY_OPEN_FAILED;
                 goto finish;
             }
@@ -2129,16 +2195,33 @@ finish:
 MOS_STATUS MosUtilities::MosUserFeatureWriteValuesID(
     PMOS_USER_FEATURE_INTERFACE             pOsUserFeatureInterface,
     PMOS_USER_FEATURE_VALUE_WRITE_DATA      pWriteValues,
-    uint32_t                                uiNumOfValues)
+    uint32_t                                uiNumOfValues,
+    MOS_CONTEXT_HANDLE                      mosCtx)
+{
+    MOS_USER_FEATURE_KEY_PATH_INFO *ufInfo = Mos_GetDeviceUfPathInfo((PMOS_CONTEXT)mosCtx);
+
+    return MosUserFeatureWriteValuesTblID(
+        pWriteValues,
+        uiNumOfValues,
+        ufInfo);
+}
+
+MOS_STATUS MosUtilities::MosUserFeatureWriteValuesID(
+    PMOS_USER_FEATURE_INTERFACE        pOsUserFeatureInterface,
+    PMOS_USER_FEATURE_VALUE_WRITE_DATA pWriteValues,
+    uint32_t                           uiNumOfValues,
+    MOS_USER_FEATURE_KEY_PATH_INFO *   ufInfo)
 {
     return MosUserFeatureWriteValuesTblID(
         pWriteValues,
-        uiNumOfValues);
+        uiNumOfValues,
+        ufInfo);
 }
 
 MOS_STATUS MosUtilities::MosUserFeatureEnableNotification(
     PMOS_USER_FEATURE_INTERFACE            pOsUserFeatureInterface,
-    PMOS_USER_FEATURE_NOTIFY_DATA          pNotification)
+    PMOS_USER_FEATURE_NOTIFY_DATA          pNotification,
+    MOS_CONTEXT_HANDLE                     mosCtx)
 {
     PMOS_USER_FEATURE_NOTIFY_DATA_COMMON    pNotifyCommon;
     int32_t                                 bResult;
@@ -2151,6 +2234,8 @@ MOS_STATUS MosUtilities::MosUserFeatureEnableNotification(
     MOS_OS_ASSERT(pNotification->pPath);
     //---------------------------------------
 
+    MOS_USER_FEATURE_KEY_PATH_INFO *ufInfo = Mos_GetDeviceUfPathInfo((PMOS_CONTEXT)mosCtx);
+
     // Reset the triggered flag
     pNotification->bTriggered = false;
 
@@ -2173,7 +2258,8 @@ MOS_STATUS MosUtilities::MosUserFeatureEnableNotification(
                           pNotification->Type,
                           pNotification->pPath,
                           KEY_READ,
-                          &pNotifyCommon->UFKey)) != MOS_STATUS_SUCCESS)
+                          &pNotifyCommon->UFKey,
+                          ufInfo)) != MOS_STATUS_SUCCESS)
         {
             MOS_OS_ASSERTMESSAGE("Failed to open user feature for reading.");
             return MOS_STATUS_USER_FEATURE_KEY_OPEN_FAILED;
